#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=uwajima1.21_tt5_local.ps
projection=-JX18/12
region=-R0/4.0/0/120
gmt psbasemap $region $projection -Bxa1f0.1+l'Epicentral Distance (deg)' -Bya50f10+l'Travel Time (s)' -BWeSn+t'Local Distance uwajima1.21' -K > $psfile
# Distance limit for hypocentroid
gmt psxy -: -R $projection -Wthick,black,- -O -K << END >> $psfile
 0.000    1.000
90.000    1.000
END
# Pn TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,green -K -O << END >> $psfile
     7.369     0.100
     7.953     0.200
     8.833     0.300
     9.922     0.400
    11.145     0.500
    12.449     0.600
    13.798     0.700
    15.173     0.800
    16.562     0.900
    17.959     1.000
    19.361     1.100
    20.767     1.200
    22.175     1.300
    23.585     1.400
    24.996     1.500
    26.407     1.600
    27.820     1.700
    29.233     1.800
    30.646     1.900
    32.060     2.000
    33.474     2.100
    34.889     2.200
    36.303     2.300
    37.718     2.400
    39.133     2.500
    40.548     2.600
    41.962     2.700
    43.378     2.800
    44.793     2.900
    46.208     3.000
    47.623     3.100
    49.039     3.200
    50.454     3.300
    51.869     3.400
    53.285     3.500
    54.700     3.600
    56.115     3.700
    57.531     3.800
    58.946     3.900
    60.361     4.000
END
# Pn label
gmt pstext -: -R $projection -F+f10p,Helvetica,green+a0.+jTL -K -O << END >> $psfile
    52.700     3.600 Pn
END
# Pb TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,blue -K -O -Ve << END >> $psfile
END
# Pg TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,red -K -O << END >> $psfile
END
# Pg label
gmt pstext -: -R $projection -F+f10p,Helvetica,red+a0.+jTL -K -O << END >> $psfile
END
# P_ TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,cyan -K -O << END >> $psfile
    47.500     2.500
    49.400     2.600
    51.300     2.700
    53.200     2.800
    55.100     2.900
    57.000     3.000
    58.900     3.100
    60.800     3.200
    62.700     3.300
    64.600     3.400
    66.500     3.500
    68.400     3.600
    70.300     3.700
    72.200     3.800
    74.100     3.900
    76.000     4.000
END
# P_ label
gmt pstext -: -R $projection -F+f10p,Helvetica,cyan+a0.+jBR -K -O << END >> $psfile
    70.400     3.600 P_
END
# Sn TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,green -K -O << END >> $psfile
    12.371     0.100
    13.354     0.200
    14.840     0.300
    16.682     0.400
    18.762     0.500
    20.992     0.600
    23.314     0.700
    25.689     0.800
    28.095     0.900
    30.519     1.000
    32.955     1.100
    35.399     1.200
    37.847     1.300
    40.299     1.400
    42.753     1.500
    45.210     1.600
    47.667     1.700
    50.126     1.800
    52.585     1.900
    55.046     2.000
    57.507     2.100
    59.968     2.200
    62.430     2.300
    64.892     2.400
    67.354     2.500
    69.816     2.600
    72.279     2.700
    74.741     2.800
    77.204     2.900
    79.667     3.000
    82.130     3.100
    84.593     3.200
    87.056     3.300
    89.518     3.400
    91.981     3.500
    94.444     3.600
    96.906     3.700
    99.369     3.800
   101.832     3.900
   104.294     4.000
END
# Sn label
gmt pstext -: -R $projection -F+f10p,Helvetica,green+a0.+jTL -K -O << END >> $psfile
    92.444     3.600 Sn
END
# Sb TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,blue -K -O -Ve << END >> $psfile
END
# Sg TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,red -K -O << END >> $psfile
END
# Sg label
gmt pstext -: -R $projection -F+f10p,Helvetica,red+a0.+jTL -K -O << END >> $psfile
END
# Lg TT curve at hypocentroid depth
gmt psxy -: -R $projection -Wthick,cyan -K -O << END >> $psfile
    78.750     2.500
    81.900     2.600
    85.050     2.700
    88.200     2.800
    91.350     2.900
    94.500     3.000
    97.650     3.100
   100.800     3.200
   103.950     3.300
   107.100     3.400
   110.250     3.500
   113.400     3.600
   116.550     3.700
   119.700     3.800
   122.850     3.900
   126.000     4.000
END
# Lg label
gmt pstext -: -R $projection -F+f10p,Helvetica,cyan+a0.+jBR -K -O << END >> $psfile
   115.400     3.600 Lg
END
# Pn TT curve at minimum depth
gmt psxy -: -R $projection -Wthin,green,- -K -O << END >> $psfile
    12.958     0.600
    14.376     0.700
    15.793     0.800
    17.211     0.900
    18.628     1.000
    20.046     1.100
    21.464     1.200
    22.881     1.300
    24.299     1.400
    25.716     1.500
    27.134     1.600
    28.552     1.700
    29.969     1.800
    31.387     1.900
    32.804     2.000
    34.222     2.100
    35.639     2.200
    37.057     2.300
    38.475     2.400
    39.892     2.500
    41.310     2.600
    42.727     2.700
    44.145     2.800
    45.563     2.900
    46.980     3.000
    48.398     3.100
    49.815     3.200
    51.233     3.300
    52.651     3.400
    54.068     3.500
    55.485     3.600
    56.902     3.700
    58.319     3.800
    59.736     3.900
    61.153     4.000
END
# Pb TT curve at minimum depth
gmt psxy -: -R $projection -Wthin,blue,- -K -O -Ve << END >> $psfile
END
# Pg TT curve at minimum depth
gmt psxy -: -R $projection -Wthin,red,- -K -O << END >> $psfile
     4.817     0.100
     5.820     0.200
     7.179     0.300
     8.719     0.400
    10.346     0.500
    12.012     0.600
    13.695     0.700
    15.386     0.800
    17.082     0.900
    18.780     1.000
    20.479     1.100
    22.180     1.200
    23.882     1.300
    25.584     1.400
    27.286     1.500
    28.989     1.600
    30.692     1.700
    32.395     1.800
    34.099     1.900
    35.802     2.000
    37.505     2.100
    39.209     2.200
    40.913     2.300
    42.616     2.400
    44.320     2.500
    46.024     2.600
    47.727     2.700
    49.431     2.800
    51.135     2.900
    52.839     3.000
    54.542     3.100
    56.246     3.200
    57.950     3.300
    59.653     3.400
    61.357     3.500
    63.061     3.600
    64.764     3.700
    66.467     3.800
    68.171     3.900
    69.875     4.000
END
# Sn TT curve at minimum depth
gmt psxy -: -R $projection -Wthin,green,- -K -O << END >> $psfile
    24.006     0.700
    26.474     0.800
    28.942     0.900
    31.411     1.000
    33.879     1.100
    36.347     1.200
    38.815     1.300
    41.283     1.400
    43.751     1.500
    46.219     1.600
    48.687     1.700
    51.155     1.800
    53.623     1.900
    56.091     2.000
    58.559     2.100
    61.027     2.200
    63.495     2.300
    65.963     2.400
    68.431     2.500
    70.899     2.600
    73.367     2.700
    75.835     2.800
    78.303     2.900
    80.771     3.000
    83.239     3.100
    85.706     3.200
    88.174     3.300
    90.640     3.400
    93.107     3.500
    95.574     3.600
    98.041     3.700
   100.508     3.800
   102.974     3.900
   105.441     4.000
END
# Sb TT curve at minimum depth
gmt psxy -: -R $projection -Wthin,blue,- -K -O -Ve << END >> $psfile
END
# Sg TT curve at minimum depth
gmt psxy -: -R $projection -Wthin,red,- -K -O << END >> $psfile
     8.044     0.100
     9.716     0.200
    11.978     0.300
    14.535     0.400
    17.226     0.500
    19.974     0.600
    22.748     0.700
    25.533     0.800
    28.324     0.900
    31.119     1.000
    33.917     1.100
    36.716     1.200
    39.516     1.300
    42.317     1.400
    45.118     1.500
    47.921     1.600
    50.723     1.700
    53.526     1.800
    56.329     1.900
    59.132     2.000
    61.935     2.100
    64.738     2.200
    67.542     2.300
    70.346     2.400
    73.149     2.500
    75.952     2.600
    78.756     2.700
    81.559     2.800
    84.363     2.900
    87.166     3.000
    89.970     3.100
    92.773     3.200
    95.577     3.300
    98.380     3.400
   101.184     3.500
   103.988     3.600
   106.791     3.700
   109.594     3.800
   112.398     3.900
   115.201     4.000
END
# Pn TT curve at maximum depth
gmt psxy -: -R $projection -Wthin,green,- -K -O << END >> $psfile
    10.429     0.100
    10.795     0.200
    11.378     0.300
    12.143     0.400
    13.054     0.500
    14.080     0.600
    15.194     0.700
    16.375     0.800
    17.605     0.900
    18.873     1.000
    20.169     1.100
    21.487     1.200
    22.822     1.300
    24.170     1.400
    25.527     1.500
    26.893     1.600
    28.266     1.700
    29.644     1.800
    31.026     1.900
    32.412     2.000
    33.801     2.100
    35.193     2.200
    36.586     2.300
    37.982     2.400
    39.379     2.500
    40.778     2.600
    42.178     2.700
    43.579     2.800
    44.981     2.900
    46.384     3.000
    47.787     3.100
    49.191     3.200
    50.596     3.300
    52.001     3.400
    53.407     3.500
    54.813     3.600
    56.220     3.700
    57.627     3.800
    59.034     3.900
    60.442     4.000
END
# Pb TT curve at maximum depth
gmt psxy -: -R $projection -Wthin,blue,- -K -O -Ve << END >> $psfile
END
# Pg TT curve at maximum depth
gmt psxy -: -R $projection -Wthin,red,- -K -O << END >> $psfile
END
# Sn TT curve at maximum depth
gmt psxy -: -R $projection -Wthin,green,- -K -O << END >> $psfile
    17.699     0.100
    18.324     0.200
    19.318     0.300
    20.625     0.400
    22.185     0.500
    23.943     0.600
    25.855     0.700
    27.884     0.800
    30.003     0.900
    32.190     1.000
    34.430     1.100
    36.710     1.200
    39.020     1.300
    41.355     1.400
    43.709     1.500
    46.079     1.600
    48.461     1.700
    50.853     1.800
    53.254     1.900
    55.661     2.000
    58.074     2.100
    60.492     2.200
    62.914     2.300
    65.340     2.400
    67.768     2.500
    70.200     2.600
    72.633     2.700
    75.069     2.800
    77.506     2.900
    79.945     3.000
    82.385     3.100
    84.826     3.200
    87.268     3.300
    89.712     3.400
    92.156     3.500
    94.601     3.600
    97.047     3.700
    99.493     3.800
   101.940     3.900
   104.387     4.000
END
# Sb TT curve at maximum depth
gmt psxy -: -R $projection -Wthin,blue,- -K -O -Ve << END >> $psfile
END
# Sg TT curve at maximum depth
gmt psxy -: -R $projection -Wthin,red,- -K -O << END >> $psfile
END
# Phases other than the standard crustal phases
gmt psxy -: -R $projection -Sd -Wthin,orange -K -O << END >> $psfile
END
# Pn arrivals
gmt psxy -: -R $projection -Sx -Wthin,green -K -O << END >> $psfile
    13.210     0.478     0.200
    11.910     0.432     0.200
    18.310     0.936     0.200
    18.210     0.964     0.200
    19.910     1.057     0.200
    20.310     1.103     0.200
    18.210     1.050     0.200
    18.910     1.050     0.200
    22.210     1.183     0.200
    23.210     1.354     0.200
    24.710     1.428     0.200
    24.210     1.428     0.200
    24.410     1.463     0.200
    24.210     1.463     0.200
    29.210     1.648     0.200
    29.910     1.648     0.200
    27.610     1.733     0.200
    27.210     1.733     0.200
    28.510     1.818     0.200
    28.210     1.818     0.200
    30.710     1.920     0.200
    30.210     1.920     0.200
    32.210     2.028     0.200
    34.410     2.136     0.200
    34.210     2.136     0.200
    32.810     2.129     0.200
    32.210     2.129     0.200
    34.710     2.207     0.200
    34.210     2.207     0.200
    37.210     2.324     0.200
    37.610     2.324     0.200
    37.610     2.468     0.200
    37.210     2.473     0.200
    37.910     2.473     0.200
    39.210     2.519     0.200
    40.110     2.519     0.200
    39.210     2.644     0.200
    39.610     2.644     0.200
    43.810     2.644     0.200
    42.010     2.669     0.200
    41.210     2.669     0.200
    43.210     2.874     0.200
    43.510     2.874     0.200
    43.210     2.815     0.200
    43.410     2.815     0.200
    47.810     3.040     0.200
    47.210     3.040     0.200
    48.210     3.069     0.200
    48.510     3.151     0.200
    48.210     3.151     0.200
    52.210     3.307     0.200
    52.710     3.307     0.200
    49.710     3.312     0.200
    49.210     3.312     0.200
    51.210     3.366     0.200
    50.810     3.443     0.200
    57.210     3.849     0.200
    57.510     3.858     0.200
    57.510     3.858     0.200
    57.210     3.858     0.200
    56.210     3.916     0.200
    56.510     3.916     0.200
    63.210     4.252     0.200
    63.510     4.252     0.200
    65.210     4.293     0.200
    64.210     4.353     0.200
    69.210     4.808     0.200
    72.210     4.821     0.200
    73.110     4.821     0.200
    74.210     5.003     0.200
    74.810     5.003     0.200
    75.410     5.140     0.200
    75.210     5.140     0.200
    76.210     5.184     0.200
    76.610     5.184     0.200
    79.210     5.274     0.200
    78.410     5.418     0.200
    81.210     5.526     0.200
    81.610     5.526     0.200
    81.810     5.551     0.200
    84.410     5.743     0.200
    84.210     5.743     0.200
    85.210     5.846     0.200
    85.410     5.846     0.200
    85.610     5.861     0.200
    85.210     5.868     0.200
    85.710     5.868     0.200
    87.210     5.912     0.200
    87.810     5.912     0.200
    85.710     5.981     0.200
    88.010     6.008     0.200
    88.010     6.010     0.200
    88.210     6.154     0.200
    88.410     6.154     0.200
    91.210     6.188     0.200
    92.010     6.188     0.200
    93.210     6.259     0.200
    94.110     6.410     0.200
    93.210     6.410     0.200
    92.410     6.427     0.200
    96.210     6.526     0.200
    97.010     6.526     0.200
    96.210     6.543     0.200
    96.410     6.543     0.200
    97.210     6.547     0.200
    98.210     6.740     0.200
   103.210     7.185     0.200
   107.110     7.447     0.200
   106.210     7.447     0.200
   109.110     7.560     0.200
   115.210     7.983     0.200
   118.210     8.036     0.200
   119.210     8.209     0.200
   124.210     8.580     0.200
   129.210     8.937     0.200
   135.210     9.213     0.200
   134.710     9.213     0.200
   134.210     9.213     0.200
   138.210     9.548     0.200
   138.410     9.548     0.200
   138.210     9.566     0.200
   137.210     9.644     0.200
   143.210    10.034     0.200
   148.310    10.077     0.200
   155.210    10.781     0.200
   155.710    10.781     0.200
   175.210    12.387     0.200
   185.210    13.031     0.200
   185.610    13.031     0.200
    11.021     0.436     0.200
    15.120     0.778     0.200
    15.720     0.862     0.200
    17.120     0.855     0.200
    18.521     1.073     0.200
    19.120     1.137     0.200
    22.120     1.396     0.200
    22.720     1.414     0.200
    25.120     1.470     0.200
    24.720     1.498     0.200
    25.820     1.540     0.200
    27.120     1.646     0.200
    26.620     1.683     0.200
    29.220     1.783     0.200
    31.120     1.793     0.200
    30.120     1.823     0.200
    30.820     1.859     0.200
    34.120     2.038     0.200
    32.120     2.078     0.200
    33.620     2.175     0.200
    36.120     2.334     0.200
    35.720     2.331     0.200
    35.120     2.338     0.200
    36.820     2.431     0.200
    38.120     2.470     0.200
    43.120     2.527     0.200
    42.120     2.777     0.200
    42.120     2.813     0.200
    45.120     3.016     0.200
    47.120     3.085     0.200
    55.220     3.547     0.200
    56.120     3.654     0.200
    60.120     4.010     0.200
    60.920     4.060     0.200
    69.120     4.500     0.200
    72.120     4.872     0.200
    82.220     5.593     0.200
    89.021     6.055     0.200
    96.320     6.551     0.200
    98.220     6.822     0.200
   139.120     9.651     0.200
   217.120    15.560     0.200
     7.484     0.132     0.200
    13.281     0.664     0.200
    13.781     0.637     0.200
    16.883     0.944     0.200
    15.984     0.752     0.200
    20.684     1.194     0.200
    18.883     1.081     0.200
    17.383     0.978     0.200
    23.383     1.401     0.200
    21.582     1.269     0.200
    25.684     1.506     0.200
    26.781     1.593     0.200
    27.684     1.727     0.200
    29.281     1.767     0.200
    23.484     1.480     0.200
    27.184     1.634     0.200
    27.383     1.650     0.200
    29.781     1.874     0.200
    34.484     2.206     0.200
    30.484     1.967     0.200
    36.184     2.335     0.200
    36.383     2.237     0.200
    35.383     2.280     0.200
    35.484     2.328     0.200
    37.684     2.471     0.200
    38.883     2.481     0.200
    40.383     2.668     0.200
    46.984     3.071     0.200
    45.184     3.013     0.200
    44.383     2.935     0.200
    47.082     3.004     0.200
    46.184     3.060     0.200
    49.082     3.170     0.200
    47.383     3.249     0.200
    59.281     3.693     0.200
    56.383     3.745     0.200
    57.383     3.832     0.200
    61.383     4.187     0.200
    62.184     4.174     0.200
    62.383     4.216     0.200
    67.383     4.635     0.200
    70.383     4.767     0.200
    72.383     4.911     0.200
    72.184     5.005     0.200
    76.383     5.210     0.200
    76.484     5.250     0.200
    80.383     5.447     0.200
    81.383     5.499     0.200
    82.184     5.604     0.200
    84.383     5.766     0.200
    87.383     5.822     0.200
    84.082     5.809     0.200
    86.383     5.898     0.200
    85.383     5.969     0.200
    90.383     6.115     0.200
    89.383     6.126     0.200
    89.184     6.125     0.200
    88.984     6.185     0.200
    90.184     6.211     0.200
    93.383     6.293     0.200
    92.383     6.364     0.200
    94.383     6.412     0.200
    95.383     6.523     0.200
    98.383     6.700     0.200
    97.281     6.685     0.200
   100.383     6.939     0.200
   100.484     6.977     0.200
   101.383     7.047     0.200
   105.684     7.311     0.200
   106.383     7.374     0.200
   114.383     7.860     0.200
   118.383     8.135     0.200
   120.383     8.227     0.200
   123.383     8.498     0.200
   127.383     8.854     0.200
   129.383     8.918     0.200
   136.383     9.476     0.200
   137.684     9.518     0.200
   140.383     9.833     0.200
   143.383     9.973     0.200
   145.383    10.061     0.200
   147.383    10.268     0.200
   154.383    10.786     0.200
   167.383    11.476     0.200
   173.383    12.014     0.200
   171.383    12.071     0.200
   175.582    12.464     0.200
   173.383    12.226     0.200
   182.383    12.834     0.200
   183.383    13.045     0.200
   198.383    14.099     0.200
   220.383    15.762     0.200
   231.383    16.868     0.200
     7.305     0.165     0.200
    12.000     0.602     0.200
    13.805     0.659     0.200
    16.000     0.793     0.200
    17.203     0.972     0.200
    17.805     0.976     0.200
    18.203     1.035     0.200
    21.203     1.224     0.200
    23.203     1.371     0.200
    23.500     1.491     0.200
    25.203     1.511     0.200
    26.203     1.587     0.200
    29.203     1.627     0.200
    27.703     1.694     0.200
    28.203     1.846     0.200
    35.203     2.208     0.200
    36.203     2.195     0.200
    37.203     2.239     0.200
    35.203     2.316     0.200
    38.102     2.463     0.200
    38.500     2.559     0.200
    43.203     2.636     0.200
    44.203     2.970     0.200
    49.203     3.158     0.200
    49.203     3.234     0.200
    72.203     4.629     0.200
    84.703     5.747     0.200
    91.500     6.198     0.200
    99.906     6.965     0.200
     7.498     0.167     0.200
    12.498     0.614     0.200
    12.898     0.649     0.200
    16.098     0.792     0.200
    17.998     0.986     0.200
    18.498     1.044     0.200
    21.198     1.235     0.200
    22.498     1.367     0.200
    25.498     1.500     0.200
    23.198     1.500     0.200
    29.498     1.615     0.200
    26.498     1.594     0.200
    26.498     1.650     0.200
    27.798     1.702     0.200
    26.498     1.706     0.200
    28.498     1.858     0.200
    34.498     1.969     0.200
    34.498     2.197     0.200
    36.498     2.205     0.200
    39.498     2.328     0.200
    38.198     2.475     0.200
    38.298     2.570     0.200
    43.498     2.648     0.200
    44.498     2.690     0.200
    41.498     2.824     0.200
    45.498     2.934     0.200
    47.298     3.057     0.200
    49.498     3.247     0.200
    53.498     3.282     0.200
    47.498     3.258     0.200
    63.498     4.215     0.200
    84.398     5.759     0.200
    92.898     6.210     0.200
   100.698     6.977     0.200
    12.146     0.604     0.200
    13.245     0.628     0.200
    16.146     0.832     0.200
    18.445     1.005     0.200
    17.146     0.967     0.200
    18.146     1.015     0.200
    23.146     1.330     0.200
    23.445     1.528     0.200
    26.146     1.560     0.200
    28.146     1.628     0.200
    27.146     1.711     0.200
    28.146     1.855     0.200
    30.146     1.982     0.200
    35.146     2.183     0.200
    35.146     2.180     0.200
    38.346     2.232     0.200
    34.146     2.338     0.200
    41.146     2.356     0.200
    41.146     2.427     0.200
    38.546     2.489     0.200
    42.146     2.497     0.200
    40.146     2.639     0.200
    45.146     2.697     0.200
    45.146     2.943     0.200
    45.146     2.959     0.200
    47.445     3.064     0.200
    47.146     3.039     0.200
    48.146     3.180     0.200
    50.146     3.253     0.200
    48.146     3.276     0.200
    63.146     4.178     0.200
    63.146     4.225     0.200
    70.146     4.655     0.200
    73.146     5.014     0.200
    74.146     5.025     0.200
    77.146     5.199     0.200
    77.146     5.269     0.200
    85.146     5.763     0.200
    87.146     5.899     0.200
    92.046     6.220     0.200
    96.146     6.420     0.200
   101.846     6.987     0.200
   139.146     9.764     0.200
     7.516     0.183     0.200
    12.215     0.617     0.200
    12.414     0.635     0.200
    16.215     0.807     0.200
    17.215     0.955     0.200
    17.816     1.000     0.200
    19.113     1.038     0.200
    21.316     1.232     0.200
    23.215     1.351     0.200
    25.215     1.488     0.200
    23.613     1.515     0.200
    26.215     1.585     0.200
    30.215     1.613     0.200
    27.215     1.686     0.200
    29.215     1.715     0.200
    28.215     1.864     0.200
    34.215     1.981     0.200
    35.215     2.184     0.200
    35.215     2.203     0.200
    37.215     2.250     0.200
    38.516     2.487     0.200
    38.613     2.582     0.200
    44.215     2.651     0.200
    46.215     3.067     0.200
    54.215     3.279     0.200
    57.215     3.750     0.200
    63.215     4.226     0.200
    84.516     5.768     0.200
    89.613     6.138     0.200
    91.516     6.221     0.200
    96.715     6.703     0.200
   100.316     6.988     0.200
     7.305     0.169     0.200
    13.406     0.634     0.200
    15.004     0.788     0.200
    18.105     0.940     0.200
    16.805     1.001     0.200
    20.305     1.173     0.200
    23.305     1.365     0.200
    25.105     1.484     0.200
    23.203     1.510     0.200
    29.105     1.595     0.200
    26.805     1.609     0.200
    27.105     1.694     0.200
    25.703     1.667     0.200
    29.703     1.878     0.200
    38.805     2.270     0.200
    38.305     2.345     0.200
    39.203     2.586     0.200
    43.105     2.668     0.200
    42.004     2.836     0.200
    49.004     3.187     0.200
    50.105     3.265     0.200
    48.105     3.273     0.200
    56.504     3.759     0.200
    58.305     3.843     0.200
    63.305     4.233     0.200
    72.305     4.656     0.200
    73.105     5.022     0.200
    76.805     5.271     0.200
    84.406     5.778     0.200
    89.004     6.144     0.200
    91.203     6.228     0.200
   101.105     6.994     0.200
     6.845     0.130     0.200
    14.044     0.654     0.200
    15.345     0.718     0.200
    14.444     0.690     0.200
    16.444     0.898     0.200
    17.845     1.004     0.200
    19.544     1.137     0.200
    22.145     1.325     0.200
    23.944     1.422     0.200
    24.444     1.481     0.200
    23.444     1.489     0.200
    28.944     1.541     0.200
    27.544     1.688     0.200
    28.345     1.730     0.200
    29.544     1.759     0.200
    30.145     1.922     0.200
    32.944     1.998     0.200
    34.944     2.185     0.200
    37.744     2.293     0.200
    37.944     2.335     0.200
    38.544     2.362     0.200
    38.744     2.592     0.200
    43.744     2.719     0.200
    47.244     3.068     0.200
    48.744     3.203     0.200
    47.944     3.272     0.200
    50.444     3.289     0.200
    50.544     3.334     0.200
    59.244     3.723     0.200
    56.944     3.783     0.200
    58.944     3.874     0.200
    63.444     4.211     0.200
    63.145     4.249     0.200
    72.444     4.661     0.200
    74.544     5.039     0.200
    84.845     5.806     0.200
    95.944     6.446     0.200
     7.266     0.180     0.200
    12.164     0.605     0.200
    14.859     0.727     0.200
    13.961     0.745     0.200
    16.164     0.853     0.200
    17.562     1.055     0.200
    19.461     1.154     0.200
    22.062     1.348     0.200
    22.562     1.387     0.200
    29.062     1.503     0.200
    27.359     1.684     0.200
    27.961     1.695     0.200
    27.859     1.710     0.200
    30.859     1.735     0.200
    27.562     1.803     0.200
    31.266     1.965     0.200
    34.664     2.049     0.200
    33.859     2.134     0.200
    37.664     2.320     0.200
    37.664     2.365     0.200
    39.359     2.412     0.200
    39.562     2.643     0.200
    44.664     2.759     0.200
    48.062     3.021     0.200
    49.266     3.095     0.200
    47.859     3.147     0.200
    50.961     3.338     0.200
    64.461     4.300     0.200
    86.062     5.854     0.200
    10.653     0.281     0.200
    11.553     0.455     0.200
    14.053     0.647     0.200
    14.853     0.728     0.200
    17.753     0.993     0.200
    17.653     0.952     0.200
    22.453     1.289     0.200
    22.253     1.362     0.200
    23.353     1.359     0.200
    24.353     1.443     0.200
    27.853     1.622     0.200
    27.553     1.662     0.200
    29.653     1.849     0.200
    33.653     2.082     0.200
    45.353     2.824     0.200
    47.253     3.185     0.200
    51.753     3.324     0.200
    48.953     3.351     0.200
    55.553     3.717     0.200
    93.553     6.428     0.200
    98.153     6.758     0.200
    99.753     6.855     0.200
     9.516     0.395     0.200
    11.812     0.500     0.200
    14.312     0.642     0.200
    15.516     0.819     0.200
    17.219     1.001     0.200
    19.117     1.027     0.200
    18.617     1.041     0.200
    19.516     1.105     0.200
    19.914     1.194     0.200
    23.219     1.351     0.200
    25.516     1.517     0.200
    26.312     1.595     0.200
    27.516     1.655     0.200
    27.719     1.688     0.200
    32.914     1.783     0.200
    32.516     2.006     0.200
    36.117     2.067     0.200
    42.617     2.477     0.200
    38.516     2.513     0.200
    38.914     2.578     0.200
    43.914     2.781     0.200
    63.117     4.191     0.200
    83.617     5.697     0.200
    89.414     6.115     0.200
    90.516     6.183     0.200
   101.312     6.952     0.200
     8.328     0.190     0.200
    11.328     0.545     0.200
    12.127     0.600     0.200
    14.328     0.804     0.200
    15.828     0.838     0.200
    18.627     0.954     0.200
    20.928     1.191     0.200
    21.928     1.351     0.200
    21.828     1.360     0.200
    21.727     1.366     0.200
    24.027     1.412     0.200
    23.727     1.439     0.200
    28.727     1.730     0.200
    31.027     1.775     0.200
    30.027     1.827     0.200
    29.627     1.834     0.200
    31.527     1.961     0.200
    32.928     2.023     0.200
    37.027     2.082     0.200
    35.227     2.196     0.200
    34.527     2.310     0.200
    39.027     2.610     0.200
    39.328     2.687     0.200
    43.727     2.878     0.200
    44.027     2.897     0.200
    52.027     3.387     0.200
    52.627     3.402     0.200
    58.828     3.892     0.200
    79.428     5.384     0.200
    83.627     5.746     0.200
    86.027     5.881     0.200
    95.828     6.652     0.200
     9.711     0.401     0.200
    11.609     0.475     0.200
    15.211     0.798     0.200
    17.305     0.984     0.200
    17.609     1.024     0.200
    18.906     1.032     0.200
    20.609     1.130     0.200
    20.609     1.205     0.200
    23.008     1.335     0.200
    26.008     1.542     0.200
    26.305     1.618     0.200
    26.406     1.612     0.200
    25.609     1.630     0.200
    27.805     1.709     0.200
    28.008     1.732     0.200
    33.008     1.807     0.200
    32.109     1.950     0.200
    31.906     1.983     0.200
    34.211     2.043     0.200
    36.609     2.289     0.200
    39.508     2.464     0.200
    39.406     2.487     0.200
    38.305     2.557     0.200
    45.805     2.994     0.200
    48.008     3.127     0.200
    62.609     4.167     0.200
    63.711     4.274     0.200
    83.711     5.672     0.200
    87.305     6.014     0.200
    88.805     6.092     0.200
    90.008     6.159     0.200
    99.508     6.929     0.200
   204.008    14.442     0.200
    23.299     1.362     0.200
    23.899     1.495     0.200
    28.899     1.705     0.200
    27.699     1.722     0.200
    30.399     1.869     0.200
    40.600     2.533     0.200
    41.899     2.576     0.200
    42.399     2.739     0.200
    62.199     3.890     0.200
    14.035     0.616     0.200
    15.535     0.699     0.200
    14.635     0.617     0.200
    16.135     0.752     0.200
    16.934     0.921     0.200
    16.834     0.869     0.200
    22.334     1.256     0.200
    22.535     1.299     0.200
    23.934     1.407     0.200
    22.035     1.282     0.200
    23.434     1.385     0.200
    25.734     1.515     0.200
    26.434     1.566     0.200
    30.334     1.848     0.200
    28.135     1.740     0.200
    27.535     1.765     0.200
    29.434     1.821     0.200
    27.934     1.783     0.200
    29.234     1.883     0.200
    33.834     1.985     0.200
    33.734     2.127     0.200
    33.635     2.121     0.200
    35.734     2.308     0.200
    37.135     2.395     0.200
    38.834     2.445     0.200
    37.234     2.431     0.200
    38.934     2.460     0.200
    40.234     2.606     0.200
    39.434     2.584     0.200
    40.635     2.626     0.200
    44.334     2.925     0.200
    43.934     2.849     0.200
    44.734     3.003     0.200
    46.434     3.096     0.200
    46.035     3.097     0.200
    49.734     3.220     0.200
    46.135     3.131     0.200
    47.635     3.203     0.200
    49.135     3.253     0.200
    49.734     3.270     0.200
    50.734     3.462     0.200
    54.934     3.663     0.200
    56.234     3.755     0.200
    56.734     3.774     0.200
    56.434     3.807     0.200
    60.734     4.086     0.200
    62.834     4.195     0.200
    64.234     4.279     0.200
    69.334     4.639     0.200
    70.434     4.785     0.200
    72.035     4.864     0.200
    74.135     5.059     0.200
    75.734     5.101     0.200
    75.035     5.109     0.200
    78.135     5.310     0.200
    78.334     5.384     0.200
    80.934     5.456     0.200
    82.734     5.665     0.200
    83.895     5.724     0.200
    83.734     5.724     0.200
    85.734     5.768     0.200
    85.734     5.867     0.200
    84.734     5.782     0.200
    86.135     5.831     0.200
    86.734     5.890     0.200
    85.234     5.930     0.200
    86.135     5.950     0.200
    88.734     6.023     0.200
    89.535     6.122     0.200
    89.234     6.144     0.200
    87.734     6.143     0.200
    90.734     6.213     0.200
    91.234     6.258     0.200
    93.035     6.298     0.200
    95.734     6.451     0.200
    95.734     6.478     0.200
    95.635     6.529     0.200
    96.434     6.611     0.200
    99.234     6.614     0.200
    98.834     6.829     0.200
   101.334     6.957     0.200
   101.135     7.030     0.200
   101.535     7.077     0.200
   107.734     7.359     0.200
   108.334     7.434     0.200
   106.434     7.484     0.200
   112.734     7.789     0.200
   114.135     7.875     0.200
   114.734     7.888     0.200
   114.834     8.016     0.200
   117.234     8.040     0.200
   118.434     8.123     0.200
   122.734     8.420     0.200
   123.334     8.535     0.200
   130.734     8.745     0.200
   128.535     8.728     0.200
   128.434     8.777     0.200
   130.734     9.028     0.200
   134.734     9.351     0.200
   137.334     9.365     0.200
   136.834     9.374     0.200
   136.734     9.439     0.200
   137.734     9.568     0.200
   142.334     9.847     0.200
   146.934    10.085     0.200
   153.334    10.525     0.200
   159.035    11.008     0.200
   158.234    11.039     0.200
   158.734    11.190     0.200
   159.734    11.221     0.200
   168.734    11.728     0.200
   169.434    11.855     0.200
   169.035    12.011     0.200
   179.734    12.574     0.200
   178.035    12.601     0.200
   180.734    12.764     0.200
   183.734    13.129     0.200
   183.734    13.290     0.200
   196.734    14.108     0.200
   212.734    15.333     0.200
   212.934    15.412     0.200
   254.734    18.765     0.200
   262.734    19.478     0.200
    16.789     0.907     0.200
    18.891     1.016     0.200
    19.594     1.057     0.200
    26.891     1.593     0.200
    28.391     1.683     0.200
    28.289     1.746     0.200
    30.992     1.885     0.200
    33.391     2.071     0.200
    33.992     2.108     0.200
    35.688     2.171     0.200
    37.594     2.392     0.200
    37.492     2.546     0.200
    58.391     3.863     0.200
    64.094     4.259     0.200
    83.391     5.728     0.200
    91.391     6.133     0.200
    91.391     6.247     0.200
    10.156     0.330     0.200
    12.559     0.516     0.200
    17.758     0.929     0.200
    16.957     0.944     0.200
    18.156     0.994     0.200
    19.957     1.081     0.200
    19.457     1.120     0.200
    20.758     1.180     0.200
    21.359     1.208     0.200
    20.758     1.203     0.200
    23.156     1.385     0.200
    24.059     1.440     0.200
    25.656     1.509     0.200
    25.758     1.544     0.200
    27.258     1.603     0.200
    27.957     1.605     0.200
    26.359     1.643     0.200
    25.758     1.653     0.200
    28.559     1.793     0.200
    30.758     1.916     0.200
    33.059     2.076     0.200
    32.859     2.084     0.200
    33.156     2.072     0.200
    35.059     2.184     0.200
    36.758     2.306     0.200
    36.758     2.435     0.200
    39.758     2.462     0.200
    38.758     2.503     0.200
    38.758     2.562     0.200
    40.957     2.599     0.200
    42.156     2.683     0.200
    41.957     2.694     0.200
    43.957     2.935     0.200
    43.457     2.970     0.200
    44.758     3.036     0.200
    46.758     3.042     0.200
    46.758     3.114     0.200
    49.758     3.276     0.200
    50.758     3.340     0.200
    50.758     3.349     0.200
    49.758     3.388     0.200
    56.559     3.783     0.200
    57.758     3.808     0.200
    57.559     3.833     0.200
    63.758     4.245     0.200
    63.656     4.266     0.200
    64.359     4.319     0.200
    66.758     4.505     0.200
    68.758     4.657     0.200
    70.758     4.761     0.200
    71.758     4.814     0.200
    71.758     4.854     0.200
    73.758     4.986     0.200
    74.957     5.108     0.200
    75.059     5.153     0.200
    78.758     5.373     0.200
    82.758     5.533     0.200
    82.859     5.591     0.200
    82.758     5.709     0.200
    85.758     5.843     0.200
    86.758     5.896     0.200
    85.156     5.907     0.200
    86.758     5.935     0.200
    89.059     6.156     0.200
    89.957     6.185     0.200
    90.258     6.238     0.200
    91.758     6.313     0.200
    93.758     6.384     0.200
    98.758     6.484     0.200
    96.758     6.513     0.200
    98.656     6.752     0.200
    99.359     6.812     0.200
   101.258     7.082     0.200
   101.758     7.127     0.200
   104.258     7.167     0.200
   110.258     7.539     0.200
   126.758     8.745     0.200
   137.758     9.518     0.200
   136.758     9.613     0.200
   161.359    11.331     0.200
   167.457    11.664     0.200
   179.359    12.719     0.200
   203.758    14.468     0.200
   201.258    14.561     0.200
   214.559    15.425     0.200
   215.758    15.746     0.200
   216.359    15.746     0.200
   235.758    16.899     0.200
   259.156    19.107     0.200
   267.758    19.895     0.200
    11.242     0.439     0.200
    11.742     0.479     0.200
    13.945     0.662     0.200
    17.047     0.930     0.200
    18.141     0.969     0.200
    18.547     1.068     0.200
    19.141     1.097     0.200
    19.844     1.058     0.200
    20.344     1.157     0.200
    19.844     1.185     0.200
    23.445     1.355     0.200
    24.344     1.421     0.200
    23.844     1.432     0.200
    24.445     1.459     0.200
    25.844     1.537     0.200
    30.844     1.653     0.200
    26.945     1.685     0.200
    27.242     1.737     0.200
    30.141     1.799     0.200
    32.445     2.043     0.200
    32.742     2.028     0.200
    37.844     2.328     0.200
    38.242     2.473     0.200
    38.742     2.504     0.200
    43.844     2.666     0.200
    41.742     2.678     0.200
    45.141     2.984     0.200
    44.742     3.044     0.200
    48.547     3.181     0.200
    50.141     3.312     0.200
    50.641     3.445     0.200
    56.945     3.797     0.200
    57.945     3.857     0.200
    67.047     4.572     0.200
    69.641     4.721     0.200
    71.945     4.869     0.200
    72.242     4.913     0.200
    74.445     5.001     0.200
    75.945     5.186     0.200
    85.742     5.860     0.200
    91.242     6.215     0.200
    93.547     6.345     0.200
    99.047     6.763     0.200
   155.242    10.740     0.200
   155.242    10.797     0.200
   161.844    11.260     0.200
   166.445    11.555     0.200
   179.344    12.622     0.200
   201.344    14.359     0.200
   258.844    19.000     0.200
   263.344    19.297     0.200
    10.043     0.455     0.200
    15.344     0.836     0.200
    16.145     0.872     0.200
    16.344     0.867     0.200
    17.344     0.983     0.200
    21.945     1.267     0.200
    23.445     1.377     0.200
    21.945     1.372     0.200
    24.645     1.443     0.200
    24.645     1.467     0.200
    25.645     1.543     0.200
    26.445     1.579     0.200
    25.543     1.581     0.200
    27.145     1.672     0.200
    27.145     1.670     0.200
    27.246     1.676     0.200
    28.645     1.811     0.200
    31.445     1.923     0.200
    31.145     1.931     0.200
    31.543     1.960     0.200
    31.645     1.946     0.200
    31.746     1.987     0.200
    31.645     2.006     0.200
    31.445     2.009     0.200
    31.645     2.024     0.200
    36.645     2.235     0.200
    35.746     2.291     0.200
    35.445     2.297     0.200
    36.043     2.315     0.200
    37.645     2.364     0.200
    39.145     2.495     0.200
    38.645     2.491     0.200
    40.246     2.539     0.200
    41.746     2.710     0.200
    40.145     2.711     0.200
    42.246     2.801     0.200
    43.645     2.847     0.200
    43.746     2.854     0.200
    44.844     2.992     0.200
    44.645     2.976     0.200
    45.645     3.036     0.200
    47.844     3.169     0.200
    48.645     3.149     0.200
    50.445     3.199     0.200
    48.344     3.209     0.200
    49.145     3.267     0.200
    51.445     3.401     0.200
    57.344     3.700     0.200
    57.043     3.798     0.200
    57.445     3.804     0.200
    63.445     4.223     0.200
    64.645     4.243     0.200
    63.445     4.267     0.200
    66.145     4.294     0.200
    65.844     4.435     0.200
    68.645     4.614     0.200
    69.246     4.633     0.200
    68.746     4.650     0.200
    74.445     4.882     0.200
    73.246     4.965     0.200
    73.844     4.988     0.200
    73.645     5.031     0.200
    74.246     5.071     0.200
    76.746     5.234     0.200
    79.645     5.315     0.200
    77.746     5.339     0.200
    82.746     5.603     0.200
    82.645     5.623     0.200
    83.746     5.640     0.200
    83.645     5.684     0.200
    83.746     5.751     0.200
    84.543     5.787     0.200
    85.445     5.835     0.200
    86.645     5.897     0.200
    86.645     5.929     0.200
    87.945     6.034     0.200
    87.445     6.058     0.200
    89.344     6.115     0.200
    89.543     6.129     0.200
    92.645     6.235     0.200
    93.645     6.338     0.200
    92.645     6.376     0.200
    93.344     6.473     0.200
    96.645     6.439     0.200
    97.145     6.658     0.200
    98.445     6.762     0.200
    99.746     6.825     0.200
   100.645     6.995     0.200
   102.945     7.039     0.200
   108.645     7.213     0.200
   109.645     7.331     0.200
   108.145     7.362     0.200
   109.645     7.506     0.200
   115.844     7.980     0.200
   119.945     8.223     0.200
   122.746     8.382     0.200
   127.746     8.823     0.200
   131.645     9.050     0.200
   138.145     9.546     0.200
   138.043     9.565     0.200
   140.945     9.632     0.200
   141.645     9.849     0.200
   142.246     9.805     0.200
   150.543    10.394     0.200
   153.043    10.655     0.200
   158.145    10.948     0.200
   163.043    11.353     0.200
   163.043    11.409     0.200
   168.043    11.501     0.200
   166.945    11.570     0.200
   165.145    11.622     0.200
   170.145    11.841     0.200
   172.645    12.151     0.200
   175.945    12.187     0.200
   174.445    12.211     0.200
   177.645    12.398     0.200
   177.344    12.636     0.200
   187.645    13.030     0.200
   185.945    13.130     0.200
   187.844    13.215     0.200
   190.645    13.587     0.200
   197.645    13.661     0.200
   194.645    13.633     0.200
   200.344    14.309     0.200
   209.645    14.937     0.200
   221.645    15.962     0.200
   221.746    15.962     0.200
   254.645    18.514     0.200
   259.645    18.852     0.200
   267.645    19.749     0.200
   273.246    20.003     0.200
    10.367     0.419     0.200
     9.967     0.403     0.200
    14.467     0.722     0.200
    14.567     0.767     0.200
    17.367     0.968     0.200
    20.267     1.175     0.200
    20.367     1.177     0.200
    21.067     1.243     0.200
    20.567     1.250     0.200
    22.867     1.317     0.200
    23.467     1.450     0.200
    26.667     1.597     0.200
    27.167     1.661     0.200
    26.667     1.676     0.200
    26.967     1.672     0.200
    29.267     1.827     0.200
    32.567     1.877     0.200
    31.367     1.943     0.200
    35.567     2.234     0.200
    35.667     2.267     0.200
    35.967     2.275     0.200
    38.367     2.447     0.200
    39.867     2.628     0.200
    43.167     2.710     0.200
    41.667     2.751     0.200
    41.767     2.838     0.200
    44.867     2.939     0.200
    46.867     3.072     0.200
    49.467     3.179     0.200
    53.267     3.555     0.200
    66.567     4.501     0.200
    72.567     4.945     0.200
    76.867     5.260     0.200
    82.467     5.617     0.200
    87.667     5.973     0.200
    95.367     6.521     0.200
    10.133     0.485     0.200
    16.730     0.906     0.200
    20.332     1.118     0.200
    20.230     1.173     0.200
    21.531     1.241     0.200
    21.930     1.264     0.200
    24.730     1.448     0.200
    23.633     1.479     0.200
    26.133     1.533     0.200
    27.133     1.622     0.200
    28.430     1.777     0.200
    29.031     1.798     0.200
    29.031     1.800     0.200
    29.031     1.793     0.200
    29.531     1.822     0.200
    31.531     1.935     0.200
    32.230     1.987     0.200
    32.531     2.083     0.200
    35.531     2.182     0.200
    35.332     2.240     0.200
    35.031     2.239     0.200
    38.332     2.478     0.200
    40.230     2.547     0.200
    39.832     2.564     0.200
    43.633     2.751     0.200
    41.430     2.806     0.200
    44.531     2.956     0.200
    46.430     3.069     0.200
    48.133     3.092     0.200
    50.531     3.303     0.200
    49.930     3.341     0.200
    52.230     3.373     0.200
    54.633     3.613     0.200
    60.430     3.991     0.200
    60.730     4.000     0.200
    64.832     4.363     0.200
    67.730     4.540     0.200
    71.133     4.756     0.200
    70.531     4.762     0.200
    76.930     5.183     0.200
    77.531     5.236     0.200
    80.832     5.489     0.200
    85.930     5.799     0.200
    85.531     5.884     0.200
    86.832     5.923     0.200
    88.230     6.025     0.200
    88.730     6.116     0.200
    90.430     6.180     0.200
    92.930     6.281     0.200
    92.832     6.283     0.200
    95.133     6.398     0.200
   102.230     7.197     0.200
   271.531    19.749     0.200
     9.430     0.339     0.200
    11.633     0.518     0.200
    13.336     0.635     0.200
    17.633     0.971     0.200
    18.133     1.023     0.200
    18.633     1.068     0.200
    18.836     1.076     0.200
    20.234     1.184     0.200
    20.836     1.233     0.200
    21.133     1.239     0.200
    23.930     1.408     0.200
    24.633     1.524     0.200
    25.430     1.510     0.200
    25.734     1.581     0.200
    25.734     1.574     0.200
    26.531     1.618     0.200
    26.633     1.663     0.200
    27.930     1.700     0.200
    31.633     1.742     0.200
    27.633     1.765     0.200
    29.836     1.767     0.200
    28.133     1.776     0.200
    30.930     1.937     0.200
    30.633     1.968     0.200
    32.930     2.052     0.200
    34.336     2.189     0.200
    36.836     2.313     0.200
    35.836     2.369     0.200
    39.836     2.554     0.200
    39.734     2.600     0.200
    39.430     2.609     0.200
    43.133     2.821     0.200
    42.930     2.827     0.200
    42.336     2.883     0.200
    44.633     2.911     0.200
    45.734     2.992     0.200
    47.234     3.070     0.200
    48.133     3.153     0.200
    47.734     3.213     0.200
    48.430     3.282     0.200
    54.836     3.649     0.200
    55.430     3.689     0.200
    56.031     3.704     0.200
    62.133     4.138     0.200
    64.734     4.409     0.200
    67.031     4.558     0.200
    69.430     4.647     0.200
    69.734     4.706     0.200
    70.031     4.750     0.200
    72.133     4.853     0.200
    73.531     5.028     0.200
    77.633     5.338     0.200
    79.531     5.393     0.200
    80.836     5.457     0.200
    83.836     5.710     0.200
    83.930     5.793     0.200
    84.430     5.820     0.200
    88.836     6.058     0.200
    93.734     6.255     0.200
    96.531     6.617     0.200
    99.930     7.003     0.200
   140.633     9.718     0.200
   166.633    11.599     0.200
   181.336    12.769     0.200
   250.031    18.069     0.200
   259.633    19.129     0.200
   263.633    19.452     0.200
     8.477     0.300     0.200
    10.375     0.445     0.200
    13.977     0.696     0.200
    14.477     0.763     0.200
    16.074     0.841     0.200
    15.777     0.878     0.200
    15.676     0.885     0.200
    17.875     1.043     0.200
    20.875     1.234     0.200
    21.875     1.270     0.200
    21.977     1.288     0.200
    21.875     1.318     0.200
    22.375     1.326     0.200
    22.176     1.338     0.200
    23.676     1.457     0.200
    23.074     1.477     0.200
    24.676     1.546     0.200
    24.977     1.557     0.200
    28.277     1.716     0.200
    27.777     1.719     0.200
    28.574     1.759     0.200
    28.676     1.792     0.200
    31.977     1.785     0.200
    30.074     1.848     0.200
    30.176     1.871     0.200
    33.676     1.958     0.200
    32.777     1.983     0.200
    33.777     2.120     0.200
    33.176     2.155     0.200
    39.676     2.298     0.200
    36.676     2.321     0.200
    36.375     2.332     0.200
    37.074     2.383     0.200
    40.176     2.624     0.200
    40.875     2.641     0.200
    40.977     2.706     0.200
    40.574     2.745     0.200
    42.977     2.796     0.200
    44.074     2.818     0.200
    42.676     2.821     0.200
    45.074     2.956     0.200
    44.777     2.995     0.200
    46.676     3.112     0.200
    50.676     3.281     0.200
    51.176     3.422     0.200
    51.375     3.435     0.200
    53.176     3.496     0.200
    54.676     3.498     0.200
    67.676     4.583     0.200
    70.277     4.828     0.200
    75.977     5.145     0.200
    81.074     5.497     0.200
    86.676     5.855     0.200
    94.074     6.402     0.200
   110.777     7.598     0.200
   115.277     7.846     0.200
   117.777     7.960     0.200
   121.176     8.385     0.200
   143.176     9.892     0.200
   161.676    11.162     0.200
   166.676    11.509     0.200
   167.176    11.577     0.200
   182.477    12.859     0.200
   249.676    18.109     0.200
   260.277    19.176     0.200
   267.676    19.571     0.200
    11.227     0.469     0.200
    11.328     0.508     0.200
    11.125     0.492     0.200
    15.125     0.833     0.200
    19.328     1.083     0.200
    19.430     1.112     0.200
    20.828     1.149     0.200
    19.930     1.142     0.200
    20.930     1.174     0.200
    22.625     1.378     0.200
    22.828     1.379     0.200
    23.430     1.425     0.200
    25.227     1.503     0.200
    25.727     1.545     0.200
    25.430     1.545     0.200
    27.328     1.671     0.200
    27.625     1.808     0.200
    29.531     1.854     0.200
    32.328     1.883     0.200
    30.828     1.963     0.200
    31.430     1.950     0.200
    31.227     2.009     0.200
    35.531     2.318     0.200
    37.328     2.386     0.200
    38.227     2.473     0.200
    39.031     2.529     0.200
    41.531     2.647     0.200
    39.625     2.627     0.200
    43.328     2.755     0.200
    44.828     2.884     0.200
    47.727     3.128     0.200
    46.031     3.148     0.200
    48.328     3.215     0.200
    53.531     3.422     0.200
    52.328     3.433     0.200
    52.328     3.496     0.200
    55.828     3.741     0.200
    59.828     4.037     0.200
    62.625     4.157     0.200
    62.625     4.183     0.200
    79.328     5.356     0.200
    80.727     5.472     0.200
    87.531     5.966     0.200
    89.625     6.174     0.200
    90.031     6.208     0.200
    90.727     6.208     0.200
    96.031     6.513     0.200
   136.031     9.412     0.200
   162.125    11.186     0.200
   171.727    12.016     0.200
   181.328    12.734     0.200
   205.328    14.600     0.200
   231.727    16.703     0.200
   263.328    19.210     0.200
     9.863     0.422     0.200
    11.965     0.578     0.200
    12.164     0.571     0.200
    14.664     0.792     0.200
    18.664     1.046     0.200
    19.266     1.071     0.200
    19.266     1.090     0.200
    20.164     1.153     0.200
    24.062     1.487     0.200
    24.965     1.543     0.200
    25.664     1.553     0.200
    26.465     1.619     0.200
    27.363     1.665     0.200
    29.664     1.863     0.200
    30.664     1.908     0.200
    31.465     2.021     0.200
    33.766     2.079     0.200
    37.062     2.361     0.200
    36.863     2.403     0.200
    40.664     2.637     0.200
    40.766     2.707     0.200
    43.465     2.764     0.200
    43.863     2.809     0.200
    46.164     2.958     0.200
    46.266     3.156     0.200
    48.766     3.224     0.200
    48.664     3.254     0.200
    53.363     3.484     0.200
    53.664     3.556     0.200
    55.965     3.646     0.200
    54.164     3.662     0.200
    63.363     4.227     0.200
    63.562     4.244     0.200
    80.965     5.521     0.200
    84.562     5.792     0.200
    90.062     6.205     0.200
    91.164     6.273     0.200
    96.266     6.564     0.200
   174.664    12.141     0.200
   207.664    14.686     0.200
   264.863    19.290     0.200
     8.789     0.341     0.200
     9.390     0.360     0.200
    15.590     0.806     0.200
    15.689     0.830     0.200
    15.590     0.864     0.200
    15.890     0.864     0.200
    15.689     0.944     0.200
    17.689     0.977     0.200
    21.090     1.211     0.200
    21.689     1.288     0.200
    22.090     1.354     0.200
    22.489     1.358     0.200
    22.890     1.366     0.200
    23.090     1.373     0.200
    23.489     1.438     0.200
    26.689     1.494     0.200
    25.689     1.614     0.200
    27.989     1.680     0.200
    28.090     1.741     0.200
    28.590     1.772     0.200
    28.989     1.805     0.200
    29.689     1.865     0.200
    33.289     1.899     0.200
    31.989     1.945     0.200
    32.890     2.049     0.200
    34.489     2.143     0.200
    36.189     2.202     0.200
    37.289     2.359     0.200
    37.590     2.405     0.200
    40.590     2.652     0.200
    40.090     2.727     0.200
    44.090     2.735     0.200
    41.090     2.743     0.200
    43.789     2.821     0.200
    43.689     2.855     0.200
    45.989     2.982     0.200
    46.689     3.115     0.200
    49.390     3.193     0.200
    51.390     3.444     0.200
    52.789     3.482     0.200
    62.590     4.248     0.200
    65.289     4.394     0.200
    68.289     4.513     0.200
    67.289     4.539     0.200
    67.590     4.584     0.200
    71.789     4.858     0.200
    78.590     5.114     0.200
    75.590     5.167     0.200
    81.390     5.543     0.200
    79.989     5.602     0.200
    86.789     5.888     0.200
   205.689    14.581     0.200
    12.139     0.468     0.200
    11.238     0.429     0.200
    14.238     0.675     0.200
    18.338     0.950     0.200
    17.738     0.987     0.200
    19.038     1.045     0.200
    18.938     1.080     0.200
    18.738     1.044     0.200
    19.238     1.105     0.200
    19.139     1.110     0.200
    21.139     1.176     0.200
    20.238     1.189     0.200
    23.238     1.344     0.200
    23.738     1.417     0.200
    24.438     1.460     0.200
    24.438     1.442     0.200
    25.738     1.533     0.200
    29.738     1.634     0.200
    28.639     1.659     0.200
    28.438     1.710     0.200
    26.938     1.693     0.200
    26.738     1.736     0.200
    30.738     1.919     0.200
    30.538     1.931     0.200
    32.538     2.020     0.200
    32.938     2.061     0.200
    34.738     2.151     0.200
    32.738     2.137     0.200
    37.738     2.311     0.200
    37.838     2.468     0.200
    39.139     2.485     0.200
    38.038     2.482     0.200
    39.139     2.530     0.200
    44.738     2.682     0.200
    42.038     2.695     0.200
    44.438     2.923     0.200
    46.738     2.968     0.200
    45.338     2.991     0.200
    44.738     3.046     0.200
    47.738     3.192     0.200
    50.438     3.321     0.200
    49.838     3.370     0.200
    51.038     3.450     0.200
    56.038     3.783     0.200
    57.139     3.810     0.200
    58.338     3.869     0.200
    64.938     4.304     0.200
    69.838     4.725     0.200
    70.438     4.852     0.200
    71.338     4.875     0.200
    74.538     5.014     0.200
    80.038     5.507     0.200
    83.338     5.617     0.200
    86.038     5.872     0.200
    91.438     6.225     0.200
    97.238     6.562     0.200
   102.738     7.170     0.200
   111.438     7.558     0.200
   116.139     7.972     0.200
   115.238     7.977     0.200
   126.838     8.755     0.200
   138.139     9.538     0.200
   138.738     9.560     0.200
   161.738    11.258     0.200
   166.738    11.573     0.200
   247.538    17.952     0.200
   259.338    19.008     0.200
   260.238    19.298     0.200
     9.578     0.365     0.200
    11.281     0.503     0.200
    13.281     0.643     0.200
    16.180     0.877     0.200
    16.781     0.926     0.200
    18.281     0.998     0.200
    18.477     1.027     0.200
    19.078     1.090     0.200
    19.680     1.164     0.200
    21.383     1.220     0.200
    20.281     1.217     0.200
    20.680     1.224     0.200
    23.578     1.378     0.200
    25.383     1.518     0.200
    24.383     1.520     0.200
    25.781     1.588     0.200
    24.781     1.590     0.200
    26.180     1.611     0.200
    27.180     1.654     0.200
    28.180     1.699     0.200
    28.180     1.750     0.200
    27.781     1.761     0.200
    29.977     1.791     0.200
    30.477     1.885     0.200
    30.477     1.914     0.200
    32.180     1.965     0.200
    32.578     2.026     0.200
    34.477     2.194     0.200
    35.977     2.307     0.200
    37.578     2.357     0.200
    39.180     2.466     0.200
    39.180     2.479     0.200
    39.180     2.523     0.200
    39.680     2.535     0.200
    39.281     2.596     0.200
    40.180     2.623     0.200
    42.180     2.650     0.200
    44.078     2.801     0.200
    42.883     2.819     0.200
    42.477     2.888     0.200
    45.578     2.986     0.200
    45.180     3.017     0.200
    48.883     3.094     0.200
    47.680     3.146     0.200
    47.680     3.199     0.200
    49.180     3.202     0.200
    48.383     3.281     0.200
    53.477     3.609     0.200
    54.977     3.637     0.200
    55.680     3.694     0.200
    61.680     4.094     0.200
    62.281     4.129     0.200
    62.180     4.188     0.200
    64.883     4.412     0.200
    66.883     4.560     0.200
    72.680     4.665     0.200
    69.680     4.679     0.200
    69.977     4.705     0.200
    69.977     4.750     0.200
    71.977     4.841     0.200
    73.180     4.975     0.200
    73.578     5.021     0.200
    77.383     5.279     0.200
    77.883     5.332     0.200
    79.180     5.375     0.200
    80.180     5.444     0.200
    80.977     5.444     0.200
    83.477     5.699     0.200
    83.180     5.750     0.200
    83.578     5.768     0.200
    89.180     6.050     0.200
    93.883     6.387     0.200
    96.180     6.604     0.200
    96.883     6.604     0.200
   107.680     7.384     0.200
   113.180     7.801     0.200
   113.781     7.801     0.200
   118.680     8.050     0.200
   135.180     9.367     0.200
   135.680     9.367     0.200
   139.180     9.719     0.200
   143.078     9.744     0.200
   145.078     9.920     0.200
   147.281    10.150     0.200
   156.383    10.789     0.200
   164.977    11.420     0.200
   181.383    12.755     0.200
   203.180    14.463     0.200
   218.180    15.584     0.200
   250.383    18.050     0.200
   261.180    19.111     0.200
   263.578    19.443     0.200
   266.180    19.641     0.200
     9.664     0.366     0.200
    11.469     0.502     0.200
    13.469     0.644     0.200
    17.266     0.876     0.200
    16.969     0.924     0.200
    17.266     0.998     0.200
    18.266     1.026     0.200
    19.164     1.049     0.200
    19.164     1.092     0.200
    20.062     1.164     0.200
    20.664     1.218     0.200
    20.969     1.224     0.200
    23.469     1.377     0.200
    25.664     1.520     0.200
    24.469     1.519     0.200
    25.164     1.590     0.200
    25.867     1.589     0.200
    26.469     1.612     0.200
    29.266     1.652     0.200
    28.266     1.700     0.200
    27.266     1.748     0.200
    31.266     1.768     0.200
    27.766     1.759     0.200
    30.664     1.886     0.200
    30.469     1.913     0.200
    32.664     2.024     0.200
    34.367     2.195     0.200
    36.164     2.306     0.200
    37.562     2.355     0.200
    39.562     2.533     0.200
    39.367     2.596     0.200
    42.367     2.625     0.200
    42.969     2.818     0.200
    42.367     2.887     0.200
    45.766     2.984     0.200
    48.867     3.096     0.200
    48.062     3.145     0.200
    48.062     3.198     0.200
    49.266     3.280     0.200
    54.664     3.635     0.200
    55.766     3.693     0.200
    70.266     4.677     0.200
    70.766     4.839     0.200
    73.062     5.020     0.200
    77.969     5.331     0.200
    83.664     5.697     0.200
    88.367     6.049     0.200
    96.867     6.603     0.200
     6.895     0.126     0.200
     6.795     0.159     0.200
    11.595     0.536     0.200
    14.095     0.749     0.200
    14.495     0.762     0.200
    15.895     0.873     0.200
    19.695     1.056     0.200
    19.295     1.046     0.200
    18.995     1.079     0.200
    22.695     1.302     0.200
    22.095     1.392     0.200
    23.295     1.411     0.200
    23.195     1.422     0.200
    23.695     1.452     0.200
    23.995     1.457     0.200
    26.695     1.613     0.200
    26.295     1.586     0.200
    25.995     1.601     0.200
    26.695     1.639     0.200
    28.895     1.699     0.200
    28.795     1.724     0.200
    27.895     1.747     0.200
    29.295     1.806     0.200
    30.295     1.860     0.200
    29.895     1.856     0.200
    31.995     1.991     0.200
    31.395     1.995     0.200
    34.395     2.151     0.200
    34.095     2.216     0.200
    36.695     2.311     0.200
    35.195     2.322     0.200
    36.895     2.370     0.200
    38.895     2.447     0.200
    39.195     2.561     0.200
    39.895     2.562     0.200
    39.795     2.571     0.200
    40.895     2.581     0.200
    40.695     2.700     0.200
    39.895     2.713     0.200
    42.895     2.820     0.200
    42.895     2.845     0.200
    44.795     2.896     0.200
    44.895     2.947     0.200
    47.195     3.005     0.200
    46.795     3.058     0.200
    47.895     3.138     0.200
    47.295     3.144     0.200
    48.695     3.173     0.200
    47.495     3.178     0.200
    52.395     3.510     0.200
    55.895     3.597     0.200
    53.795     3.598     0.200
    55.195     3.632     0.200
    60.895     4.061     0.200
    63.895     4.074     0.200
    61.895     4.104     0.200
    62.695     4.252     0.200
    64.595     4.407     0.200
    67.095     4.568     0.200
    67.995     4.572     0.200
    68.295     4.606     0.200
    71.495     4.798     0.200
    72.495     4.936     0.200
    73.195     5.015     0.200
    76.195     5.230     0.200
    80.395     5.407     0.200
    81.995     5.648     0.200
    82.995     5.652     0.200
    87.495     5.973     0.200
    95.895     6.568     0.200
    98.095     6.785     0.200
   100.095     6.910     0.200
   102.395     6.975     0.200
   104.295     7.142     0.200
   105.895     7.325     0.200
   113.295     7.776     0.200
   116.995     8.022     0.200
   119.795     8.157     0.200
   124.595     8.590     0.200
   127.195     8.740     0.200
   135.295     9.343     0.200
   135.995     9.363     0.200
   137.695     9.438     0.200
   141.095     9.728     0.200
   141.595     9.862     0.200
   144.895     9.862     0.200
   145.895     9.941     0.200
   156.195    10.701     0.200
   161.795    11.210     0.200
   167.495    11.589     0.200
   166.895    11.808     0.200
   175.295    12.388     0.200
   184.095    12.978     0.200
   186.895    13.308     0.200
   206.395    14.708     0.200
   235.895    16.917     0.200
   236.895    16.917     0.200
   250.895    18.294     0.200
   262.895    19.352     0.200
    10.172     0.375     0.200
    10.172     0.416     0.200
    15.770     0.795     0.200
    15.070     0.770     0.200
    15.672     0.834     0.200
    16.469     0.922     0.200
    17.570     0.953     0.200
    17.469     1.002     0.200
    21.969     1.208     0.200
    20.672     1.222     0.200
    21.570     1.294     0.200
    21.770     1.301     0.200
    22.672     1.325     0.200
    22.871     1.397     0.200
    23.371     1.348     0.200
    23.469     1.501     0.200
    24.871     1.526     0.200
    25.570     1.622     0.200
    26.172     1.633     0.200
    27.070     1.646     0.200
    27.371     1.716     0.200
    27.770     1.715     0.200
    28.969     1.799     0.200
    29.570     1.843     0.200
    30.070     1.815     0.200
    30.570     1.878     0.200
    33.172     1.903     0.200
    31.270     1.925     0.200
    32.270     2.011     0.200
    33.371     2.183     0.200
    33.672     2.229     0.200
    36.570     2.357     0.200
    36.270     2.318     0.200
    37.570     2.400     0.200
    37.770     2.412     0.200
    36.871     2.413     0.200
    40.570     2.523     0.200
    40.570     2.588     0.200
    40.570     2.698     0.200
    41.469     2.701     0.200
    40.469     2.680     0.200
    40.770     2.702     0.200
    41.570     2.760     0.200
    41.770     2.738     0.200
    43.469     2.778     0.200
    41.070     2.785     0.200
    44.070     2.861     0.200
    43.570     2.890     0.200
    46.371     3.021     0.200
    46.570     3.074     0.200
    45.469     3.071     0.200
    47.172     3.165     0.200
    47.469     3.158     0.200
    49.871     3.202     0.200
    51.871     3.485     0.200
    52.371     3.509     0.200
    54.070     3.566     0.200
    54.570     3.573     0.200
    58.570     3.966     0.200
    60.871     4.001     0.200
    60.570     4.062     0.200
    63.270     4.302     0.200
    65.371     4.447     0.200
    66.770     4.556     0.200
    70.570     4.556     0.200
    68.770     4.587     0.200
    68.570     4.605     0.200
    68.469     4.635     0.200
    69.672     4.712     0.200
    71.469     4.848     0.200
    71.172     4.895     0.200
    72.672     4.901     0.200
    72.270     4.998     0.200
    75.270     5.208     0.200
    79.270     5.316     0.200
    81.672     5.570     0.200
    81.469     5.647     0.200
    86.070     5.923     0.200
    91.969     6.260     0.200
    92.770     6.333     0.200
    94.770     6.476     0.200
    99.570     6.687     0.200
    99.070     6.798     0.200
    98.371     6.869     0.200
   102.770     6.991     0.200
   103.672     7.163     0.200
   105.672     7.256     0.200
   110.570     7.675     0.200
   111.672     7.673     0.200
   116.070     7.922     0.200
   117.570     8.037     0.200
   122.070     8.463     0.200
   126.070     8.648     0.200
   134.172     9.239     0.200
   134.371     9.261     0.200
   137.770     9.404     0.200
   137.871     9.616     0.200
   141.469     9.796     0.200
   142.570     9.836     0.200
   144.672     9.952     0.200
   153.070    10.541     0.200
   156.070    10.796     0.200
   160.172    11.033     0.200
   161.270    11.131     0.200
   160.570    11.220     0.200
   165.770    11.530     0.200
   165.969    11.551     0.200
   181.969    12.836     0.200
   204.570    14.515     0.200
   249.172    18.105     0.200
   260.070    19.169     0.200
     6.791     0.059     0.200
     9.391     0.385     0.200
    11.590     0.579     0.200
    12.090     0.600     0.200
    11.990     0.592     0.200
    14.391     0.767     0.200
    15.791     0.846     0.200
    17.891     1.001     0.200
    20.191     1.157     0.200
    20.391     1.239     0.200
    21.090     1.248     0.200
    22.891     1.352     0.200
    24.191     1.506     0.200
    25.490     1.555     0.200
    26.191     1.612     0.200
    27.291     1.678     0.200
    27.090     1.720     0.200
    31.691     1.973     0.200
    30.891     2.009     0.200
    32.090     2.004     0.200
    33.590     2.076     0.200
    33.291     2.110     0.200
    34.391     2.161     0.200
    35.191     2.219     0.200
    34.891     2.196     0.200
    34.891     2.245     0.200
    36.090     2.276     0.200
    36.590     2.376     0.200
    37.590     2.474     0.200
    39.191     2.470     0.200
    39.891     2.576     0.200
    40.490     2.626     0.200
    41.891     2.688     0.200
    40.291     2.680     0.200
    40.791     2.693     0.200
    41.691     2.731     0.200
    40.590     2.761     0.200
    44.191     2.749     0.200
    43.891     2.929     0.200
    44.691     2.931     0.200
    44.490     2.943     0.200
    46.291     3.015     0.200
    45.791     3.037     0.200
    47.191     3.078     0.200
    48.590     3.135     0.200
    47.490     3.194     0.200
    48.490     3.199     0.200
    52.691     3.521     0.200
    53.990     3.552     0.200
    54.490     3.623     0.200
    63.391     4.326     0.200
    71.391     4.590     0.200
    71.191     4.755     0.200
    72.391     4.933     0.200
    82.891     5.613     0.200
    12.131     0.569     0.200
    12.131     0.563     0.200
    13.832     0.706     0.200
    17.031     0.877     0.200
    16.932     0.945     0.200
    17.432     0.965     0.200
    19.131     1.090     0.200
    21.531     1.246     0.200
    21.432     1.244     0.200
    20.932     1.261     0.200
    25.131     1.452     0.200
    24.832     1.515     0.200
    25.230     1.488     0.200
    26.832     1.607     0.200
    27.332     1.659     0.200
    27.531     1.737     0.200
    28.131     1.738     0.200
    28.031     1.835     0.200
    30.531     1.921     0.200
    30.230     1.894     0.200
    31.730     1.966     0.200
    32.230     2.016     0.200
    32.631     2.079     0.200
    33.031     2.127     0.200
    34.031     2.200     0.200
    35.432     2.224     0.200
    36.131     2.331     0.200
    38.631     2.468     0.200
    39.631     2.609     0.200
    40.230     2.675     0.200
    43.131     2.774     0.200
    42.031     2.765     0.200
    43.631     2.930     0.200
    45.031     2.939     0.200
    47.531     3.094     0.200
    45.832     3.153     0.200
    48.631     3.238     0.200
    53.031     3.512     0.200
    54.832     3.638     0.200
    54.332     3.662     0.200
    53.832     3.613     0.200
    56.031     3.687     0.200
    55.730     3.708     0.200
    60.031     4.058     0.200
    62.730     4.205     0.200
    72.432     4.992     0.200
    75.432     5.107     0.200
    84.230     5.802     0.200
    91.832     6.222     0.200
   136.031     9.378     0.200
    11.117     0.476     0.200
    12.219     0.570     0.200
    12.516     0.595     0.200
    13.617     0.688     0.200
    15.117     0.761     0.200
    15.914     0.853     0.200
    19.617     1.084     0.200
    20.414     1.173     0.200
    20.820     1.211     0.200
    21.117     1.244     0.200
    21.719     1.264     0.200
    22.016     1.340     0.200
    26.117     1.526     0.200
    25.820     1.563     0.200
    24.414     1.570     0.200
    25.320     1.577     0.200
    26.219     1.593     0.200
    26.219     1.610     0.200
    28.617     1.821     0.200
    30.820     1.893     0.200
    32.117     1.996     0.200
    32.219     2.014     0.200
    32.414     2.026     0.200
    32.016     2.061     0.200
    33.516     2.123     0.200
    33.516     2.134     0.200
    34.617     2.188     0.200
    38.414     2.269     0.200
    36.414     2.306     0.200
    35.719     2.293     0.200
    39.219     2.535     0.200
    38.820     2.575     0.200
    38.820     2.566     0.200
    39.414     2.579     0.200
    40.320     2.590     0.200
    40.414     2.621     0.200
    42.820     2.673     0.200
    42.117     2.743     0.200
    43.016     2.825     0.200
    42.219     2.868     0.200
    43.719     2.886     0.200
    46.117     3.007     0.200
    45.820     3.016     0.200
    46.320     3.081     0.200
    46.516     3.089     0.200
    47.016     3.107     0.200
    47.320     3.140     0.200
    49.914     3.131     0.200
    49.719     3.376     0.200
    53.617     3.608     0.200
    54.219     3.614     0.200
    56.219     3.589     0.200
    55.719     3.700     0.200
    55.414     3.762     0.200
    61.820     4.165     0.200
    63.219     4.218     0.200
    63.914     4.271     0.200
    65.016     4.266     0.200
    65.914     4.440     0.200
    67.516     4.575     0.200
    70.617     4.680     0.200
    69.414     4.706     0.200
    72.219     4.935     0.200
    76.719     5.117     0.200
    74.719     5.121     0.200
    78.414     5.333     0.200
    82.016     5.507     0.200
    81.820     5.539     0.200
    83.219     5.654     0.200
    83.820     5.653     0.200
    83.117     5.681     0.200
    82.617     5.733     0.200
    84.719     5.819     0.200
    85.820     5.870     0.200
    88.219     5.947     0.200
    87.320     5.959     0.200
    86.219     5.996     0.200
    86.914     6.038     0.200
    97.219     6.528     0.200
   105.914     7.118     0.200
     8.004     0.183     0.200
    10.805     0.468     0.200
    11.805     0.539     0.200
    15.004     0.800     0.200
    16.105     0.851     0.200
    16.805     0.922     0.200
    19.906     1.159     0.200
    20.605     1.199     0.200
    21.105     1.285     0.200
    22.105     1.287     0.200
    21.605     1.286     0.200
    22.805     1.350     0.200
    24.105     1.448     0.200
    23.906     1.484     0.200
    23.906     1.539     0.200
    27.406     1.641     0.200
    27.406     1.679     0.200
    27.805     1.714     0.200
    27.504     1.763     0.200
    30.504     1.882     0.200
    30.703     1.957     0.200
    33.305     2.088     0.200
    34.105     2.134     0.200
    34.004     2.174     0.200
    35.406     2.227     0.200
    35.004     2.220     0.200
    40.203     2.384     0.200
    37.203     2.380     0.200
    37.805     2.438     0.200
    39.203     2.513     0.200
    37.906     2.517     0.200
    38.805     2.574     0.200
    39.504     2.601     0.200
    42.504     2.755     0.200
    41.605     2.823     0.200
    44.305     2.788     0.200
    44.305     2.919     0.200
    44.703     2.934     0.200
    45.105     2.983     0.200
    45.203     2.984     0.200
    46.004     3.041     0.200
    50.504     3.246     0.200
    48.906     3.308     0.200
    53.004     3.517     0.200
    52.305     3.530     0.200
    54.305     3.611     0.200
    54.406     3.693     0.200
    60.703     4.091     0.200
    61.605     4.124     0.200
    64.305     4.355     0.200
    67.004     4.552     0.200
    69.406     4.604     0.200
    70.906     4.851     0.200
    76.906     5.243     0.200
    79.805     5.424     0.200
    80.504     5.444     0.200
    82.305     5.584     0.200
    82.203     5.585     0.200
    86.703     5.901     0.200
    13.397     0.683     0.200
    14.598     0.739     0.200
    14.997     0.788     0.200
    15.797     0.841     0.200
    18.697     1.009     0.200
    20.897     1.176     0.200
    24.397     1.381     0.200
    24.797     1.423     0.200
    24.497     1.403     0.200
    24.497     1.420     0.200
    25.397     1.574     0.200
    25.497     1.569     0.200
    27.098     1.577     0.200
    28.598     1.665     0.200
    28.197     1.706     0.200
    29.997     1.824     0.200
    31.598     1.929     0.200
    32.197     1.994     0.200
    32.497     1.968     0.200
    31.997     1.967     0.200
    32.497     2.019     0.200
    33.297     2.076     0.200
    34.697     2.136     0.200
    35.497     2.236     0.200
    39.797     2.518     0.200
    39.497     2.536     0.200
    42.197     2.860     0.200
    46.197     3.027     0.200
    46.897     3.053     0.200
    48.098     3.119     0.200
    47.497     3.120     0.200
    52.897     3.537     0.200
    54.397     3.547     0.200
    55.497     3.628     0.200
    61.397     4.071     0.200
     7.398     0.193     0.200
     7.695     0.236     0.200
    12.496     0.634     0.200
    14.297     0.752     0.200
    13.598     0.668     0.200
    15.398     0.811     0.200
    14.996     0.816     0.200
    19.398     1.098     0.200
    19.996     1.179     0.200
    22.398     1.310     0.200
    23.195     1.359     0.200
    20.996     1.274     0.200
    23.098     1.394     0.200
    23.797     1.433     0.200
    23.195     1.408     0.200
    22.496     1.447     0.200
    26.797     1.629     0.200
    25.598     1.610     0.200
    27.797     1.725     0.200
    27.195     1.752     0.200
    32.195     1.961     0.200
    32.898     2.084     0.200
    35.098     2.114     0.200
    34.098     2.117     0.200
    32.898     2.137     0.200
    34.797     2.180     0.200
    35.598     2.278     0.200
    36.797     2.317     0.200
    36.898     2.316     0.200
    39.695     2.490     0.200
    37.695     2.500     0.200
    40.398     2.578     0.200
    41.695     2.751     0.200
    41.598     2.758     0.200
    41.598     2.711     0.200
    40.695     2.764     0.200
    42.496     2.779     0.200
    46.598     2.970     0.200
    45.598     3.003     0.200
    47.098     3.122     0.200
    47.398     3.163     0.200
    48.598     3.190     0.200
    49.195     3.322     0.200
    52.398     3.459     0.200
    54.898     3.651     0.200
    55.098     3.713     0.200
    56.195     3.734     0.200
    62.797     4.132     0.200
    61.496     4.125     0.200
    63.598     4.245     0.200
    64.797     4.334     0.200
    65.797     4.433     0.200
    66.996     4.493     0.200
    68.098     4.645     0.200
    69.098     4.654     0.200
    68.098     4.649     0.200
    69.195     4.691     0.200
    72.996     4.935     0.200
    73.996     5.091     0.200
    76.695     5.168     0.200
    78.297     5.340     0.200
    79.297     5.493     0.200
    80.695     5.492     0.200
    80.496     5.532     0.200
    82.098     5.568     0.200
    83.797     5.713     0.200
    82.598     5.728     0.200
    84.496     5.734     0.200
    83.996     5.780     0.200
    84.297     5.805     0.200
    85.496     5.836     0.200
    87.297     5.960     0.200
    89.195     5.999     0.200
    88.598     6.021     0.200
    90.195     6.180     0.200
    95.098     6.537     0.200
   100.598     6.936     0.200
   105.297     7.187     0.200
   111.898     7.394     0.200
   111.797     7.675     0.200
   115.098     7.877     0.200
   114.797     7.883     0.200
   118.797     8.163     0.200
   123.898     8.345     0.200
   124.195     8.479     0.200
   130.797     8.946     0.200
   137.195     9.392     0.200
   136.398     9.397     0.200
   136.996     9.472     0.200
   138.398     9.488     0.200
   141.598     9.776     0.200
   142.195     9.734     0.200
   144.496     9.780     0.200
   145.598    10.025     0.200
   150.195    10.405     0.200
   151.496    10.546     0.200
   158.598    10.965     0.200
   165.598    11.499     0.200
   165.797    11.441     0.200
   168.297    11.748     0.200
   182.297    12.884     0.200
   205.797    14.618     0.200
     7.227     0.185     0.200
     7.625     0.247     0.200
    11.426     0.553     0.200
    12.227     0.617     0.200
    14.125     0.744     0.200
    14.227     0.763     0.200
    15.227     0.805     0.200
    15.125     0.807     0.200
    19.527     1.101     0.200
    19.828     1.169     0.200
    21.426     1.276     0.200
    22.227     1.308     0.200
    22.727     1.318     0.200
    23.027     1.365     0.200
    22.828     1.386     0.200
    23.027     1.401     0.200
    23.727     1.422     0.200
    25.426     1.608     0.200
    26.527     1.627     0.200
    27.527     1.717     0.200
    28.328     1.754     0.200
    28.625     1.784     0.200
    31.625     1.964     0.200
    32.727     2.081     0.200
    33.926     2.117     0.200
    35.227     2.121     0.200
    34.426     2.171     0.200
    35.125     2.271     0.200
    36.727     2.309     0.200
    36.426     2.316     0.200
    38.926     2.495     0.200
    37.926     2.503     0.200
    41.328     2.706     0.200
    41.527     2.743     0.200
    41.328     2.749     0.200
    40.527     2.769     0.200
    42.426     2.780     0.200
    45.727     3.003     0.200
    47.727     3.120     0.200
    48.328     3.159     0.200
    47.727     3.187     0.200
    49.125     3.324     0.200
    55.027     3.649     0.200
    56.227     3.715     0.200
    55.828     3.733     0.200
    62.027     4.126     0.200
    65.828     4.432     0.200
    69.625     4.646     0.200
    69.027     4.648     0.200
    72.027     4.922     0.200
    79.527     5.482     0.200
    83.227     5.711     0.200
    82.527     5.712     0.200
     7.430     0.179     0.200
     7.828     0.240     0.200
    12.727     0.646     0.200
    12.531     0.613     0.200
    14.633     0.754     0.200
    13.531     0.655     0.200
    15.430     0.819     0.200
    14.727     0.759     0.200
    14.930     0.810     0.200
    19.930     1.165     0.200
    22.328     1.320     0.200
    23.727     1.373     0.200
    20.930     1.264     0.200
    24.031     1.430     0.200
    22.633     1.440     0.200
    26.430     1.639     0.200
    27.727     1.711     0.200
    33.328     2.093     0.200
    33.828     2.129     0.200
    33.531     2.128     0.200
    36.227     2.282     0.200
    39.430     2.504     0.200
    41.633     2.753     0.200
    41.430     2.758     0.200
    43.328     2.849     0.200
    45.828     2.984     0.200
    47.430     3.169     0.200
    46.828     3.109     0.200
    47.727     3.176     0.200
    48.930     3.312     0.200
    54.430     3.474     0.200
    55.133     3.638     0.200
    54.930     3.703     0.200
    65.328     4.146     0.200
    61.031     4.114     0.200
    63.227     4.232     0.200
    64.727     4.321     0.200
    65.133     4.421     0.200
    69.031     4.635     0.200
    68.031     4.637     0.200
    68.633     4.644     0.200
    71.531     4.911     0.200
    72.828     4.922     0.200
    74.430     5.023     0.200
    74.328     5.080     0.200
    76.633     5.155     0.200
    78.227     5.327     0.200
    80.930     5.474     0.200
    79.430     5.488     0.200
    78.930     5.516     0.200
    80.727     5.481     0.200
    80.227     5.522     0.200
    81.727     5.555     0.200
    83.430     5.700     0.200
    83.531     5.701     0.200
    84.133     5.720     0.200
    82.133     5.717     0.200
    84.031     5.769     0.200
    85.727     5.948     0.200
    87.133     5.948     0.200
    88.828     5.986     0.200
    88.031     6.009     0.200
    88.328     6.168     0.200
    92.633     6.331     0.200
    94.727     6.525     0.200
    96.633     6.627     0.200
    96.633     6.641     0.200
   100.227     6.924     0.200
   104.828     7.174     0.200
   110.227     7.408     0.200
   111.727     7.662     0.200
   115.031     7.791     0.200
   114.828     7.863     0.200
   114.633     7.869     0.200
   118.828     7.964     0.200
   118.430     8.150     0.200
   121.531     8.332     0.200
   125.227     8.566     0.200
   124.031     8.465     0.200
   128.133     8.831     0.200
   130.727     8.932     0.200
   131.328     9.023     0.200
   137.133     9.378     0.200
   136.227     9.384     0.200
   136.031     9.408     0.200
   136.531     9.458     0.200
   137.828     9.474     0.200
   141.430     9.785     0.200
   141.828     9.721     0.200
   141.031     9.766     0.200
   144.328    10.011     0.200
   147.430    10.109     0.200
   155.930    10.721     0.200
   158.633    10.758     0.200
   156.531    10.887     0.200
   156.430    10.959     0.200
   158.430    11.021     0.200
   163.328    11.331     0.200
   164.430    11.429     0.200
   169.531    11.739     0.200
   172.930    11.810     0.200
   170.227    12.096     0.200
   178.727    12.607     0.200
   175.930    12.613     0.200
   180.227    12.638     0.200
   179.531    12.683     0.200
   180.828    12.887     0.200
   187.031    13.325     0.200
   189.727    13.604     0.200
   205.930    14.614     0.200
   218.430    15.666     0.200
   221.430    15.840     0.200
   250.031    18.202     0.200
   250.430    18.290     0.200
   250.430    18.353     0.200
   253.031    18.464     0.200
     7.281     0.195     0.200
     7.684     0.252     0.200
    15.082     0.794     0.200
    20.082     1.178     0.200
    22.184     1.294     0.200
    22.980     1.353     0.200
    22.383     1.320     0.200
    21.582     1.290     0.200
    23.082     1.376     0.200
    23.883     1.416     0.200
    23.281     1.412     0.200
    26.480     1.613     0.200
    25.781     1.621     0.200
    27.883     1.726     0.200
    28.480     1.768     0.200
    31.582     1.951     0.200
    32.684     2.068     0.200
    33.082     2.145     0.200
    34.582     2.179     0.200
    35.480     2.261     0.200
    36.383     2.303     0.200
    36.980     2.320     0.200
    38.383     2.482     0.200
    38.082     2.516     0.200
    40.281     2.588     0.200
    41.480     2.733     0.200
    41.480     2.740     0.200
    41.582     2.718     0.200
    42.582     2.825     0.200
    40.883     2.781     0.200
    42.582     2.794     0.200
    46.883     2.967     0.200
    45.781     3.017     0.200
    47.480     3.144     0.200
    47.980     3.133     0.200
    47.582     3.172     0.200
    47.980     3.200     0.200
    49.082     3.338     0.200
    52.582     3.454     0.200
    55.383     3.662     0.200
    55.184     3.728     0.200
    56.281     3.747     0.200
    64.883     4.127     0.200
    62.281     4.140     0.200
    63.781     4.256     0.200
    66.184     4.446     0.200
    70.980     4.660     0.200
    68.281     4.662     0.200
    72.184     4.936     0.200
    74.383     5.105     0.200
    79.383     5.478     0.200
    81.082     5.506     0.200
    81.781     5.580     0.200
    83.684     5.724     0.200
    84.082     5.724     0.200
    83.082     5.725     0.200
    83.883     5.743     0.200
    87.082     5.973     0.200
   148.980    10.411     0.200
   164.480    11.482     0.200
   253.480    18.460     0.200
    10.535     0.330     0.200
    15.234     0.726     0.200
    15.234     0.729     0.200
    17.535     0.937     0.200
    18.635     1.041     0.200
    20.434     1.161     0.200
    25.035     1.490     0.200
    25.035     1.530     0.200
    25.635     1.526     0.200
    26.535     1.572     0.200
    27.234     1.684     0.200
    30.334     1.871     0.200
    30.635     1.925     0.200
    31.234     2.007     0.200
    32.535     2.017     0.200
    32.934     2.053     0.200
    33.334     2.119     0.200
    35.234     2.185     0.200
    34.434     2.189     0.200
    35.434     2.323     0.200
    38.334     2.357     0.200
    36.135     2.349     0.200
    40.234     2.612     0.200
    40.334     2.621     0.200
    41.535     2.658     0.200
    40.734     2.662     0.200
    41.334     2.759     0.200
    43.535     2.852     0.200
    45.035     2.986     0.200
    45.234     2.971     0.200
    45.334     3.071     0.200
    47.635     3.139     0.200
    47.334     3.149     0.200
    48.035     3.164     0.200
    48.434     3.216     0.200
    51.035     3.220     0.200
    51.734     3.540     0.200
    55.535     3.699     0.200
    57.734     3.848     0.200
    57.434     3.923     0.200
    64.334     4.311     0.200
    63.635     4.317     0.200
    64.334     4.326     0.200
    67.334     4.563     0.200
    68.234     4.621     0.200
    69.934     4.750     0.200
    70.635     4.827     0.200
    73.434     4.979     0.200
    73.734     5.000     0.200
    74.135     5.061     0.200
    77.234     5.182     0.200
    76.635     5.263     0.200
    83.135     5.627     0.200
    82.434     5.635     0.200
    83.734     5.689     0.200
    84.334     5.765     0.200
    84.635     5.766     0.200
    84.734     5.910     0.200
    85.535     5.925     0.200
    86.434     5.968     0.200
    87.635     6.008     0.200
    89.234     6.072     0.200
    89.834     6.086     0.200
    90.035     6.219     0.200
    91.934     6.312     0.200
    93.234     6.531     0.200
    97.035     6.616     0.200
    97.135     6.633     0.200
   106.135     7.227     0.200
   113.135     7.725     0.200
   114.434     7.859     0.200
   120.834     8.205     0.200
   124.035     8.458     0.200
   130.635     8.869     0.200
   130.334     8.910     0.200
   135.834     9.322     0.200
   136.734     9.370     0.200
   136.135     9.404     0.200
   137.734     9.462     0.200
   140.035     9.692     0.200
   146.434    10.045     0.200
   146.535    10.271     0.200
   178.035    12.480     0.200
     7.298     0.134     0.200
     9.198     0.373     0.200
    12.498     0.652     0.200
    12.998     0.653     0.200
    14.098     0.747     0.200
    14.998     0.770     0.200
    20.098     1.143     0.200
    20.498     1.189     0.200
    21.798     1.276     0.200
    21.598     1.309     0.200
    21.698     1.303     0.200
    21.998     1.304     0.200
    22.198     1.328     0.200
    24.498     1.431     0.200
    25.398     1.589     0.200
    26.298     1.601     0.200
    26.598     1.631     0.200
    27.098     1.673     0.200
    27.998     1.790     0.200
    31.998     1.992     0.200
    32.198     2.038     0.200
    33.098     2.075     0.200
    32.198     2.093     0.200
    33.398     2.115     0.200
    34.398     2.191     0.200
    35.598     2.242     0.200
    35.698     2.297     0.200
    40.098     2.543     0.200
    38.298     2.543     0.200
    39.098     2.553     0.200
    39.898     2.645     0.200
    40.298     2.649     0.200
    40.798     2.659     0.200
    42.798     2.805     0.200
    41.698     2.824     0.200
    41.998     2.821     0.200
    45.598     3.010     0.200
    46.798     3.099     0.200
    47.198     3.125     0.200
    47.298     3.121     0.200
    47.898     3.162     0.200
    49.498     3.353     0.200
    54.498     3.630     0.200
    56.098     3.733     0.200
    56.698     3.742     0.200
    61.498     4.149     0.200
    63.398     4.230     0.200
    64.298     4.299     0.200
    66.198     4.437     0.200
    68.398     4.646     0.200
    72.898     4.915     0.200
    72.198     4.930     0.200
    78.398     5.337     0.200
    83.498     5.696     0.200
    87.898     5.961     0.200
    13.656     0.688     0.200
    15.957     0.845     0.200
    19.656     1.110     0.200
    20.855     1.141     0.200
    22.559     1.276     0.200
    24.457     1.418     0.200
    23.059     1.429     0.200
    24.059     1.447     0.200
    25.156     1.475     0.200
    26.059     1.532     0.200
    25.957     1.548     0.200
    88.258     5.968     0.200
    89.156     6.112     0.200
   211.258    15.122     0.200
    12.465     0.606     0.200
    14.066     0.677     0.200
    15.664     0.810     0.200
    19.465     1.063     0.200
    19.367     1.070     0.200
    19.766     1.084     0.200
    20.164     1.122     0.200
    21.516     1.183     0.200
    21.867     1.225     0.200
    23.566     1.328     0.200
    24.164     1.387     0.200
    25.066     1.476     0.200
    26.164     1.528     0.200
    26.867     1.605     0.200
    27.465     1.642     0.200
    27.766     1.658     0.200
    87.914     5.994     0.200
    95.266     6.434     0.200
    95.516     6.496     0.200
    97.715     6.583     0.200
     7.309     0.105     0.200
    10.209     0.437     0.200
    11.809     0.565     0.200
    12.510     0.604     0.200
    12.709     0.613     0.200
    13.109     0.652     0.200
    14.010     0.731     0.200
    15.410     0.819     0.200
    18.109     1.003     0.200
    19.109     1.070     0.200
    21.010     1.238     0.200
    20.809     1.275     0.200
    76.939     5.298     0.200
    77.316     5.298     0.200
    82.609     5.627     0.200
    82.885     5.628     0.200
    87.729     6.071     0.200
    89.959     6.230     0.200
   109.760     7.606     0.200
   160.609    11.216     0.200
   165.709    11.467     0.200
   181.910    12.778     0.200
   216.109    15.506     0.200
   249.109    18.054     0.200
   250.936    18.256     0.200
   265.609    19.476     0.200
    11.805     0.555     0.200
     9.402     0.417     0.200
    10.703     0.504     0.200
    14.805     0.787     0.200
    16.105     0.869     0.200
    15.203     0.820     0.200
    20.004     1.170     0.200
    23.402     1.360     0.200
    23.305     1.367     0.200
    85.645     5.901     0.200
    85.902     5.901     0.200
    89.516     6.135     0.200
    89.504     6.135     0.200
    89.152     6.136     0.200
    90.754     6.286     0.200
    95.273     6.609     0.200
    98.254     6.889     0.200
   138.004     9.606     0.200
   152.004    10.608     0.200
   164.805    11.393     0.200
   162.305    11.402     0.200
   171.805    12.008     0.200
   175.504    12.249     0.200
   184.305    12.991     0.200
   200.004    14.329     0.200
   208.004    14.868     0.200
   216.004    15.463     0.200
   223.805    16.244     0.200
   236.504    17.302     0.200
   244.203    17.844     0.200
   253.504    18.437     0.200
   264.504    19.478     0.200
   264.883    19.479     0.200
   269.582    19.939     0.200
   280.805    20.836     0.200
     8.348     0.281     0.200
     8.746     0.326     0.200
     9.246     0.374     0.200
    12.348     0.604     0.200
    12.547     0.637     0.200
    15.645     0.855     0.200
    17.348     0.971     0.200
    16.746     0.939     0.200
    18.145     1.035     0.200
    18.145     1.067     0.200
    20.945     1.227     0.200
    20.348     1.233     0.200
    21.246     1.251     0.200
    26.145     1.600     0.200
    78.746     5.334     0.200
    79.008     5.334     0.200
    86.895     6.041     0.200
   181.895    12.880     0.200
   213.047    15.211     0.200
   250.547    18.120     0.200
   267.746    19.648     0.200
     6.844     0.136     0.200
     7.445     0.228     0.200
    10.145     0.461     0.200
    11.344     0.555     0.200
    12.344     0.611     0.200
    14.043     0.748     0.200
    13.543     0.709     0.200
    19.844     1.164     0.200
    21.344     1.234     0.200
    22.145     1.315     0.200
    23.992     1.418     0.200
    79.820     5.515     0.200
    81.844     5.599     0.200
    82.320     5.600     0.200
   108.895     7.536     0.200
   182.844    12.962     0.200
   186.742    13.237     0.200
   207.504    14.669     0.200
   252.344    18.259     0.200
   253.742    18.466     0.200
   266.043    19.642     0.200
    10.184     0.288     0.200
    11.684     0.449     0.200
    11.883     0.499     0.200
    12.082     0.498     0.200
    12.383     0.537     0.200
    15.582     0.789     0.200
    15.184     0.782     0.200
    15.480     0.800     0.200
    16.883     0.942     0.200
    16.684     0.902     0.200
    17.980     0.973     0.200
    18.281     1.019     0.200
    18.980     1.087     0.200
    76.781     5.340     0.200
    77.531     5.340     0.200
    88.082     6.060     0.200
    88.645     6.061     0.200
    93.934     6.537     0.200
   151.230    10.756     0.200
   165.332    11.476     0.200
     7.766     0.225     0.200
     7.965     0.245     0.200
    11.867     0.597     0.200
    11.965     0.574     0.200
    12.367     0.602     0.200
    13.766     0.705     0.200
    15.066     0.800     0.200
    21.816     1.278     0.200
    22.566     1.312     0.200
    21.566     1.309     0.200
    79.668     5.492     0.200
    84.496     5.750     0.200
    84.367     5.750     0.200
    84.066     5.750     0.200
    84.430     5.751     0.200
    90.137     6.247     0.200
   105.566     7.402     0.200
   142.367     9.743     0.200
   160.168    10.967     0.200
   166.668    11.469     0.200
   165.086    11.459     0.200
   166.566    11.757     0.200
   182.566    12.863     0.200
   187.418    13.375     0.200
   205.727    14.603     0.200
   205.996    14.603     0.200
   250.465    18.190     0.200
   253.344    18.480     0.200
   262.465    19.247     0.200
   265.965    19.527     0.200
    11.258     0.355     0.200
    11.758     0.375     0.200
    11.461     0.340     0.200
    13.164     0.528     0.200
    14.258     0.648     0.200
    17.062     0.881     0.200
    17.664     0.923     0.200
    17.664     0.937     0.200
    18.258     0.994     0.200
    19.164     1.050     0.200
    21.664     1.229     0.200
    23.258     1.347     0.200
    75.344     5.195     0.200
    85.531     5.918     0.200
    88.305     6.073     0.200
    88.461     6.073     0.200
    88.758     6.073     0.200
    88.711     6.073     0.200
    95.109     6.626     0.200
   102.711     7.242     0.200
   163.461    11.545     0.200
   199.508    14.226     0.200
   200.016    14.226     0.200
   246.258    17.809     0.200
   248.438    18.257     0.200
   249.258    18.257     0.200
   259.258    18.860     0.200
     8.336     0.209     0.200
    10.035     0.400     0.200
    12.137     0.581     0.200
    13.734     0.695     0.200
    13.836     0.709     0.200
    14.234     0.733     0.200
    14.637     0.760     0.200
    21.137     1.202     0.200
    20.938     1.201     0.200
    78.066     5.333     0.200
    84.535     5.769     0.200
    84.535     5.769     0.200
    84.336     5.769     0.200
   109.234     7.455     0.200
   166.438    11.604     0.200
   203.938    14.451     0.200
   251.137    18.327     0.200
     9.715     0.306     0.200
     9.512     0.283     0.200
    12.012     0.516     0.200
    13.312     0.636     0.200
    13.312     0.653     0.200
    15.012     0.783     0.200
    16.012     0.838     0.200
    20.965     1.195     0.200
    22.914     1.339     0.200
    22.812     1.392     0.200
    85.215     5.828     0.200
    85.113     5.828     0.200
    84.914     5.828     0.200
    85.512     5.829     0.200
    90.215     6.289     0.200
   104.715     7.343     0.200
   149.965    10.574     0.200
   155.414    10.937     0.200
   162.113    11.467     0.200
   168.113    11.743     0.200
   188.113    13.438     0.200
   251.215    18.464     0.200
   262.613    19.187     0.200
    10.000     0.319     0.200
    11.398     0.468     0.200
    12.102     0.519     0.200
    11.898     0.517     0.200
    14.602     0.735     0.200
    15.699     0.823     0.200
    15.898     0.838     0.200
    16.199     0.862     0.200
    19.398     1.091     0.200
    21.102     1.195     0.200
    76.191     5.232     0.200
    85.711     5.859     0.200
    85.898     5.859     0.200
    86.000     5.859     0.200
   186.352    13.383     0.200
     7.559     0.155     0.200
     9.759     0.398     0.200
    12.859     0.639     0.200
    13.359     0.666     0.200
    13.159     0.658     0.200
    13.559     0.678     0.200
    14.759     0.770     0.200
    20.359     1.156     0.200
    22.059     1.253     0.200
    21.759     1.333     0.200
    77.079     5.329     0.200
    83.959     5.712     0.200
    83.859     5.712     0.200
    84.459     5.713     0.200
    90.059     6.274     0.200
   203.659    14.465     0.200
   251.959    18.309     0.200
    11.905     0.580     0.200
    11.706     0.576     0.200
    12.706     0.638     0.200
    12.006     0.619     0.200
    13.605     0.743     0.200
    16.605     0.897     0.200
    20.105     1.126     0.200
    18.105     1.057     0.200
    21.155     1.186     0.200
    24.105     1.380     0.200
    24.605     1.476     0.200
    25.706     1.578     0.200
    28.105     1.697     0.200
    28.306     1.692     0.200
    30.605     1.894     0.200
    31.506     1.976     0.200
    28.905     1.848     0.200
    28.405     1.861     0.200
    31.605     1.943     0.200
    36.905     2.349     0.200
    38.006     2.437     0.200
    43.506     2.862     0.200
    45.306     2.993     0.200
    45.806     3.145     0.200
    61.405     4.148     0.200
    65.306     4.331     0.200
    64.905     4.353     0.200
    72.605     4.901     0.200
    73.905     5.022     0.200
    76.806     5.267     0.200
    82.405     5.606     0.200
    86.405     5.967     0.200
    86.905     5.950     0.200
    90.806     6.220     0.200
    92.806     6.361     0.200
    92.556     6.370     0.200
    92.605     6.370     0.200
    92.806     6.370     0.200
    92.968     6.371     0.200
    93.155     6.454     0.200
    95.405     6.468     0.200
    93.306     6.481     0.200
    98.355     6.650     0.200
    96.605     6.649     0.200
    96.006     6.556     0.200
   134.806     9.436     0.200
   146.256    10.295     0.200
   150.105    10.610     0.200
   161.806    11.255     0.200
   176.306    12.170     0.200
   176.806    12.362     0.200
   177.286    12.503     0.200
   183.605    12.915     0.200
   197.306    14.106     0.200
   196.556    14.117     0.200
   208.806    14.851     0.200
   252.806    18.411     0.200
   259.806    18.928     0.200
   259.726    19.069     0.200
   263.605    19.444     0.200
     8.270     0.289     0.200
     9.270     0.382     0.200
    10.367     0.467     0.200
    11.867     0.563     0.200
    13.168     0.664     0.200
    15.867     0.855     0.200
    17.066     0.947     0.200
    21.066     1.179     0.200
    80.828     5.541     0.200
    86.168     5.896     0.200
    86.668     5.896     0.200
    86.492     5.897     0.200
   265.258    19.600     0.200
     9.945     0.396     0.200
    10.246     0.428     0.200
    12.645     0.595     0.200
    14.348     0.733     0.200
    14.645     0.759     0.200
    17.445     0.957     0.200
    17.645     0.972     0.200
    19.746     1.086     0.200
    83.098     5.782     0.200
    93.625     6.421     0.200
    93.445     6.421     0.200
    93.723     6.422     0.200
   196.848    14.106     0.200
   228.945    16.508     0.200
    11.223     0.447     0.200
    12.523     0.550     0.200
    13.324     0.631     0.200
    15.723     0.827     0.200
    18.453     1.033     0.200
    18.273     1.033     0.200
    18.625     1.037     0.200
    19.625     1.094     0.200
    21.125     1.222     0.200
    25.324     1.475     0.200
    80.473     5.540     0.200
    80.473     5.540     0.200
    88.434     6.078     0.200
    88.723     6.078     0.200
    92.699     6.440     0.200
   101.086     7.077     0.200
   158.398    11.083     0.200
     6.680     0.052     0.200
     8.875     0.362     0.200
    10.578     0.473     0.200
    11.180     0.509     0.200
    11.680     0.568     0.200
    14.078     0.742     0.200
    19.273     1.094     0.200
    19.078     1.128     0.200
    24.125     1.461     0.200
    54.781     3.692     0.200
    54.930     3.718     0.200
    58.664     4.043     0.200
    71.172     4.855     0.200
    72.188     4.923     0.200
    73.406     5.012     0.200
    75.570     5.178     0.200
    76.445     5.289     0.200
    78.523     5.416     0.200
    81.273     5.513     0.200
    81.250     5.514     0.200
    84.672     5.837     0.200
   110.727     7.661     0.200
   183.773    13.116     0.200
     8.570     0.276     0.200
     9.570     0.360     0.200
    10.470     0.463     0.200
    12.670     0.584     0.200
    13.070     0.639     0.200
    14.870     0.779     0.200
    15.770     0.851     0.200
    18.270     1.022     0.200
    21.170     1.256     0.200
    21.270     1.278     0.200
    23.370     1.408     0.200
    22.670     1.344     0.200
    61.980     4.146     0.200
    71.670     4.822     0.200
    74.570     5.132     0.200
    75.640     5.132     0.200
    74.570     5.132     0.200
    76.010     5.150     0.200
    81.890     5.517     0.200
    81.640     5.517     0.200
    82.270     5.518     0.200
    89.995     6.252     0.200
    89.150     6.281     0.200
   110.745     7.795     0.200
   112.390     7.795     0.200
   127.270     8.805     0.200
   148.390    10.378     0.200
   147.758    10.378     0.200
   155.270    10.999     0.200
   166.170    11.821     0.200
   167.370    11.821     0.200
   180.970    12.710     0.200
   183.470    13.006     0.200
   183.360    13.006     0.200
   196.870    14.114     0.200
   198.870    14.343     0.200
   213.910    15.316     0.200
   213.370    15.316     0.200
   227.070    16.504     0.200
   244.470    17.939     0.200
   249.170    18.057     0.200
    20.445     1.160     0.200
    24.617     1.425     0.200
    24.992     1.425     0.200
    69.062     4.581     0.200
    88.094     6.050     0.200
    88.672     6.050     0.200
    88.094     6.050     0.200
    88.484     6.071     0.200
    89.148     6.061     0.200
    88.945     6.061     0.200
    89.688     6.061     0.200
    89.133     6.061     0.200
    88.812     6.166     0.200
   143.422    10.092     0.200
   164.344    11.479     0.200
   162.891    11.479     0.200
   195.070    13.854     0.200
   194.531    13.854     0.200
   229.992    16.513     0.200
     7.506     0.143     0.200
     9.805     0.394     0.200
    12.805     0.649     0.200
    12.904     0.651     0.200
    13.205     0.657     0.200
    13.305     0.667     0.200
    14.705     0.767     0.200
    20.105     1.151     0.200
    21.680     1.265     0.200
    21.875     1.265     0.200
    21.506     1.322     0.200
    63.895     4.296     0.200
    77.555     5.334     0.200
    77.275     5.334     0.200
    77.555     5.334     0.200
    77.895     5.353     0.200
    83.535     5.700     0.200
    83.516     5.701     0.200
    83.506     5.701     0.200
    83.975     5.702     0.200
   108.055     7.519     0.200
   153.805    10.676     0.200
   161.605    11.425     0.200
   204.605    14.475     0.200
   247.805    18.062     0.200
   262.805    19.123     0.200
     7.156     0.118     0.200
     9.258     0.370     0.200
    10.855     0.484     0.200
    11.258     0.521     0.200
    12.855     0.649     0.200
    12.957     0.645     0.200
    13.957     0.705     0.200
    15.855     0.851     0.200
    17.758     1.004     0.200
    18.457     1.033     0.200
    21.355     1.196     0.200
    21.758     1.300     0.200
    23.559     1.409     0.200
    83.473     5.759     0.200
    92.059     6.312     0.200
    92.145     6.313     0.200
    94.105     6.517     0.200
    97.105     6.776     0.200
     7.086     0.186     0.200
     8.984     0.366     0.200
     9.883     0.443     0.200
    10.484     0.487     0.200
    11.086     0.539     0.200
    15.586     0.853     0.200
    17.281     0.973     0.200
    18.484     1.050     0.200
    17.758     1.050     0.200
    20.984     1.278     0.200
    22.773     1.358     0.200
    26.086     1.567     0.200
    25.797     1.567     0.200
    42.164     2.787     0.200
    41.664     2.796     0.200
    43.047     2.852     0.200
    59.594     3.985     0.200
    64.297     4.340     0.200
    67.633     4.714     0.200
    78.133     5.368     0.200
    79.484     5.385     0.200
    77.938     5.368     0.200
    79.586     5.386     0.200
    78.828     5.386     0.200
    78.195     5.419     0.200
   249.484    18.189     0.200
     7.367     0.064     0.200
     9.672     0.387     0.200
    10.570     0.462     0.200
    11.266     0.522     0.200
    11.570     0.543     0.200
    14.570     0.765     0.200
    18.867     1.070     0.200
    18.867     1.125     0.200
    19.188     1.125     0.200
    24.195     1.469     0.200
    24.539     1.469     0.200
    24.562     1.479     0.200
    42.359     2.728     0.200
    41.672     2.768     0.200
    43.977     2.903     0.200
    61.227     4.091     0.200
    65.727     4.448     0.200
    77.820     5.399     0.200
    81.062     5.499     0.200
    80.867     5.499     0.200
    81.234     5.500     0.200
    80.469     5.500     0.200
    93.547     6.421     0.200
   249.367    18.184     0.200
   269.141    19.837     0.200
     6.500     0.022     0.200
     9.102     0.381     0.200
    11.406     0.537     0.200
    11.906     0.570     0.200
    11.602     0.572     0.200
    14.203     0.764     0.200
    19.000     1.091     0.200
    20.203     1.198     0.200
    24.180     1.394     0.200
    53.672     3.645     0.200
    61.680     4.177     0.200
    64.719     4.424     0.200
    65.969     4.508     0.200
    66.797     4.557     0.200
    69.523     4.739     0.200
    69.867     4.790     0.200
    70.703     4.863     0.200
    72.219     4.949     0.200
    74.859     5.155     0.200
    76.703     5.251     0.200
    78.305     5.370     0.200
    81.953     5.573     0.200
    83.938     5.798     0.200
   149.875    10.592     0.200
     7.941     0.279     0.200
     9.043     0.384     0.200
     9.742     0.418     0.200
    11.941     0.565     0.200
    14.043     0.751     0.200
    15.840     0.924     0.200
    19.043     1.089     0.200
    28.293     1.664     0.200
    53.973     3.664     0.200
    56.641     3.854     0.200
    69.027     4.695     0.200
    68.531     4.674     0.200
    69.449     4.755     0.200
    69.949     4.796     0.200
    71.562     4.915     0.200
    71.590     4.918     0.200
    73.438     4.997     0.200
    73.246     5.029     0.200
    73.828     5.076     0.200
    75.352     5.179     0.200
    78.340     5.325     0.200
    78.148     5.391     0.200
    79.906     5.525     0.200
    86.457     5.921     0.200
     8.727     0.128     0.200
     9.324     0.189     0.200
    11.625     0.502     0.200
    12.227     0.522     0.200
    13.125     0.575     0.200
    13.824     0.673     0.200
    14.324     0.692     0.200
    15.125     0.765     0.200
    15.824     0.800     0.200
    16.926     0.844     0.200
    16.023     0.844     0.200
    16.145     0.844     0.200
    18.023     0.991     0.200
    18.426     1.052     0.200
    19.324     1.066     0.200
    19.727     1.124     0.200
    19.824     1.155     0.200
    22.324     1.267     0.200
    21.523     1.264     0.200
    22.125     1.276     0.200
    22.324     1.318     0.200
    23.324     1.365     0.200
    23.727     1.384     0.200
    24.227     1.440     0.200
    25.625     1.540     0.200
    25.426     1.550     0.200
    25.926     1.543     0.200
    26.324     1.617     0.200
    28.426     1.779     0.200
    28.926     1.837     0.200
    29.145     1.837     0.200
    30.324     1.901     0.200
    30.453     1.901     0.200
    30.824     1.892     0.200
    29.523     1.948     0.200
    30.824     1.962     0.200
    31.227     1.984     0.200
    34.023     2.207     0.200
    34.125     2.242     0.200
    35.523     2.259     0.200
    35.664     2.259     0.200
    35.023     2.305     0.200
    37.523     2.445     0.200
    37.324     2.473     0.200
    38.727     2.568     0.200
    38.844     2.568     0.200
    40.324     2.648     0.200
    44.227     2.975     0.200
    47.156     3.165     0.200
    47.816     3.165     0.200
    47.730     3.214     0.200
    49.184     3.312     0.200
    50.805     3.405     0.200
    51.945     3.498     0.200
    52.246     3.537     0.200
    51.824     3.574     0.200
    53.184     3.599     0.200
    53.402     3.599     0.200
    54.742     3.708     0.200
    54.555     3.708     0.200
    55.246     3.719     0.200
    55.434     3.754     0.200
    55.645     3.775     0.200
    56.094     3.806     0.200
    56.457     3.831     0.200
    58.664     3.984     0.200
    59.016     3.994     0.200
    60.793     4.157     0.200
    61.223     4.157     0.200
    61.223     4.180     0.200
    61.402     4.180     0.200
    61.828     4.191     0.200
    62.094     4.224     0.200
    62.164     4.244     0.200
    62.926     4.247     0.200
    62.234     4.261     0.200
    62.633     4.261     0.200
    62.527     4.261     0.200
    64.078     4.368     0.200
    64.039     4.381     0.200
    64.297     4.381     0.200
    65.094     4.432     0.200
    66.398     4.485     0.200
    64.988     4.477     0.200
    66.047     4.477     0.200
    66.859     4.555     0.200
    66.180     4.555     0.200
    66.902     4.583     0.200
    67.164     4.583     0.200
    67.152     4.588     0.200
    67.355     4.593     0.200
    66.953     4.593     0.200
    68.426     4.687     0.200
    69.543     4.711     0.200
    69.094     4.721     0.200
    69.926     4.727     0.200
    69.113     4.745     0.200
    70.617     4.758     0.200
    70.051     4.771     0.200
    70.480     4.771     0.200
    70.145     4.775     0.200
    70.102     4.792     0.200
    69.965     4.796     0.200
    70.523     4.795     0.200
    70.195     4.818     0.200
    71.102     4.849     0.200
    70.902     4.858     0.200
    71.324     4.858     0.200
    71.586     4.875     0.200
    71.645     4.897     0.200
    70.926     4.959     0.200
    72.223     4.965     0.200
    73.227     5.023     0.200
    73.125     5.015     0.200
    73.105     5.027     0.200
    73.504     5.029     0.200
    73.625     5.065     0.200
    75.164     5.157     0.200
    75.727     5.187     0.200
    76.094     5.193     0.200
    76.094     5.217     0.200
    76.355     5.238     0.200
    75.727     5.268     0.200
    78.473     5.371     0.200
    79.094     5.371     0.200
    78.320     5.386     0.200
    78.727     5.384     0.200
    78.602     5.403     0.200
    80.094     5.503     0.200
    80.125     5.514     0.200
    80.117     5.506     0.200
    79.926     5.514     0.200
    80.273     5.520     0.200
    80.195     5.570     0.200
    81.121     5.605     0.200
    81.715     5.635     0.200
    82.426     5.631     0.200
    81.324     5.658     0.200
    85.023     5.765     0.200
    84.332     5.816     0.200
    84.441     5.847     0.200
    84.523     5.849     0.200
    85.484     5.856     0.200
    85.078     5.863     0.200
    86.379     5.953     0.200
    88.152     6.038     0.200
    87.629     6.048     0.200
    88.164     6.070     0.200
    88.227     6.068     0.200
    87.625     6.069     0.200
    89.824     6.162     0.200
    90.066     6.201     0.200
    89.426     6.204     0.200
    89.711     6.204     0.200
    89.824     6.249     0.200
    90.023     6.267     0.200
    91.625     6.308     0.200
    91.523     6.308     0.200
    91.953     6.307     0.200
    91.410     6.308     0.200
    90.887     6.308     0.200
    91.820     6.334     0.200
    92.324     6.327     0.200
    92.172     6.360     0.200
    93.125     6.366     0.200
    92.590     6.428     0.200
    93.484     6.455     0.200
    93.340     6.467     0.200
    94.625     6.545     0.200
    96.926     6.596     0.200
    95.125     6.610     0.200
    96.523     6.615     0.200
    95.375     6.646     0.200
    95.336     6.674     0.200
   102.926     7.125     0.200
   103.426     7.141     0.200
   101.844     7.164     0.200
   105.324     7.201     0.200
   104.926     7.248     0.200
   104.574     7.248     0.200
   105.824     7.312     0.200
   106.426     7.409     0.200
   108.492     7.586     0.200
   108.926     7.586     0.200
   109.613     7.671     0.200
   112.727     7.759     0.200
   113.926     8.016     0.200
   117.227     8.110     0.200
   126.234     8.758     0.200
   133.324     9.262     0.200
   136.926     9.595     0.200
   144.523    10.063     0.200
   144.324    10.118     0.200
   144.125    10.186     0.200
   153.176    10.712     0.200
   159.625    11.011     0.200
   157.125    11.029     0.200
   159.727    11.198     0.200
   162.426    11.333     0.200
   168.023    11.748     0.200
   171.324    11.910     0.200
   170.426    11.920     0.200
   177.324    12.569     0.200
   178.324    12.699     0.200
   177.426    12.699     0.200
   186.625    13.272     0.200
   192.227    13.800     0.200
   194.590    13.912     0.200
   194.023    13.912     0.200
   196.727    14.197     0.200
   202.625    14.442     0.200
   210.523    15.102     0.200
   223.824    16.232     0.200
   223.996    16.232     0.200
   237.125    17.388     0.200
   243.523    17.794     0.200
   248.227    18.009     0.200
   259.926    19.050     0.200
   263.926    19.546     0.200
     7.492     0.188     0.200
     8.092     0.240     0.200
    11.791     0.547     0.200
    12.691     0.610     0.200
    12.592     0.637     0.200
    13.092     0.665     0.200
    14.592     0.767     0.200
    21.891     1.283     0.200
    20.992     1.273     0.200
    21.221     1.273     0.200
    23.191     1.312     0.200
    22.771     1.312     0.200
    27.951     1.720     0.200
    37.682     2.495     0.200
    41.111     2.756     0.200
    47.131     3.119     0.200
    49.088     3.310     0.200
    49.379     3.310     0.200
    51.820     3.501     0.200
    52.533     3.572     0.200
    53.943     3.650     0.200
    54.670     3.694     0.200
    55.660     3.757     0.200
    55.699     3.764     0.200
    56.625     3.852     0.200
    57.840     3.927     0.200
    58.738     3.991     0.200
    60.689     4.134     0.200
    60.869     4.157     0.200
    61.898     4.216     0.200
    62.521     4.266     0.200
    64.031     4.285     0.200
    63.406     4.331     0.200
    64.660     4.406     0.200
    65.031     4.444     0.200
    66.199     4.534     0.200
    67.244     4.605     0.200
    67.699     4.623     0.200
    67.670     4.624     0.200
    67.793     4.627     0.200
    68.641     4.646     0.200
    69.539     4.689     0.200
    70.080     4.796     0.200
    70.660     4.817     0.200
    70.346     4.830     0.200
    70.672     4.843     0.200
    72.127     4.906     0.200
    72.420     4.934     0.200
    72.891     5.000     0.200
    73.691     5.118     0.200
    76.111     5.185     0.200
    75.660     5.197     0.200
    77.660     5.275     0.200
    78.660     5.316     0.200
    78.055     5.344     0.200
    77.889     5.357     0.200
    78.053     5.392     0.200
    79.248     5.448     0.200
    79.361     5.489     0.200
    80.182     5.542     0.200
    83.611     5.709     0.200
    84.391     5.709     0.200
    83.592     5.709     0.200
    83.523     5.710     0.200
    84.092     5.710     0.200
    84.027     5.833     0.200
    85.660     5.915     0.200
    86.188     5.937     0.200
    86.660     5.956     0.200
    88.770     6.121     0.200
    88.957     6.179     0.200
    89.031     6.208     0.200
    93.246     6.448     0.200
    93.666     6.492     0.200
    94.754     6.506     0.200
   101.391     7.003     0.200
   131.791     9.242     0.200
   162.191    11.435     0.200
   164.992    11.499     0.200
   170.191    11.743     0.200
   170.691    12.105     0.200
   171.721    12.105     0.200
   181.791    12.883     0.200
   186.775    13.334     0.200
   187.291    13.334     0.200
   187.281    13.335     0.200
   203.992    14.616     0.200
   218.652    15.676     0.200
   221.326    15.847     0.200
   251.492    18.201     0.200
   266.891    19.552     0.200
     9.748     0.364     0.200
     9.648     0.359     0.200
    10.348     0.434     0.200
    13.447     0.661     0.200
    14.148     0.725     0.200
    16.049     0.865     0.200
    16.549     0.896     0.200
    20.223     1.118     0.200
    20.037     1.118     0.200
    23.248     1.377     0.200
    23.748     1.387     0.200
    24.068     1.472     0.200
    35.668     2.307     0.200
    39.898     2.636     0.200
    47.549     3.191     0.200
    47.865     3.220     0.200
    50.158     3.317     0.200
    50.246     3.384     0.200
    51.619     3.502     0.200
    52.430     3.544     0.200
    53.227     3.606     0.200
    54.256     3.683     0.200
    54.736     3.720     0.200
    55.217     3.720     0.200
    55.752     3.787     0.200
    56.396     3.822     0.200
    57.016     3.862     0.200
    60.229     4.084     0.200
    60.227     4.088     0.200
    60.217     4.108     0.200
    60.217     4.107     0.200
    61.709     4.208     0.200
    62.016     4.231     0.200
    63.107     4.302     0.200
    63.217     4.299     0.200
    63.211     4.346     0.200
    64.396     4.395     0.200
    65.621     4.477     0.200
    66.828     4.488     0.200
    66.217     4.508     0.200
    66.893     4.548     0.200
    66.357     4.555     0.200
    66.506     4.584     0.200
    68.127     4.661     0.200
    68.445     4.676     0.200
    68.689     4.702     0.200
    69.217     4.738     0.200
    69.760     4.779     0.200
    70.676     4.790     0.200
    70.953     4.832     0.200
    70.637     4.834     0.200
    71.258     4.848     0.200
    71.258     4.881     0.200
    72.189     4.943     0.200
    72.547     4.980     0.200
    73.496     5.033     0.200
    73.836     5.071     0.200
    76.285     5.230     0.200
    76.297     5.240     0.200
    76.191     5.240     0.200
    77.227     5.252     0.200
    78.217     5.325     0.200
    78.074     5.374     0.200
    77.988     5.376     0.200
    78.799     5.443     0.200
    79.008     5.443     0.200
    79.588     5.497     0.200
    80.355     5.545     0.200
    81.191     5.591     0.200
    83.982     5.819     0.200
    84.406     5.839     0.200
    84.723     5.838     0.200
    85.246     5.868     0.200
    86.062     5.917     0.200
    85.928     5.910     0.200
    86.447     5.910     0.200
    86.248     5.911     0.200
    87.271     6.014     0.200
    87.637     6.050     0.200
    88.719     6.180     0.200
    92.201     6.381     0.200
    92.223     6.389     0.200
    92.520     6.397     0.200
    92.881     6.440     0.200
    97.709     6.842     0.200
   103.947     7.273     0.200
   157.572    10.900     0.200
   168.848    11.749     0.200
   200.688    14.507     0.200
   260.049    19.144     0.200
     8.320     0.037     0.200
     9.984     0.332     0.200
    10.828     0.406     0.200
    10.961     0.424     0.200
    14.250     0.736     0.200
    14.320     0.743     0.200
    16.773     0.913     0.200
    18.055     0.964     0.200
    20.414     1.118     0.200
    19.070     1.097     0.200
    23.031     1.379     0.200
    28.875     1.772     0.200
    29.172     1.772     0.200
    30.102     1.896     0.200
    41.195     2.741     0.200
    41.969     2.741     0.200
    73.109     4.948     0.200
    73.969     4.948     0.200
    75.805     5.208     0.200
    76.070     5.208     0.200
    77.680     5.314     0.200
    82.773     5.719     0.200
    82.820     5.719     0.200
    82.812     5.776     0.200
    92.031     6.397     0.200
    93.172     6.397     0.200
    93.805     6.399     0.200
    93.094     6.400     0.200
    93.273     6.400     0.200
    93.375     6.400     0.200
    93.570     6.400     0.200
    95.422     6.615     0.200
    95.375     6.642     0.200
    94.570     6.712     0.200
   105.773     7.373     0.200
   109.953     7.647     0.200
   124.859     8.850     0.200
   155.984    10.847     0.200
   155.172    11.073     0.200
   163.820    11.414     0.200
   173.172    12.129     0.200
   171.102    12.274     0.200
   176.648    12.552     0.200
   180.570    12.685     0.200
   178.344    12.831     0.200
   203.078    14.598     0.200
   249.672    18.164     0.200
   256.781    18.894     0.200
   261.469    19.199     0.200
     7.281     0.132     0.200
     8.859     0.306     0.200
    11.699     0.541     0.200
    11.770     0.546     0.200
    12.531     0.604     0.200
    13.008     0.648     0.200
    14.961     0.766     0.200
    15.109     0.780     0.200
    17.461     0.970     0.200
    18.320     1.001     0.200
    18.211     1.001     0.200
    18.520     1.001     0.200
    19.461     1.077     0.200
    21.430     1.243     0.200
    22.289     1.254     0.200
    22.789     1.332     0.200
    27.961     1.767     0.200
    29.941     1.816     0.200
    30.879     1.908     0.200
    31.219     1.908     0.200
    32.980     2.046     0.200
    33.840     2.135     0.200
    35.059     2.222     0.200
    34.598     2.224     0.200
    35.309     2.294     0.200
    36.281     2.306     0.200
    37.020     2.385     0.200
    40.289     2.650     0.200
    42.309     2.709     0.200
    41.410     2.723     0.200
    41.488     2.746     0.200
    42.020     2.746     0.200
    41.609     2.746     0.200
    44.730     2.885     0.200
    43.969     2.929     0.200
    44.148     2.947     0.200
    46.461     3.141     0.200
    48.551     3.147     0.200
    49.180     3.263     0.200
    52.578     3.478     0.200
    52.801     3.524     0.200
    53.551     3.556     0.200
    55.918     3.689     0.200
    56.660     3.747     0.200
    55.691     3.795     0.200
    58.809     4.052     0.200
    60.410     4.088     0.200
    62.000     4.184     0.200
    70.758     4.749     0.200
    70.781     4.817     0.200
    71.918     4.817     0.200
    71.020     4.912     0.200
    75.520     5.183     0.200
    75.820     5.183     0.200
    75.699     5.200     0.200
    76.121     5.200     0.200
    75.418     5.200     0.200
    80.121     5.431     0.200
    81.430     5.580     0.200
    82.668     5.686     0.200
    82.270     5.686     0.200
    82.789     5.742     0.200
    86.930     5.990     0.200
    88.668     5.999     0.200
    91.270     6.267     0.200
    91.520     6.267     0.200
    91.121     6.267     0.200
    91.430     6.267     0.200
    91.320     6.266     0.200
    91.719     6.267     0.200
    93.020     6.317     0.200
    92.000     6.323     0.200
    92.051     6.380     0.200
    92.918     6.380     0.200
    91.898     6.405     0.200
    97.594     6.845     0.200
    97.961     6.845     0.200
    98.520     6.845     0.200
   100.590     7.063     0.200
   101.219     7.063     0.200
   105.918     7.237     0.200
   125.320     8.717     0.200
   135.320     9.380     0.200
   139.410     9.525     0.200
   138.020     9.717     0.200
   146.520    10.364     0.200
   154.020    10.711     0.200
   160.121    11.163     0.200
   161.457    11.312     0.200
   159.301    11.312     0.200
   158.918    11.312     0.200
   163.918    11.524     0.200
   169.320    11.881     0.200
   168.281    11.881     0.200
   173.320    12.069     0.200
   180.219    12.654     0.200
   180.820    12.735     0.200
   189.820    13.337     0.200
   187.719    13.365     0.200
   193.254    13.932     0.200
   194.320    13.932     0.200
   194.320    13.933     0.200
   204.078    14.615     0.200
   205.621    14.619     0.200
   209.320    14.875     0.200
   224.359    16.271     0.200
   235.820    17.104     0.200
   250.820    18.185     0.200
   255.660    18.777     0.200
   256.219    18.777     0.200
   264.418    19.225     0.200
   266.418    19.605     0.200
     9.820     0.304     0.200
    10.750     0.402     0.200
    11.383     0.454     0.200
    13.852     0.650     0.200
    14.227     0.695     0.200
    15.938     0.844     0.200
    17.109     0.909     0.200
    18.633     1.030     0.200
    22.148     1.289     0.200
    22.359     1.316     0.200
    23.102     1.347     0.200
    22.547     1.388     0.200
    22.781     1.388     0.200
    23.023     1.388     0.200
    24.117     1.437     0.200
    36.773     2.454     0.200
    37.820     2.454     0.200
    68.109     4.754     0.200
    69.758     4.754     0.200
    73.812     5.087     0.200
    73.797     5.087     0.200
    74.039     5.139     0.200
    83.664     5.635     0.200
    82.961     5.636     0.200
    83.430     5.636     0.200
    83.570     5.637     0.200
    84.664     5.865     0.200
    91.219     6.360     0.200
    90.773     6.389     0.200
   143.688     9.938     0.200
   144.383     9.938     0.200
   147.023    10.419     0.200
   153.672    10.550     0.200
   154.672    11.023     0.200
   158.969    11.360     0.200
   185.047    13.106     0.200
   197.133    14.268     0.200
   202.281    14.268     0.200
   198.070    14.271     0.200
   205.469    14.699     0.200
   215.523    15.454     0.200
   235.773    16.849     0.200
   243.969    17.862     0.200
   247.211    18.045     0.200
   263.773    19.333     0.200
     7.820     0.239     0.200
     9.438     0.404     0.200
    10.789     0.512     0.200
    11.352     0.531     0.200
    13.781     0.731     0.200
    15.750     0.867     0.200
    19.359     1.115     0.200
    19.586     1.115     0.200
    19.914     1.115     0.200
    21.141     1.190     0.200
    20.336     1.166     0.200
    23.078     1.332     0.200
    21.898     1.300     0.200
    26.445     1.666     0.200
    26.586     1.666     0.200
    42.445     2.840     0.200
    43.188     2.840     0.200
    42.742     2.840     0.200
    69.781     4.718     0.200
    70.188     4.718     0.200
    69.898     4.718     0.200
    74.211     5.085     0.200
    74.492     5.085     0.200
    76.500     5.286     0.200
    76.789     5.286     0.200
    78.141     5.322     0.200
    78.289     5.322     0.200
    77.102     5.322     0.200
    83.438     5.756     0.200
    83.000     5.756     0.200
    83.172     5.811     0.200
    89.852     6.174     0.200
    90.086     6.174     0.200
    89.688     6.174     0.200
    90.836     6.173     0.200
    90.594     6.174     0.200
    92.492     6.400     0.200
    92.297     6.428     0.200
    92.922     6.460     0.200
    98.391     6.903     0.200
    98.141     6.903     0.200
    98.898     6.903     0.200
   101.586     7.076     0.200
   123.000     8.624     0.200
   123.891     8.624     0.200
   138.188     9.726     0.200
   148.539    10.413     0.200
   148.586    10.456     0.200
   151.391    10.636     0.200
   151.688    10.636     0.200
   160.789    11.281     0.200
   161.320    11.313     0.200
   171.086    11.899     0.200
   170.336    11.899     0.200
   167.891    11.899     0.200
   171.289    12.117     0.200
   177.688    12.619     0.200
   179.391    12.619     0.200
   178.891    12.619     0.200
   177.289    12.620     0.200
   181.891    12.846     0.200
   188.891    13.367     0.200
   194.289    13.868     0.200
   193.992    13.868     0.200
   194.320    13.869     0.200
   197.500    13.942     0.200
   207.500    14.704     0.200
   204.016    14.713     0.200
   206.391    14.713     0.200
   206.047    14.713     0.200
   205.688    14.717     0.200
   210.391    14.984     0.200
   223.852    16.218     0.200
   224.891    16.218     0.200
   227.891    16.347     0.200
   242.789    17.723     0.200
   251.188    18.286     0.200
   257.016    18.829     0.200
   265.688    19.327     0.200
     7.516     0.053     0.200
     9.477     0.348     0.200
    10.125     0.399     0.200
    10.336     0.426     0.200
    13.086     0.624     0.200
    14.258     0.739     0.200
    14.242     0.738     0.200
    16.883     0.922     0.200
    17.492     0.961     0.200
    17.266     0.961     0.200
    17.656     0.968     0.200
    19.102     1.098     0.200
    20.188     1.112     0.200
    23.266     1.384     0.200
    30.062     1.897     0.200
    41.367     2.756     0.200
    73.367     4.949     0.200
    77.461     5.316     0.200
    83.164     5.735     0.200
    93.266     6.403     0.200
    92.930     6.404     0.200
    94.617     6.609     0.200
    95.266     6.637     0.200
     9.543     0.438     0.200
    12.883     0.653     0.200
    15.043     0.838     0.200
    18.934     1.099     0.200
    25.447     1.563     0.200
    25.572     1.563     0.200
    25.773     1.563     0.200
    46.172     3.089     0.200
    61.582     4.151     0.200
    62.172     4.151     0.200
    66.434     4.518     0.200
    66.572     4.518     0.200
    66.773     4.518     0.200
    69.752     4.767     0.200
    70.773     4.767     0.200
    71.072     4.767     0.200
    78.242     5.456     0.200
    79.672     5.456     0.200
    82.172     5.609     0.200
    82.373     5.609     0.200
    82.633     5.609     0.200
    82.863     5.609     0.200
    82.760     5.610     0.200
    83.623     5.819     0.200
    83.793     5.872     0.200
    85.398     5.908     0.200
    84.832     5.936     0.200
    85.002     5.936     0.200
    96.732     6.612     0.200
    96.172     6.612     0.200
    97.273     6.612     0.200
   116.463     8.060     0.200
   116.172     8.060     0.200
   117.473     8.060     0.200
   133.873     9.470     0.200
   135.373     9.581     0.200
   155.434    11.022     0.200
   156.848    11.022     0.200
   168.273    11.682     0.200
   172.572    12.042     0.200
   187.072    13.203     0.200
   190.473    13.201     0.200
   186.822    13.353     0.200
   187.473    13.353     0.200
   187.512    13.354     0.200
   214.072    15.315     0.200
   219.492    15.732     0.200
   219.273    15.732     0.200
   219.172    15.732     0.200
   223.947    16.056     0.200
   223.572    16.056     0.200
   234.373    16.896     0.200
   254.773    18.537     0.200
   267.373    19.594     0.200
   281.273    20.923     0.200
    10.289     0.459     0.200
    12.109     0.609     0.200
    12.234     0.598     0.200
    12.109     0.595     0.200
    14.859     0.802     0.200
    16.289     0.883     0.200
    16.508     0.895     0.200
    22.430     1.262     0.200
    22.234     1.289     0.200
    22.820     1.272     0.200
    22.531     1.272     0.200
    21.578     1.259     0.200
    27.320     1.685     0.200
    27.625     1.685     0.200
    45.930     3.037     0.200
    69.555     4.734     0.200
    70.227     4.734     0.200
    70.539     4.734     0.200
    74.227     5.104     0.200
    74.930     5.104     0.200
    75.125     5.104     0.200
    77.891     5.294     0.200
    78.727     5.294     0.200
    79.875     5.491     0.200
    80.227     5.491     0.200
    80.391     5.491     0.200
    86.727     5.969     0.200
    85.781     5.969     0.200
    87.109     6.024     0.200
    90.352     6.207     0.200
    90.727     6.207     0.200
    90.984     6.207     0.200
    91.047     6.207     0.200
    91.234     6.208     0.200
    91.477     6.310     0.200
    90.766     6.338     0.200
    91.328     6.338     0.200
    90.375     6.338     0.200
    96.570     6.669     0.200
    97.039     6.669     0.200
    97.336     6.800     0.200
    96.055     6.800     0.200
   105.625     7.226     0.200
   124.172     8.656     0.200
   123.625     8.656     0.200
   127.930     8.656     0.200
   144.625    10.226     0.200
   144.531    10.226     0.200
   155.078    10.713     0.200
   164.867    11.500     0.200
   172.531    12.099     0.200
   180.875    12.666     0.200
   180.930    12.692     0.200
   178.930    12.692     0.200
   187.531    13.354     0.200
   196.328    13.574     0.200
   196.375    13.966     0.200
   206.516    14.701     0.200
   230.781    16.535     0.200
   238.328    16.922     0.200
   266.227    19.513     0.200
    10.404     0.455     0.200
    12.385     0.613     0.200
    12.145     0.593     0.200
    12.244     0.602     0.200
    15.184     0.805     0.200
    16.273     0.884     0.200
    16.564     0.893     0.200
    22.664     1.266     0.200
    21.645     1.258     0.200
    22.533     1.292     0.200
    22.703     1.277     0.200
    22.359     1.277     0.200
    27.545     1.682     0.200
    27.273     1.682     0.200
    46.084     3.042     0.200
    70.104     4.731     0.200
    70.533     4.731     0.200
    70.414     4.731     0.200
    74.795     5.101     0.200
    75.234     5.101     0.200
    74.494     5.101     0.200
    76.895     5.290     0.200
    79.895     5.496     0.200
    80.635     5.496     0.200
    86.514     5.973     0.200
    85.904     6.028     0.200
    90.533     6.204     0.200
    91.135     6.204     0.200
    90.805     6.204     0.200
    90.184     6.205     0.200
    92.010     6.305     0.200
    91.744     6.333     0.200
    97.635     6.801     0.200
    99.045     6.905     0.200
   104.135     7.224     0.200
   125.475     8.653     0.200
   125.203     8.653     0.200
   144.635    10.221     0.200
   162.734    11.393     0.200
   179.354    12.690     0.200
   195.533    13.965     0.200
   230.309    16.536     0.200
   256.033    18.479     0.200
   268.334    19.517     0.200
    11.160     0.509     0.200
    11.820     0.564     0.200
    12.711     0.634     0.200
    13.250     0.670     0.200
    14.711     0.746     0.200
    17.441     0.960     0.200
    17.621     0.962     0.200
    22.441     1.236     0.200
    28.469     1.748     0.200
    71.621     4.794     0.200
    76.160     5.164     0.200
    80.191     5.529     0.200
    87.492     6.017     0.200
    88.410     6.018     0.200
    87.871     6.073     0.200
    91.332     6.271     0.200
    92.191     6.271     0.200
    92.164     6.271     0.200
    97.883     6.726     0.200
   162.461    11.369     0.200
   254.559    18.497     0.200
    11.000     0.358     0.200
    11.891     0.432     0.200
    12.578     0.492     0.200
    12.352     0.491     0.200
    12.352     0.507     0.200
    15.750     0.798     0.200
    16.578     0.860     0.200
    18.273     0.993     0.200
    17.969     0.955     0.200
    22.109     1.292     0.200
    24.133     1.364     0.200
    26.547     1.589     0.200
    25.969     1.589     0.200
    26.203     1.589     0.200
    35.953     2.260     0.200
    35.562     2.260     0.200
    35.852     2.260     0.200
    38.352     2.494     0.200
    68.648     4.585     0.200
    68.117     4.585     0.200
    68.461     4.585     0.200
    71.320     4.897     0.200
    71.906     4.897     0.200
    72.703     4.943     0.200
    73.047     4.943     0.200
    77.500     5.320     0.200
    78.891     5.280     0.200
    77.188     5.320     0.200
    77.602     5.374     0.200
    88.352     5.994     0.200
    88.117     5.994     0.200
    87.953     5.994     0.200
    88.461     5.994     0.200
    88.602     5.995     0.200
    88.297     5.995     0.200
    88.445     6.050     0.200
    87.711     6.050     0.200
    93.578     6.496     0.200
    93.750     6.524     0.200
   102.625     7.251     0.200
   102.750     7.251     0.200
   102.172     7.251     0.200
   106.547     7.522     0.200
   106.148     7.522     0.200
   132.852     9.353     0.200
   138.953     9.772     0.200
   141.547    10.086     0.200
   152.102    10.752     0.200
   156.750    10.808     0.200
   154.977    10.851     0.200
   159.453    11.181     0.200
   163.750    11.426     0.200
   163.352    11.426     0.200
   161.969    11.426     0.200
   167.148    11.649     0.200
   175.852    12.209     0.200
   174.352    12.349     0.200
   179.047    12.593     0.200
   180.352    12.921     0.200
   182.648    12.892     0.200
   190.078    13.547     0.200
   188.953    13.547     0.200
   188.953    13.548     0.200
   190.148    13.602     0.200
   190.852    13.681     0.200
   200.250    14.460     0.200
   201.750    14.367     0.200
   200.539    14.367     0.200
   202.109    14.367     0.200
   218.852    15.860     0.200
   219.750    15.860     0.200
   220.742    15.884     0.200
   241.148    17.719     0.200
   246.750    17.950     0.200
   259.547    19.144     0.200
   260.453    19.172     0.200
   259.648    19.246     0.200
   261.352    19.402     0.200
   276.148    20.681     0.200
     7.445     0.225     0.200
    10.727     0.500     0.200
    10.445     0.476     0.200
    11.758     0.571     0.200
    12.336     0.596     0.200
    13.203     0.678     0.200
    13.438     0.681     0.200
    16.727     0.925     0.200
    17.867     1.007     0.200
    20.305     1.117     0.200
    20.617     1.141     0.200
    20.727     1.173     0.200
    22.602     1.342     0.200
    28.586     1.803     0.200
    30.023     1.839     0.200
    44.617     2.929     0.200
    72.086     4.856     0.200
    76.281     5.225     0.200
    78.617     5.392     0.200
    78.797     5.429     0.200
    85.141     5.946     0.200
    91.703     6.322     0.200
    92.484     6.322     0.200
    92.180     6.323     0.200
    91.562     6.323     0.200
    96.312     6.719     0.200
     7.602     0.243     0.200
    10.320     0.434     0.200
    11.117     0.513     0.200
    12.586     0.622     0.200
    13.539     0.727     0.200
    19.133     1.124     0.200
    19.477     1.124     0.200
    19.328     1.124     0.200
    20.680     1.213     0.200
    40.180     2.641     0.200
    40.930     2.641     0.200
    42.242     2.846     0.200
    42.727     2.846     0.200
    61.328     4.132     0.200
    61.938     4.132     0.200
    61.031     4.132     0.200
    65.781     4.493     0.200
    66.633     4.493     0.200
    69.680     4.815     0.200
    75.031     5.179     0.200
    73.797     5.179     0.200
    75.250     5.179     0.200
    79.562     5.521     0.200
    79.820     5.521     0.200
    80.227     5.521     0.200
    81.031     5.557     0.200
    80.352     5.557     0.200
    82.047     5.557     0.200
    81.531     5.557     0.200
    81.977     5.557     0.200
    81.930     5.583     0.200
    82.531     5.631     0.200
    87.352     6.047     0.200
    85.898     6.076     0.200
    91.047     6.297     0.200
   109.781     7.575     0.200
   148.031    10.382     0.200
   152.031    10.700     0.200
   160.727    10.981     0.200
   171.727    11.732     0.200
   173.430    12.255     0.200
   181.430    12.840     0.200
   186.930    12.897     0.200
   184.531    12.988     0.200
   185.602    13.197     0.200
   185.602    13.198     0.200
   206.727    14.778     0.200
   207.602    14.686     0.200
   211.430    15.087     0.200
   216.031    15.547     0.200
   219.898    15.775     0.200
   219.531    15.775     0.200
   231.828    16.711     0.200
   250.430    18.278     0.200
   253.547    18.460     0.200
   255.406    18.693     0.200
   266.930    19.673     0.200
   277.328    20.629     0.200
     8.492     0.217     0.200
    11.273     0.491     0.200
    12.453     0.561     0.200
    13.473     0.650     0.200
    14.801     0.762     0.200
    17.395     0.942     0.200
    17.742     0.974     0.200
    22.512     1.301     0.200
    22.312     1.337     0.200
    21.984     1.337     0.200
    23.082     1.380     0.200
    24.301     1.436     0.200
    38.031     2.527     0.200
    38.164     2.527     0.200
    40.645     2.669     0.200
    40.371     2.669     0.200
    63.602     4.248     0.200
    63.293     4.248     0.200
    67.754     4.600     0.200
    67.594     4.600     0.200
    69.922     4.838     0.200
    70.402     4.838     0.200
    72.312     4.995     0.200
    72.621     4.995     0.200
    74.969     5.176     0.200
    74.973     5.176     0.200
    75.461     5.176     0.200
    82.473     5.630     0.200
    82.363     5.630     0.200
    82.703     5.630     0.200
    82.852     5.631     0.200
    82.984     5.631     0.200
    86.484     5.952     0.200
    90.461     6.305     0.200
    89.961     6.333     0.200
    90.062     6.333     0.200
   143.961     9.958     0.200
   143.824    10.042     0.200
   152.496    10.786     0.200
   180.824    12.683     0.200
   185.246    13.137     0.200
   183.223    13.138     0.200
   198.043    14.350     0.200
   199.352    14.350     0.200
   202.754    14.549     0.200
   202.363    14.549     0.200
   207.223    14.772     0.200
   237.324    16.931     0.200
   246.523    17.943     0.200
   248.934    18.133     0.200
   248.582    18.133     0.200
   250.621    18.366     0.200
   259.723    19.147     0.200
     9.532     0.341     0.200
    11.053     0.472     0.200
    12.103     0.552     0.200
    11.853     0.562     0.200
    13.272     0.657     0.200
    15.702     0.851     0.200
    17.817     1.006     0.200
    18.522     1.054     0.200
    20.793     1.201     0.200
    26.123     1.630     0.200
    33.753     2.105     0.200
    40.032     2.640     0.200
    69.043     4.664     0.200
    73.482     5.026     0.200
    73.862     5.070     0.200
    79.072     5.316     0.200
    79.692     5.520     0.200
    80.853     5.520     0.200
    80.293     5.520     0.200
    89.133     6.096     0.200
    89.081     6.097     0.200
    89.202     6.097     0.200
    92.668     6.466     0.200
    92.862     6.495     0.200
   157.279    11.077     0.200
   223.836    16.111     0.200
   248.492    18.095     0.200
     7.254     0.140     0.200
    10.184     0.452     0.200
    11.172     0.513     0.200
    13.152     0.669     0.200
    12.625     0.648     0.200
    13.152     0.682     0.200
    16.414     0.898     0.200
    19.414     1.058     0.200
    20.344     1.161     0.200
    17.895     1.029     0.200
    22.695     1.338     0.200
    29.125     1.823     0.200
    29.434     1.823     0.200
    29.234     1.823     0.200
    28.734     1.828     0.200
    28.953     1.828     0.200
    28.535     1.828     0.200
    43.344     2.842     0.200
    43.184     2.842     0.200
    71.832     4.881     0.200
    71.953     4.881     0.200
    71.492     4.881     0.200
    77.832     5.305     0.200
    76.402     5.249     0.200
    76.582     5.249     0.200
    76.184     5.249     0.200
    80.332     5.470     0.200
    78.812     5.470     0.200
    84.684     5.806     0.200
    84.922     5.806     0.200
    84.785     5.806     0.200
    92.332     6.341     0.200
    92.215     6.341     0.200
    91.953     6.341     0.200
    92.332     6.340     0.200
    92.844     6.340     0.200
    92.598     6.341     0.200
    92.164     6.341     0.200
    94.535     6.491     0.200
    94.332     6.491     0.200
    94.770     6.491     0.200
    93.883     6.516     0.200
    93.555     6.543     0.200
    93.684     6.543     0.200
    93.785     6.543     0.200
    93.934     6.543     0.200
    95.332     6.732     0.200
    98.633     6.927     0.200
    99.113     6.927     0.200
    99.984     6.927     0.200
    97.785     6.927     0.200
   132.832     9.376     0.200
   148.734    10.460     0.200
   156.703    10.808     0.200
   155.043    10.808     0.200
   155.832    10.808     0.200
   159.734    11.176     0.200
   162.332    11.303     0.200
   167.535    11.438     0.200
   161.332    11.449     0.200
   163.035    11.449     0.200
   164.172    11.449     0.200
   170.082    12.052     0.200
   173.035    12.019     0.200
   172.285    12.019     0.200
   174.734    12.201     0.200
   181.332    12.794     0.200
   183.332    12.784     0.200
   179.734    12.791     0.200
   180.035    12.791     0.200
   180.230    12.791     0.200
   180.504    12.791     0.200
   191.234    13.474     0.200
   191.434    13.774     0.200
   198.535    14.102     0.200
   196.910    14.039     0.200
   196.234    14.039     0.200
   196.262    14.041     0.200
   196.785    14.041     0.200
   201.844    14.544     0.200
   201.414    14.544     0.200
   206.434    14.797     0.200
   206.184    14.702     0.200
   203.625    14.702     0.200
   208.934    14.941     0.200
   212.234    15.234     0.200
   227.734    16.409     0.200
   227.035    16.387     0.200
   225.754    16.387     0.200
   226.832    16.387     0.200
   239.734    17.483     0.200
   246.832    17.971     0.200
   251.535    18.269     0.200
   257.434    18.928     0.200
   257.434    18.907     0.200
   260.160    19.146     0.200
   261.934    19.353     0.200
   265.434    19.492     0.200
   263.832    19.450     0.200
   268.633    19.729     0.200
    10.059     0.436     0.200
    11.227     0.530     0.200
    13.199     0.643     0.200
    12.699     0.638     0.200
    13.508     0.711     0.200
    16.887     0.948     0.200
    19.527     1.076     0.200
    19.773     1.107     0.200
    18.246     1.045     0.200
    20.648     1.136     0.200
    29.629     1.801     0.200
    43.598     2.904     0.200
    72.777     4.895     0.200
    78.039     5.370     0.200
    85.297     5.875     0.200
    85.086     5.875     0.200
    85.688     5.875     0.200
    93.059     6.360     0.200
    93.867     6.360     0.200
    93.359     6.361     0.200
    93.176     6.361     0.200
    94.918     6.690     0.200
   161.520    11.514     0.200
   161.707    11.514     0.200
   261.824    19.216     0.200
     7.641     0.176     0.200
    10.711     0.468     0.200
    11.586     0.542     0.200
    12.781     0.619     0.200
    13.227     0.670     0.200
    13.625     0.681     0.200
    16.375     0.899     0.200
    17.961     1.011     0.200
    19.570     1.088     0.200
    19.398     1.093     0.200
    20.727     1.174     0.200
    22.375     1.330     0.200
    29.180     1.809     0.200
    29.102     1.838     0.200
    42.695     2.877     0.200
    71.797     4.862     0.200
    76.336     5.230     0.200
    77.180     5.339     0.200
    84.523     5.837     0.200
    84.391     5.837     0.200
    91.852     6.325     0.200
    92.875     6.324     0.200
    91.734     6.325     0.200
    91.992     6.325     0.200
    93.422     6.485     0.200
    93.133     6.513     0.200
    93.766     6.524     0.200
    96.656     6.736     0.200
   148.320    10.495     0.200
   196.695    14.035     0.200
   227.820    16.498     0.200
   250.922    18.305     0.200
     7.211     0.198     0.200
     9.078     0.367     0.200
    10.406     0.473     0.200
    12.062     0.573     0.200
    11.852     0.573     0.200
    13.828     0.704     0.200
    14.688     0.780     0.200
    18.047     1.008     0.200
    18.742     1.017     0.200
    19.648     1.066     0.200
    19.375     1.077     0.200
    19.398     1.115     0.200
    28.242     1.731     0.200
    30.023     1.912     0.200
    43.344     2.891     0.200
    72.867     4.965     0.200
    77.539     5.334     0.200
    77.703     5.362     0.200
    78.727     5.538     0.200
    84.312     5.879     0.200
    93.047     6.431     0.200
    93.977     6.430     0.200
    93.352     6.431     0.200
    17.148     0.956     0.200
    18.477     1.038     0.200
    23.461     1.374     0.200
    30.008     1.808     0.200
    30.617     1.808     0.200
    29.992     1.834     0.200
    43.922     2.931     0.200
    44.367     2.931     0.200
    72.547     4.886     0.200
    76.969     5.255     0.200
    77.969     5.255     0.200
    78.508     5.397     0.200
    78.977     5.397     0.200
    85.766     5.901     0.200
    85.461     5.901     0.200
    84.906     5.901     0.200
    91.992     6.354     0.200
    93.781     6.354     0.200
    93.492     6.353     0.200
    91.680     6.354     0.200
    93.719     6.354     0.200
    94.047     6.503     0.200
    95.148     6.584     0.200
    97.648     6.687     0.200
    96.047     6.687     0.200
    97.672     6.852     0.200
   149.820    10.549     0.200
   163.516    11.225     0.200
   177.820    12.295     0.200
   183.219    12.867     0.200
   195.516    13.564     0.200
   197.219    14.081     0.200
   197.219    14.082     0.200
   206.992    14.788     0.200
   209.375    14.788     0.200
   228.117    16.438     0.200
   230.664    16.565     0.200
   251.719    18.354     0.200
   263.070    19.240     0.200
   265.617    19.415     0.200
     9.977     0.415     0.200
    10.898     0.493     0.200
    13.047     0.629     0.200
    13.172     0.670     0.200
    14.234     0.721     0.200
    17.398     0.942     0.200
    17.742     1.062     0.200
    20.648     1.122     0.200
    28.023     1.785     0.200
    30.242     1.862     0.200
    42.406     2.860     0.200
    77.492     5.327     0.200
    83.812     5.834     0.200
    84.828     5.834     0.200
    92.109     6.378     0.200
    93.344     6.377     0.200
    92.031     6.378     0.200
    92.133     6.378     0.200
    94.547     6.689     0.200
   150.812    10.477     0.200
   248.414    17.880     0.200
     6.998     0.163     0.200
     9.867     0.422     0.200
    10.808     0.502     0.200
    12.907     0.635     0.200
    13.128     0.661     0.200
    13.718     0.716     0.200
    16.928     0.940     0.200
    19.038     1.049     0.200
    18.438     1.057     0.200
    19.083     1.072     0.200
    20.458     1.128     0.200
    22.567     1.375     0.200
    29.248     1.791     0.200
    29.117     1.855     0.200
    43.657     2.868     0.200
    72.788     4.908     0.200
    77.147     5.277     0.200
    78.128     5.335     0.200
    84.758     5.841     0.200
    85.258     5.841     0.200
    84.947     5.841     0.200
    92.737     6.371     0.200
    93.121     6.372     0.200
    94.657     6.523     0.200
    94.268     6.551     0.200
   252.607    18.291     0.200
   261.883    19.185     0.200
   264.607    19.470     0.200
    19.545     1.142     0.200
    23.742     1.449     0.200
    41.865     2.706     0.200
    61.025     4.112     0.200
    65.904     4.469     0.200
    72.775     5.071     0.200
    77.502     5.399     0.200
    81.215     5.521     0.200
    80.064     5.521     0.200
    81.547     5.521     0.200
    88.264     6.181     0.200
    88.389     6.094     0.200
    87.814     6.123     0.200
    93.344     6.443     0.200
   111.354     7.662     0.200
   110.562     7.662     0.200
   111.295     7.816     0.200
   150.420    10.613     0.200
   168.734    11.894     0.200
   186.145    13.171     0.200
   184.225    13.116     0.200
   204.844    14.584     0.200
   215.865    15.455     0.200
   215.494    15.455     0.200
   216.439    15.486     0.200
   219.264    15.648     0.200
   218.457    15.648     0.200
    21.242     1.326     0.200
    36.543     2.391     0.200
    37.402     2.391     0.200
    42.195     2.806     0.200
    41.824     2.806     0.200
    64.473     4.359     0.200
    68.781     4.722     0.200
    68.902     4.722     0.200
    75.242     5.191     0.200
    75.039     5.191     0.200
    84.543     5.795     0.200
    84.125     5.795     0.200
    84.543     5.795     0.200
    91.645     6.332     0.200
    88.949     6.218     0.200
    88.812     6.218     0.200
    99.043     6.753     0.200
    97.434     6.753     0.200
    98.785     6.753     0.200
   105.770     7.470     0.200
   135.242     9.476     0.200
   147.945    10.227     0.200
   147.746    10.227     0.200
   147.562    10.227     0.200
   147.965    10.447     0.200
   165.031    11.564     0.200
   166.805    11.564     0.200
   171.844    11.935     0.200
   172.344    12.211     0.200
   171.891    12.211     0.200
   172.133    12.211     0.200
   177.074    12.598     0.200
   175.742    12.598     0.200
   179.895    12.882     0.200
   188.594    13.452     0.200
   206.121    14.674     0.200
   206.703    14.674     0.200
   209.641    15.064     0.200
   208.043    15.035     0.200
   220.242    15.799     0.200
   219.367    15.799     0.200
   219.824    15.799     0.200
END
# Pb arrivals
gmt psxy -: -R $projection -Sx -Wthin,blue -K -O << END >> $psfile
END
# P_ arrivals
gmt psxy -: -R $projection -Sx -Wthin,cyan -K -O << END >> $psfile
END
# Pg arrivals
gmt psxy -: -R $projection -Sx -Wthin,red -K -O << END >> $psfile
     7.146     0.206     0.200
     8.299     0.308     0.200
    12.299     0.627     0.200
    13.199     0.584     0.200
    13.499     0.690     0.200
    13.199     0.649     0.200
    24.799     1.310     0.200
    37.100     1.961     0.200
    45.899     2.543     0.200
     7.188     0.265     0.200
     9.891     0.459     0.200
    20.891     1.037     0.200
    25.391     1.386     0.200
    37.492     2.145     0.200
    54.391     3.161     0.200
     9.332     0.410     0.200
    14.133     0.749     0.200
    37.531     2.053     0.200
    39.531     2.165     0.200
     8.297     0.332     0.200
     6.355     0.196     0.200
    10.758     0.492     0.200
    15.156     0.821     0.200
     7.945     0.294     0.200
    11.039     0.513     0.200
    14.039     0.724     0.200
    14.945     0.762     0.200
    16.039     0.845     0.200
     6.312     0.104     0.200
     8.383     0.301     0.200
     8.703     0.320     0.200
     8.586     0.354     0.200
    22.930     1.272     0.200
     8.725     0.359     0.200
    22.814     1.277     0.200
     8.582     0.367     0.200
    23.391     1.282     0.200
    23.262     1.282     0.200
     7.117     0.226     0.200
    10.352     0.447     0.200
    11.375     0.551     0.200
    13.469     0.650     0.200
    13.109     0.622     0.200
    19.836     1.096     0.200
    21.039     1.142     0.200
END
# Sn arrivals
gmt psxy -: -R $projection -Sc -Wthin,green -K -O << END >> $psfile
    23.210     0.478     0.200
    20.410     0.432     0.200
    26.210     0.664     0.200
    30.110     0.936     0.200
    31.210     0.964     0.200
    33.210     1.057     0.200
    34.110     1.057     0.200
    33.210     1.103     0.200
    33.510     1.103     0.200
    31.210     1.050     0.200
    32.110     1.050     0.200
    37.210     1.183     0.200
    40.210     1.354     0.200
    40.710     1.354     0.200
    47.210     1.539     0.200
    52.210     1.648     0.200
    53.010     1.648     0.200
    52.210     1.720     0.200
    48.210     1.733     0.200
    48.610     1.733     0.200
    49.210     1.818     0.200
    51.210     1.920     0.200
    51.710     1.920     0.200
    57.210     2.028     0.200
    56.710     2.028     0.200
    58.210     2.136     0.200
    59.110     2.136     0.200
    57.210     2.129     0.200
    63.210     2.324     0.200
    64.110     2.324     0.200
    64.210     2.473     0.200
    64.510     2.473     0.200
    68.210     2.644     0.200
    72.210     2.669     0.200
    72.610     2.669     0.200
    76.210     2.909     0.200
    76.410     2.909     0.200
    82.210     3.040     0.200
    82.610     3.040     0.200
    78.210     3.041     0.200
    78.810     3.041     0.200
    81.210     3.069     0.200
    81.910     3.151     0.200
    93.210     3.307     0.200
    84.610     3.300     0.200
    85.210     3.312     0.200
    85.410     3.312     0.200
    89.210     3.366     0.200
    89.210     3.443     0.200
    89.510     3.443     0.200
   101.210     3.858     0.200
   101.710     3.858     0.200
    98.210     3.858     0.200
   102.210     3.916     0.200
   103.110     3.916     0.200
   113.210     4.293     0.200
   113.810     4.293     0.200
   113.210     4.353     0.200
   129.210     4.808     0.200
   130.210     5.003     0.200
   130.810     5.003     0.200
   140.210     5.274     0.200
   140.610     5.274     0.200
   142.210     5.551     0.200
   149.210     5.743     0.200
   149.810     5.743     0.200
   151.210     5.846     0.200
   151.510     5.846     0.200
   163.210     6.188     0.200
   162.210     6.427     0.200
   163.010     6.427     0.200
   170.210     6.543     0.200
   170.810     6.543     0.200
   195.210     7.447     0.200
   273.210    10.781     0.200
   273.910    10.781     0.200
   483.210    19.344     0.200
    15.120     0.243     0.200
    18.120     0.436     0.200
    26.120     0.778     0.200
    27.120     0.897     0.200
    28.120     0.855     0.200
    35.120     1.137     0.200
    38.120     1.414     0.200
    41.120     1.470     0.200
    38.120     1.498     0.200
    46.120     1.683     0.200
    50.120     1.783     0.200
    54.120     2.038     0.200
    63.120     2.078     0.200
    63.120     2.338     0.200
    73.120     2.527     0.200
   107.120     4.060     0.200
    13.383     0.132     0.200
    22.383     0.664     0.200
    21.383     0.637     0.200
    28.383     0.944     0.200
    26.383     0.752     0.200
    35.383     1.194     0.200
    31.383     1.081     0.200
    29.383     0.978     0.200
    43.383     1.506     0.200
    48.383     1.767     0.200
    45.383     1.634     0.200
    51.383     1.884     0.200
    42.383     1.650     0.200
    53.383     1.874     0.200
    64.383     2.335     0.200
    65.383     2.280     0.200
    83.383     3.071     0.200
    73.383     2.808     0.200
    81.383     3.013     0.200
   100.383     3.693     0.200
   126.383     4.635     0.200
   157.383     5.898     0.200
   221.383     8.498     0.200
   228.383     8.854     0.200
   253.383     9.833     0.200
   257.383     9.973     0.200
   264.383    10.268     0.200
   481.383    19.462     0.200
    12.203     0.165     0.200
    20.203     0.602     0.200
    22.203     0.659     0.200
    25.203     0.793     0.200
    29.203     0.976     0.200
    32.203     1.035     0.200
    45.203     1.511     0.200
    47.203     1.587     0.200
    49.203     1.709     0.200
    52.203     1.758     0.200
    54.203     1.846     0.200
    60.203     2.208     0.200
    61.203     2.195     0.200
    65.203     2.239     0.200
    66.203     2.363     0.200
    75.203     2.636     0.200
   114.203     4.203     0.200
    12.498     0.167     0.200
    20.498     0.614     0.200
    21.498     0.649     0.200
    25.498     0.792     0.200
    28.498     0.960     0.200
    30.498     0.986     0.200
    31.498     1.044     0.200
    44.498     1.500     0.200
    46.498     1.594     0.200
    48.498     1.702     0.200
    51.498     1.706     0.200
    50.498     1.749     0.200
    50.498     1.858     0.200
    60.498     2.197     0.200
    61.498     2.205     0.200
    76.498     2.648     0.200
    72.498     2.824     0.200
    82.498     2.981     0.200
    30.146     1.005     0.200
    40.146     1.528     0.200
    60.146     2.183     0.200
    63.146     2.338     0.200
    71.146     2.639     0.200
    73.146     2.849     0.200
   108.146     4.178     0.200
   138.146     5.199     0.200
    12.215     0.183     0.200
    20.215     0.617     0.200
    22.215     0.635     0.200
    25.215     0.807     0.200
    30.215     0.955     0.200
    32.215     1.038     0.200
    36.215     1.232     0.200
    39.215     1.351     0.200
    45.215     1.488     0.200
    41.215     1.515     0.200
    46.215     1.585     0.200
    52.215     1.613     0.200
    48.215     1.686     0.200
    49.215     1.734     0.200
    55.215     1.864     0.200
    59.215     1.981     0.200
    58.215     2.184     0.200
    65.215     2.203     0.200
    65.215     2.250     0.200
   113.215     4.226     0.200
    12.305     0.169     0.200
    23.305     0.636     0.200
    22.305     0.634     0.200
    25.305     0.788     0.200
    29.305     1.001     0.200
    31.305     1.061     0.200
    36.305     1.253     0.200
    44.305     1.510     0.200
    48.305     1.609     0.200
    48.305     1.694     0.200
    57.305     1.878     0.200
    69.305     2.586     0.200
    72.305     2.720     0.200
    73.305     2.836     0.200
   105.305     3.843     0.200
    11.944     0.130     0.200
    22.944     0.654     0.200
    24.944     0.718     0.200
    23.944     0.690     0.200
    27.944     0.898     0.200
    28.944     1.004     0.200
    33.944     1.137     0.200
    48.944     1.688     0.200
    47.944     1.730     0.200
    56.944     1.922     0.200
    56.944     1.998     0.200
    65.944     2.293     0.200
    68.944     2.335     0.200
    66.944     2.592     0.200
    73.944     2.821     0.200
   123.944     4.661     0.200
    12.062     0.180     0.200
    20.062     0.605     0.200
    25.062     0.727     0.200
    24.062     0.745     0.200
    29.062     0.853     0.200
    33.062     1.154     0.200
    41.062     1.387     0.200
    48.062     1.684     0.200
    49.062     1.695     0.200
    53.062     1.803     0.200
    57.062     1.965     0.200
    61.062     2.134     0.200
    67.062     2.320     0.200
    69.062     2.365     0.200
    69.062     2.643     0.200
    78.062     2.759     0.200
    20.353     0.455     0.200
    25.353     0.647     0.200
    25.353     0.728     0.200
    30.353     0.993     0.200
    32.353     0.960     0.200
    31.353     0.952     0.200
    37.353     1.289     0.200
    39.353     1.362     0.200
    38.353     1.359     0.200
    47.353     1.622     0.200
    47.353     1.662     0.200
    53.353     2.012     0.200
    58.353     2.082     0.200
    79.353     2.824     0.200
    81.353     2.891     0.200
    81.353     3.185     0.200
    91.353     3.324     0.200
    84.353     3.351     0.200
    20.516     0.500     0.200
    21.516     0.642     0.200
    25.516     0.819     0.200
    30.312     1.001     0.200
    30.516     1.027     0.200
    30.516     1.041     0.200
    34.516     1.105     0.200
    35.516     1.194     0.200
    40.516     1.351     0.200
    45.516     1.517     0.200
    45.516     1.595     0.200
    51.516     1.655     0.200
    49.516     1.688     0.200
    53.516     1.758     0.200
    56.516     1.783     0.200
    56.516     1.972     0.200
    56.516     2.006     0.200
    61.516     2.067     0.200
    68.516     2.513     0.200
    67.414     2.578     0.200
    76.516     2.781     0.200
    14.027     0.190     0.200
    20.027     0.545     0.200
    22.027     0.600     0.200
    25.727     0.804     0.200
    27.027     0.838     0.200
    34.027     1.114     0.200
    35.027     1.191     0.200
    41.027     1.351     0.200
    40.027     1.360     0.200
    41.027     1.412     0.200
    43.027     1.439     0.200
    50.027     1.730     0.200
    52.027     1.775     0.200
    53.027     1.827     0.200
    52.027     1.834     0.200
    55.027     1.961     0.200
    63.027     2.082     0.200
    65.027     2.196     0.200
    60.727     2.310     0.200
    70.027     2.350     0.200
    67.027     2.486     0.200
    73.027     2.687     0.200
    90.027     3.387     0.200
    17.008     0.401     0.200
    20.008     0.475     0.200
    26.008     0.798     0.200
    29.508     0.984     0.200
    31.008     1.024     0.200
    32.008     1.032     0.200
    35.008     1.130     0.200
    39.008     1.335     0.200
    44.008     1.542     0.200
    44.008     1.618     0.200
    46.008     1.612     0.200
    45.008     1.630     0.200
    51.008     1.709     0.200
    52.008     1.732     0.200
    59.008     1.983     0.200
    62.008     2.043     0.200
    60.008     2.289     0.200
    67.008     2.330     0.200
    68.008     2.464     0.200
    68.008     2.487     0.200
    66.508     2.557     0.200
    82.008     3.127     0.200
   109.008     4.167     0.200
   111.906     4.274     0.200
    19.899     0.627     0.200
    42.399     1.495     0.200
    48.600     1.705     0.200
    70.699     2.533     0.200
    72.299     2.739     0.200
    23.234     0.616     0.200
    25.734     0.699     0.200
    27.635     0.752     0.200
    29.334     0.921     0.200
    32.734     1.049     0.200
    38.635     1.256     0.200
    38.334     1.299     0.200
    39.035     1.282     0.200
    41.135     1.385     0.200
    44.535     1.515     0.200
    44.734     1.566     0.200
    53.635     1.848     0.200
    48.934     1.740     0.200
    48.234     1.765     0.200
    52.234     1.821     0.200
    48.934     1.783     0.200
    52.434     1.883     0.200
    58.535     1.985     0.200
    60.734     2.127     0.200
    59.535     2.121     0.200
    63.535     2.395     0.200
    67.934     2.445     0.200
    65.535     2.431     0.200
    67.635     2.460     0.200
    71.035     2.606     0.200
    70.035     2.626     0.200
    72.734     2.736     0.200
    76.635     2.849     0.200
    79.334     3.003     0.200
    81.234     3.097     0.200
    86.434     3.220     0.200
    80.234     3.131     0.200
    81.934     3.203     0.200
    85.434     3.253     0.200
    84.734     3.270     0.200
    89.734     3.462     0.200
    95.734     3.663     0.200
    99.035     3.755     0.200
   100.734     3.774     0.200
   105.734     4.086     0.200
   108.834     4.195     0.200
   112.234     4.279     0.200
   125.535     4.639     0.200
   126.535     4.864     0.200
   129.635     5.059     0.200
   141.734     5.310     0.200
   137.434     5.384     0.200
   145.734     5.665     0.200
   149.734     5.724     0.200
   149.734     5.768     0.200
   149.234     5.867     0.200
   147.734     5.782     0.200
   148.734     5.930     0.200
   150.535     5.950     0.200
   157.734     6.023     0.200
   155.734     6.143     0.200
   163.934     6.258     0.200
   169.234     6.451     0.200
   163.734     6.517     0.200
   172.734     6.529     0.200
   174.234     6.614     0.200
   183.234     6.957     0.200
   205.734     7.888     0.200
   201.535     8.016     0.200
   216.234     8.484     0.200
   215.734     8.420     0.200
   227.734     8.777     0.200
   279.234    11.039     0.200
   286.734    11.221     0.200
   298.734    11.728     0.200
   355.734    14.108     0.200
   467.734    18.765     0.200
    29.992     0.907     0.200
    33.289     1.016     0.200
    53.688     1.885     0.200
    16.758     0.330     0.200
    20.258     0.516     0.200
    25.258     0.656     0.200
    29.758     0.929     0.200
    28.758     0.944     0.200
    31.258     0.994     0.200
    33.359     1.081     0.200
    34.656     1.120     0.200
    35.758     1.180     0.200
    35.656     1.203     0.200
    41.059     1.385     0.200
    44.656     1.509     0.200
    44.859     1.544     0.200
    48.359     1.605     0.200
    44.656     1.643     0.200
    43.258     1.653     0.200
    51.859     1.916     0.200
    56.758     2.076     0.200
    60.258     2.184     0.200
    68.957     2.599     0.200
    73.457     2.683     0.200
    72.758     2.694     0.200
    81.359     2.836     0.200
    77.758     2.970     0.200
    86.059     3.349     0.200
   100.258     3.833     0.200
   111.758     4.266     0.200
   129.559     4.986     0.200
   131.758     5.108     0.200
   288.758    11.331     0.200
   391.758    15.746     0.200
    19.547     0.439     0.200
    20.844     0.479     0.200
    24.141     0.662     0.200
    29.945     0.930     0.200
    31.945     0.969     0.200
    32.742     1.097     0.200
    32.242     1.058     0.200
    35.547     1.185     0.200
    40.945     1.355     0.200
    42.844     1.421     0.200
    42.047     1.432     0.200
    44.344     1.537     0.200
    53.945     1.653     0.200
    52.242     1.799     0.200
    50.047     1.817     0.200
    59.844     2.043     0.200
    66.844     2.328     0.200
    65.844     2.473     0.200
    73.344     2.666     0.200
    72.445     2.678     0.200
   132.242     5.186     0.200
    25.645     0.836     0.200
    37.645     1.372     0.200
    47.746     1.676     0.200
    53.645     1.923     0.200
    54.645     1.946     0.200
    53.844     1.987     0.200
    62.645     2.235     0.200
    63.645     2.364     0.200
    65.645     2.491     0.200
    70.645     2.711     0.200
    79.645     2.992     0.200
    77.645     2.976     0.200
    78.645     3.036     0.200
    78.645     3.036     0.200
    87.344     3.267     0.200
    90.945     3.311     0.200
   112.645     4.243     0.200
   125.645     4.614     0.200
   132.145     5.031     0.200
   166.645     6.355     0.200
   169.645     6.473     0.200
   170.645     6.439     0.200
   247.645     9.849     0.200
   257.945    10.205     0.200
   287.645    11.409     0.200
   309.645    12.151     0.200
   335.645    13.130     0.200
   484.645    19.605     0.200
    17.567     0.419     0.200
    17.267     0.403     0.200
    25.767     0.722     0.200
    25.167     0.767     0.200
    29.367     0.968     0.200
    29.567     0.975     0.200
    35.067     1.175     0.200
    36.667     1.177     0.200
    36.867     1.243     0.200
    37.167     1.250     0.200
    40.067     1.317     0.200
    42.967     1.450     0.200
    47.067     1.597     0.200
    47.667     1.661     0.200
    48.967     1.676     0.200
    48.667     1.672     0.200
    54.367     1.827     0.200
    58.467     1.877     0.200
    55.567     1.943     0.200
    63.967     2.275     0.200
    67.767     2.447     0.200
    70.067     2.628     0.200
    24.531     0.749     0.200
    29.430     0.906     0.200
    51.031     1.798     0.200
    50.832     1.800     0.200
    51.730     1.822     0.200
    55.832     1.987     0.200
    57.133     2.083     0.200
    67.531     2.478     0.200
    75.832     2.806     0.200
    82.031     3.069     0.200
    83.531     3.157     0.200
   156.531     6.025     0.200
    16.234     0.339     0.200
    20.133     0.518     0.200
    23.531     0.635     0.200
    30.836     0.971     0.200
    31.234     1.023     0.200
    32.633     1.068     0.200
    35.633     1.184     0.200
    36.133     1.233     0.200
    36.336     1.239     0.200
    41.531     1.408     0.200
    43.133     1.524     0.200
    44.930     1.510     0.200
    45.531     1.574     0.200
    46.531     1.618     0.200
    48.531     1.700     0.200
    51.633     1.742     0.200
    48.031     1.776     0.200
    54.430     1.937     0.200
    53.633     1.968     0.200
    57.133     2.052     0.200
    61.336     2.189     0.200
    62.234     2.313     0.200
    73.133     2.543     0.200
    70.133     2.554     0.200
    69.531     2.609     0.200
    74.336     2.883     0.200
    84.336     3.153     0.200
    84.930     3.282     0.200
    95.234     3.649     0.200
   108.734     4.138     0.200
   127.234     4.853     0.200
   129.133     5.028     0.200
   136.836     5.338     0.200
   146.633     5.710     0.200
    14.477     0.300     0.200
    18.676     0.445     0.200
    23.277     0.696     0.200
    27.875     0.841     0.200
    28.176     0.885     0.200
    31.977     1.043     0.200
    36.875     1.234     0.200
    37.777     1.270     0.200
    38.777     1.288     0.200
    38.574     1.318     0.200
    38.676     1.326     0.200
    43.977     1.546     0.200
    48.477     1.716     0.200
    48.375     1.719     0.200
    49.777     1.759     0.200
    50.676     1.785     0.200
    51.277     1.848     0.200
    53.676     1.871     0.200
    58.574     2.120     0.200
    58.977     2.155     0.200
    65.676     2.298     0.200
    64.176     2.321     0.200
    64.676     2.332     0.200
    72.074     2.706     0.200
    71.676     2.745     0.200
    80.176     2.956     0.200
    94.277     3.498     0.200
   106.676     3.995     0.200
   143.676     5.497     0.200
    19.531     0.469     0.200
    19.930     0.508     0.200
    19.625     0.492     0.200
    26.531     0.833     0.200
    32.930     1.083     0.200
    34.531     1.112     0.200
    37.328     1.149     0.200
    35.031     1.142     0.200
    39.328     1.383     0.200
    40.031     1.378     0.200
    40.328     1.379     0.200
    41.625     1.425     0.200
    43.828     1.545     0.200
    53.828     1.854     0.200
    53.828     1.883     0.200
    54.227     1.963     0.200
    56.227     1.950     0.200
    62.125     2.318     0.200
    69.625     2.627     0.200
    83.828     3.128     0.200
    95.930     3.741     0.200
   103.531     4.037     0.200
   108.930     4.157     0.200
   108.227     4.183     0.200
   125.430     4.869     0.200
   136.727     5.356     0.200
   156.430     6.174     0.200
   157.328     6.208     0.200
    17.266     0.422     0.200
    20.965     0.578     0.200
    20.363     0.571     0.200
    25.465     0.792     0.200
    35.766     1.046     0.200
    33.965     1.090     0.200
    34.266     1.153     0.200
    40.664     1.430     0.200
    42.562     1.487     0.200
    44.266     1.543     0.200
    47.664     1.665     0.200
    51.062     1.818     0.200
    52.664     1.804     0.200
    52.965     1.863     0.200
    59.164     2.079     0.200
    65.062     2.403     0.200
    71.766     2.637     0.200
    72.766     2.707     0.200
    75.664     2.764     0.200
    85.363     3.224     0.200
    96.863     3.646     0.200
   108.965     4.227     0.200
   109.062     4.244     0.200
   120.266     4.667     0.200
   418.664    16.768     0.200
    15.289     0.341     0.200
    15.689     0.360     0.200
    26.590     0.806     0.200
    27.189     0.830     0.200
    27.090     0.864     0.200
    29.689     0.944     0.200
    36.789     1.211     0.200
    38.189     1.288     0.200
    40.189     1.366     0.200
    41.090     1.373     0.200
    45.689     1.494     0.200
    46.090     1.614     0.200
    48.989     1.680     0.200
    50.989     1.805     0.200
    55.390     1.945     0.200
    69.189     2.394     0.200
    66.489     2.405     0.200
   102.189     3.968     0.200
   146.689     5.543     0.200
    19.738     0.468     0.200
    19.639     0.429     0.200
    25.238     0.675     0.200
    30.738     0.950     0.200
    31.038     0.987     0.200
    32.938     1.044     0.200
    32.838     1.105     0.200
    35.438     1.189     0.200
    40.938     1.344     0.200
    42.139     1.460     0.200
    42.838     1.442     0.200
    45.538     1.533     0.200
    48.738     1.634     0.200
    51.738     1.919     0.200
    51.738     1.931     0.200
    56.038     2.020     0.200
    56.938     2.061     0.200
    58.338     2.137     0.200
    65.838     2.468     0.200
    68.738     2.530     0.200
    74.038     2.682     0.200
    73.438     2.695     0.200
    80.738     3.052     0.200
    79.238     3.046     0.200
    98.538     3.783     0.200
   100.538     3.810     0.200
   102.139     3.869     0.200
   111.538     4.304     0.200
   131.338     5.014     0.200
   150.738     5.872     0.200
    16.883     0.365     0.200
    20.477     0.503     0.200
    23.477     0.643     0.200
    26.977     0.877     0.200
    31.977     0.998     0.200
    31.781     1.027     0.200
    33.680     1.090     0.200
    35.078     1.164     0.200
    37.383     1.220     0.200
    41.477     1.378     0.200
    44.781     1.518     0.200
    45.680     1.611     0.200
    49.180     1.699     0.200
    52.180     1.766     0.200
    53.477     1.914     0.200
    53.383     1.965     0.200
    57.078     2.026     0.200
    69.180     2.466     0.200
    66.180     2.479     0.200
    70.078     2.596     0.200
    77.883     2.904     0.200
    99.781     3.694     0.200
   108.883     4.129     0.200
   110.180     4.188     0.200
   116.078     4.412     0.200
   130.477     4.975     0.200
   129.281     5.021     0.200
   140.180     5.375     0.200
   145.180     5.578     0.200
   145.078     5.768     0.200
   168.180     6.378     0.200
   246.180     9.719     0.200
   276.180    10.789     0.200
   480.180    19.443     0.200
   572.180    23.264     0.200
    16.367     0.366     0.200
    19.766     0.502     0.200
    23.266     0.644     0.200
    28.562     0.876     0.200
    31.266     0.998     0.200
    31.164     1.026     0.200
    34.867     1.164     0.200
    35.766     1.218     0.200
    41.266     1.377     0.200
    45.367     1.520     0.200
    42.164     1.519     0.200
    43.367     1.590     0.200
    46.062     1.612     0.200
    49.266     1.700     0.200
    51.266     1.748     0.200
    53.766     1.768     0.200
    47.664     1.759     0.200
    54.469     1.913     0.200
    54.266     1.963     0.200
    59.266     2.024     0.200
    60.266     2.195     0.200
    69.562     2.533     0.200
    68.766     2.596     0.200
    11.895     0.126     0.200
    23.995     0.749     0.200
    25.695     0.762     0.200
    27.295     0.873     0.200
    33.595     1.056     0.200
    32.695     1.046     0.200
    39.795     1.302     0.200
    41.095     1.411     0.200
    43.695     1.422     0.200
    42.795     1.452     0.200
    41.895     1.457     0.200
    46.895     1.613     0.200
    47.095     1.586     0.200
    49.395     1.699     0.200
    52.895     1.747     0.200
    51.395     1.806     0.200
    53.795     1.860     0.200
    55.395     1.991     0.200
    58.495     1.995     0.200
    61.195     2.151     0.200
    66.595     2.370     0.200
    70.895     2.571     0.200
    71.895     2.581     0.200
    73.295     2.713     0.200
    77.495     2.820     0.200
    77.295     2.845     0.200
    80.895     2.925     0.200
    82.495     3.005     0.200
    93.895     3.597     0.200
   145.695     5.595     0.200
   145.895     5.652     0.200
   386.895    15.660     0.200
   421.895    16.917     0.200
   490.895    19.646     0.200
    17.270     0.375     0.200
    26.570     0.795     0.200
    25.770     0.770     0.200
    29.570     0.922     0.200
    37.070     1.208     0.200
    36.469     1.222     0.200
    38.070     1.301     0.200
    40.371     1.325     0.200
    39.969     1.397     0.200
    41.672     1.348     0.200
    42.469     1.501     0.200
    43.070     1.526     0.200
    46.172     1.622     0.200
    48.070     1.646     0.200
    49.672     1.716     0.200
    49.770     1.715     0.200
    51.172     1.799     0.200
    50.570     1.815     0.200
    54.371     1.925     0.200
    65.770     2.400     0.200
    65.969     2.412     0.200
    74.570     2.588     0.200
    69.570     2.680     0.200
    72.770     2.702     0.200
    74.570     2.760     0.200
    72.570     2.785     0.200
    80.172     3.021     0.200
    83.570     3.074     0.200
    86.871     3.202     0.200
    89.172     3.485     0.200
    94.871     3.566     0.200
   104.570     3.966     0.200
   102.871     4.001     0.200
   116.570     4.556     0.200
   123.672     4.848     0.200
   141.570     5.570     0.200
   141.469     5.647     0.200
   155.871     6.174     0.200
   272.570    10.796     0.200
   476.570    19.169     0.200
    11.791     0.059     0.200
    16.291     0.385     0.200
    20.990     0.579     0.200
    21.191     0.592     0.200
    22.891     0.668     0.200
    23.990     0.705     0.200
    24.291     0.735     0.200
    24.891     0.767     0.200
    34.791     1.157     0.200
    35.891     1.198     0.200
    37.191     1.248     0.200
    39.691     1.322     0.200
    40.090     1.355     0.200
    44.490     1.555     0.200
    46.891     1.612     0.200
    50.391     1.672     0.200
    47.891     1.678     0.200
    56.990     2.004     0.200
    59.291     2.161     0.200
    61.191     2.196     0.200
    69.090     2.576     0.200
    14.631     0.241     0.200
    21.131     0.569     0.200
    21.631     0.533     0.200
    23.230     0.673     0.200
    24.230     0.706     0.200
    25.332     0.760     0.200
    29.631     0.945     0.200
    33.432     1.090     0.200
    34.832     1.186     0.200
    37.631     1.246     0.200
    44.631     1.452     0.200
    43.031     1.515     0.200
    47.932     1.663     0.200
    71.131     2.675     0.200
    14.016     0.170     0.200
    19.117     0.476     0.200
    21.820     0.583     0.200
    21.117     0.570     0.200
    21.820     0.595     0.200
    24.516     0.667     0.200
    24.914     0.713     0.200
    23.516     0.688     0.200
    26.117     0.761     0.200
    36.219     1.173     0.200
    36.414     1.211     0.200
    36.414     1.244     0.200
    39.117     1.272     0.200
    45.516     1.563     0.200
    43.617     1.577     0.200
    47.414     1.582     0.200
    45.820     1.593     0.200
    49.016     1.821     0.200
    55.820     2.014     0.200
    56.414     2.061     0.200
    68.516     2.579     0.200
    92.016     3.608     0.200
    96.516     3.762     0.200
   106.219     4.165     0.200
   108.719     4.218     0.200
   109.414     4.271     0.200
   113.219     4.440     0.200
   115.820     4.575     0.200
   118.219     4.641     0.200
   118.719     4.680     0.200
   124.516     4.935     0.200
   135.516     5.333     0.200
   141.719     5.507     0.200
   144.219     5.680     0.200
   143.320     5.772     0.200
   144.719     5.819     0.200
   148.320     5.870     0.200
   151.820     5.959     0.200
   160.016     6.190     0.200
    14.004     0.183     0.200
    19.004     0.468     0.200
    20.504     0.525     0.200
    20.703     0.539     0.200
    22.906     0.645     0.200
    25.805     0.800     0.200
    28.203     0.851     0.200
    28.605     0.922     0.200
    36.004     1.199     0.200
    37.004     1.285     0.200
    38.105     1.286     0.200
    38.703     1.350     0.200
    42.504     1.448     0.200
    41.305     1.484     0.200
    47.504     1.679     0.200
    48.305     1.714     0.200
    54.004     1.957     0.200
    68.305     2.513     0.200
    78.605     2.934     0.200
    89.805     3.530     0.200
   103.906     4.091     0.200
   115.105     4.552     0.200
   122.305     4.851     0.200
    23.098     0.683     0.200
    25.098     0.739     0.200
    27.297     0.841     0.200
    31.297     0.989     0.200
    32.197     1.009     0.200
    48.897     1.706     0.200
    54.598     1.929     0.200
    55.897     1.967     0.200
    56.197     2.019     0.200
    56.797     2.067     0.200
    71.197     2.642     0.200
    79.297     3.027     0.200
    89.697     3.537     0.200
    12.797     0.193     0.200
    25.195     0.772     0.200
    26.098     0.816     0.200
    35.598     1.179     0.200
    40.398     1.330     0.200
    42.297     1.433     0.200
    53.398     1.794     0.200
   142.898     5.493     0.200
   147.797     5.713     0.200
    12.527     0.185     0.200
    13.227     0.247     0.200
    20.328     0.553     0.200
    21.426     0.617     0.200
    21.727     0.635     0.200
    22.426     0.666     0.200
    24.625     0.744     0.200
    25.625     0.763     0.200
    25.828     0.805     0.200
    26.727     0.807     0.200
    35.426     1.169     0.200
    39.625     1.308     0.200
    39.926     1.318     0.200
    40.625     1.386     0.200
    42.027     1.401     0.200
    41.527     1.422     0.200
    73.926     2.743     0.200
    73.328     2.749     0.200
   148.027     5.711     0.200
    12.633     0.179     0.200
    35.633     1.165     0.200
    39.727     1.320     0.200
    39.430     1.320     0.200
    42.133     1.394     0.200
    48.828     1.711     0.200
    60.727     2.166     0.200
    73.227     2.758     0.200
    89.227     3.149     0.200
   103.031     3.722     0.200
   390.430    15.666     0.200
   482.430    19.557     0.200
    12.684     0.195     0.200
    13.383     0.252     0.200
    20.383     0.621     0.200
    20.480     0.565     0.200
    21.480     0.619     0.200
    24.281     0.735     0.200
    22.781     0.679     0.200
    24.684     0.770     0.200
    35.383     1.178     0.200
    41.684     1.416     0.200
    53.383     1.791     0.200
    72.582     2.740     0.200
   150.980     5.724     0.200
   151.082     5.724     0.200
    17.934     0.330     0.200
    19.434     0.414     0.200
    20.234     0.414     0.200
    25.934     0.726     0.200
    25.834     0.729     0.200
    27.334     0.838     0.200
    29.834     0.883     0.200
    30.334     0.958     0.200
    32.334     1.041     0.200
    35.135     1.161     0.200
    39.635     1.277     0.200
    43.234     1.461     0.200
    42.934     1.490     0.200
    43.334     1.530     0.200
    43.934     1.526     0.200
    45.934     1.572     0.200
    46.734     1.684     0.200
    54.035     1.918     0.200
    53.934     1.925     0.200
    54.035     2.007     0.200
    56.434     2.017     0.200
    60.434     2.185     0.200
    59.934     2.189     0.200
    61.535     2.323     0.200
    62.834     2.349     0.200
    69.734     2.621     0.200
    71.535     2.658     0.200
    71.334     2.759     0.200
    77.434     2.986     0.200
    78.734     3.071     0.200
    85.334     3.216     0.200
    87.135     3.220     0.200
    96.135     3.699     0.200
    98.535     3.923     0.200
   111.734     4.311     0.200
   109.535     4.317     0.200
   110.535     4.326     0.200
   116.535     4.563     0.200
   120.834     4.750     0.200
   127.334     5.061     0.200
   138.834     5.442     0.200
   146.734     5.765     0.200
   147.434     5.925     0.200
   161.035     6.312     0.200
   164.334     6.531     0.200
    12.798     0.134     0.200
    16.298     0.373     0.200
    21.798     0.652     0.200
    22.898     0.658     0.200
    22.498     0.653     0.200
    22.798     0.661     0.200
    23.298     0.675     0.200
    24.398     0.747     0.200
    26.098     0.770     0.200
    34.598     1.143     0.200
    36.498     1.189     0.200
    38.398     1.276     0.200
    37.398     1.309     0.200
    37.998     1.303     0.200
    38.798     1.304     0.200
    39.498     1.328     0.200
    49.498     1.673     0.200
    47.998     1.790     0.200
    66.898     2.543     0.200
    71.798     2.659     0.200
    26.559     0.821     0.200
    27.355     0.845     0.200
   158.258     5.967     0.200
    23.367     0.677     0.200
    26.465     0.810     0.200
    30.266     0.920     0.200
    33.266     1.063     0.200
    32.965     1.070     0.200
    34.066     1.084     0.200
   154.566     5.994     0.200
   167.414     6.496     0.200
   165.414     6.583     0.200
    12.709     0.105     0.200
    17.709     0.437     0.200
    20.709     0.565     0.200
    21.910     0.604     0.200
    21.910     0.613     0.200
    22.809     0.652     0.200
    24.209     0.731     0.200
    26.209     0.819     0.200
    31.809     1.003     0.200
    33.309     1.070     0.200
    36.510     1.238     0.200
    36.609     1.275     0.200
    39.809     1.325     0.200
   136.766     5.298     0.200
   158.459     6.230     0.200
    20.105     0.555     0.200
    16.305     0.417     0.200
    17.902     0.504     0.200
    25.402     0.787     0.200
    27.902     0.869     0.200
    34.504     1.170     0.200
    41.105     1.360     0.200
   153.152     5.901     0.200
   156.797     6.136     0.200
   292.004    11.393     0.200
   292.004    11.402     0.200
   306.305    12.008     0.200
   307.004    12.249     0.200
   359.004    14.329     0.200
   372.004    14.868     0.200
   404.004    16.244     0.200
   484.004    19.567     0.200
   579.004    23.679     0.200
    14.945     0.281     0.200
    15.348     0.326     0.200
    16.348     0.374     0.200
    21.746     0.604     0.200
    22.445     0.637     0.200
    27.848     0.855     0.200
    30.047     0.939     0.200
    31.746     1.067     0.200
    37.547     1.227     0.200
    35.547     1.233     0.200
    37.746     1.251     0.200
   137.145     5.275     0.200
   153.496     6.041     0.200
    11.742     0.136     0.200
    12.844     0.228     0.200
    17.844     0.461     0.200
    19.645     0.555     0.200
    21.242     0.611     0.200
    24.242     0.748     0.200
    23.742     0.709     0.200
    36.543     1.234     0.200
    38.844     1.315     0.200
    41.742     1.418     0.200
   141.594     5.515     0.200
   144.844     5.599     0.200
   187.742     7.536     0.200
    17.281     0.288     0.200
    20.184     0.499     0.200
    20.184     0.498     0.200
    21.582     0.537     0.200
    27.480     0.789     0.200
    26.184     0.782     0.200
    26.480     0.800     0.200
    30.383     0.942     0.200
    29.281     0.902     0.200
    31.582     0.973     0.200
    31.383     1.019     0.200
    32.781     1.087     0.200
   136.281     5.340     0.200
   154.082     6.060     0.200
   155.332     6.061     0.200
    13.168     0.225     0.200
    13.766     0.245     0.200
    20.566     0.597     0.200
    21.266     0.574     0.200
    21.566     0.602     0.200
    24.066     0.705     0.200
    25.965     0.800     0.200
    38.918     1.278     0.200
   291.367    11.459     0.200
   297.367    11.757     0.200
    19.164     0.355     0.200
    19.258     0.340     0.200
    22.461     0.528     0.200
    24.758     0.648     0.200
    29.609     0.881     0.200
    30.758     0.923     0.200
    30.258     0.937     0.200
    31.961     0.994     0.200
    33.062     1.050     0.200
    37.664     1.229     0.200
   129.203     5.195     0.200
   148.781     5.918     0.200
    14.137     0.209     0.200
    17.438     0.400     0.200
    20.637     0.581     0.200
    23.535     0.695     0.200
    24.234     0.709     0.200
    25.035     0.733     0.200
    25.035     0.760     0.200
    36.387     1.202     0.200
    36.836     1.201     0.200
   150.637     5.769     0.200
    16.613     0.306     0.200
    16.012     0.283     0.200
    20.312     0.516     0.200
    22.512     0.636     0.200
    23.512     0.653     0.200
    25.914     0.783     0.200
    27.715     0.838     0.200
   152.113     5.828     0.200
   151.113     5.828     0.200
   181.613     7.343     0.200
   240.914     9.661     0.200
   240.812     9.661     0.200
   263.664    10.574     0.200
   293.414    11.467     0.200
    16.898     0.319     0.200
    19.301     0.468     0.200
    20.602     0.519     0.200
    20.602     0.517     0.200
    25.500     0.735     0.200
    27.602     0.823     0.200
    27.602     0.838     0.200
    28.398     0.862     0.200
    33.301     1.091     0.200
    36.898     1.195     0.200
   133.250     5.232     0.200
   148.898     5.859     0.200
   149.000     5.859     0.200
    12.859     0.155     0.200
    16.859     0.398     0.200
    21.859     0.639     0.200
    23.159     0.666     0.200
    22.759     0.658     0.200
    23.559     0.678     0.200
    25.559     0.770     0.200
    35.859     1.156     0.200
    38.309     1.253     0.200
    20.706     0.580     0.200
    20.105     0.576     0.200
    22.006     0.638     0.200
    20.806     0.619     0.200
    37.806     1.186     0.200
   166.405     6.454     0.200
   168.155     6.650     0.200
   236.806     9.436     0.200
   256.105    10.295     0.200
   269.806    10.610     0.200
   284.806    11.255     0.200
   308.806    12.170     0.200
   356.806    14.106     0.200
   564.105    22.966     0.200
   578.806    23.589     0.200
    14.066     0.289     0.200
    15.566     0.382     0.200
    17.566     0.467     0.200
    20.367     0.563     0.200
    22.867     0.664     0.200
    26.969     0.855     0.200
    30.066     0.947     0.200
    37.219     1.179     0.200
   139.117     5.541     0.200
    17.348     0.396     0.200
    18.047     0.428     0.200
    22.145     0.595     0.200
    24.746     0.733     0.200
    25.547     0.759     0.200
    29.547     0.957     0.200
    30.945     0.972     0.200
    35.246     1.086     0.200
   148.047     5.782     0.200
   163.348     6.421     0.200
   164.371     6.422     0.200
   167.246     6.669     0.200
    17.125     0.303     0.200
    19.824     0.447     0.200
    21.223     0.550     0.200
    23.023     0.631     0.200
    27.824     0.827     0.200
    33.016     1.033     0.200
    32.250     1.033     0.200
    31.824     1.037     0.200
    33.625     1.094     0.200
    37.023     1.222     0.200
   140.723     5.540     0.200
   140.723     5.540     0.200
   154.426     6.078     0.200
    11.477     0.052     0.200
    15.578     0.362     0.200
    18.680     0.473     0.200
    19.477     0.509     0.200
    20.477     0.568     0.200
    24.773     0.742     0.200
    33.773     1.094     0.200
    42.555     1.461     0.200
   139.078     5.416     0.200
   190.773     7.661     0.200
    15.170     0.276     0.200
    16.870     0.360     0.200
    17.970     0.463     0.200
    22.170     0.584     0.200
    22.670     0.639     0.200
    25.870     0.779     0.200
    27.370     0.851     0.200
    36.970     1.256     0.200
    39.570     1.344     0.200
   131.520     5.132     0.200
   131.520     5.132     0.200
   280.170    10.999     0.200
   320.770    12.710     0.200
    24.141     0.724     0.200
    25.344     0.762     0.200
    27.344     0.845     0.200
   118.562     4.581     0.200
   154.391     6.050     0.200
   153.625     6.050     0.200
   154.391     6.050     0.200
   159.141     6.061     0.200
   172.391     6.767     0.200
   172.734     6.913     0.200
    13.006     0.143     0.200
    17.006     0.394     0.200
    21.805     0.649     0.200
    22.506     0.651     0.200
    23.105     0.657     0.200
    23.205     0.667     0.200
    25.205     0.767     0.200
    38.006     1.265     0.200
    38.775     1.265     0.200
   112.006     4.296     0.200
   135.529     5.334     0.200
   136.186     5.334     0.200
   135.535     5.334     0.200
   136.836     5.353     0.200
   186.279     7.519     0.200
   446.805    18.062     0.200
    12.059     0.118     0.200
    15.957     0.370     0.200
    18.656     0.484     0.200
    19.559     0.521     0.200
    22.457     0.649     0.200
    22.355     0.645     0.200
    24.059     0.705     0.200
    26.957     0.851     0.200
    30.855     1.004     0.200
    32.133     1.033     0.200
   147.008     5.759     0.200
   158.969     6.313     0.200
   168.383     6.517     0.200
   169.457     6.776     0.200
    12.484     0.186     0.200
    15.586     0.366     0.200
    17.188     0.443     0.200
    18.281     0.487     0.200
    19.383     0.539     0.200
    27.383     0.853     0.200
    30.688     0.973     0.200
    46.961     1.567     0.200
   137.438     5.368     0.200
   139.883     5.385     0.200
    12.367     0.064     0.200
    16.766     0.387     0.200
    18.172     0.462     0.200
    19.570     0.522     0.200
    19.867     0.543     0.200
    25.070     0.765     0.200
    33.469     1.125     0.200
    33.266     1.125     0.200
   139.641     5.399     0.200
   140.070     5.499     0.200
    11.305     0.022     0.200
    15.906     0.381     0.200
    20.000     0.537     0.200
    20.906     0.570     0.200
    20.406     0.572     0.200
    25.000     0.764     0.200
    33.203     1.091     0.200
    41.078     1.394     0.200
   137.898     5.370     0.200
    13.840     0.279     0.200
    15.641     0.384     0.200
    16.840     0.418     0.200
    20.441     0.565     0.200
    24.242     0.751     0.200
    27.840     0.924     0.200
    33.043     1.089     0.200
    49.543     1.664     0.200
   140.941     5.525     0.200
    15.324     0.128     0.200
    16.227     0.189     0.200
    20.324     0.502     0.200
    22.824     0.575     0.200
    24.523     0.673     0.200
    26.727     0.765     0.200
    27.625     0.800     0.200
    26.727     0.794     0.200
    28.941     0.844     0.200
    28.426     0.844     0.200
    32.523     1.052     0.200
    37.824     1.264     0.200
    42.625     1.440     0.200
    54.324     1.892     0.200
   120.426     4.687     0.200
   141.328     5.514     0.200
   160.727     6.308     0.200
   161.516     6.308     0.200
   166.551     6.646     0.200
   234.125     9.262     0.200
   266.102    10.689     0.200
   284.812    11.198     0.200
   301.926    11.910     0.200
   405.301    16.230     0.200
   402.824    16.232     0.200
   410.227    16.538     0.200
   440.926    17.794     0.200
   443.926    18.009     0.200
   444.824    18.084     0.200
   476.523    19.050     0.200
   473.523    19.162     0.200
   482.523    19.546     0.200
   572.023    23.262     0.200
    12.791     0.188     0.200
    13.891     0.240     0.200
    20.391     0.547     0.200
    21.992     0.610     0.200
    21.492     0.637     0.200
    35.002     1.273     0.200
    40.518     1.312     0.200
   150.191     5.709     0.200
   389.191    15.676     0.200
   450.092    18.201     0.200
   487.492    19.552     0.200
    16.947     0.364     0.200
    16.748     0.359     0.200
    17.648     0.434     0.200
    25.049     0.725     0.200
    28.648     0.896     0.200
    34.197     1.118     0.200
   138.799     5.443     0.200
   152.648     5.910     0.200
   300.148    11.749     0.200
    14.312     0.037     0.200
    17.320     0.332     0.200
    19.039     0.406     0.200
    18.781     0.424     0.200
    25.109     0.736     0.200
    24.570     0.743     0.200
    28.875     0.913     0.200
    31.094     0.964     0.200
    33.070     1.097     0.200
    40.328     1.379     0.200
    50.422     1.772     0.200
    65.641     2.435     0.200
    71.641     2.741     0.200
   125.289     4.948     0.200
   133.516     5.208     0.200
   144.320     5.719     0.200
   161.852     6.397     0.200
   166.570     6.615     0.200
   482.570    19.199     0.200
    12.289     0.132     0.200
    15.020     0.306     0.200
    20.289     0.541     0.200
    19.949     0.546     0.200
    21.891     0.604     0.200
    22.379     0.648     0.200
    26.148     0.766     0.200
    25.969     0.780     0.200
    29.980     0.970     0.200
    31.621     1.001     0.200
    77.648     2.929     0.200
    76.148     2.947     0.200
    80.039     3.141     0.200
   145.621     5.686     0.200
   285.918    11.163     0.200
   302.121    11.881     0.200
   368.621    14.619     0.200
   379.918    15.230     0.200
   412.918    16.708     0.200
   477.320    19.316     0.200
    17.148     0.304     0.200
    18.359     0.402     0.200
    19.469     0.454     0.200
    23.609     0.650     0.200
    24.758     0.695     0.200
    27.859     0.844     0.200
    29.969     0.909     0.200
    31.383     1.030     0.200
    38.469     1.316     0.200
    38.133     1.388     0.200
    39.742     1.388     0.200
   130.023     5.087     0.200
   160.094     6.360     0.200
   372.070    14.699     0.200
   440.367    17.862     0.200
    13.312     0.239     0.200
    15.992     0.404     0.200
    18.672     0.512     0.200
    19.672     0.531     0.200
    23.352     0.731     0.200
    27.211     0.867     0.200
    34.586     1.115     0.200
   146.289     5.756     0.200
   157.789     6.174     0.200
   164.789     6.400     0.200
   238.188     9.497     0.200
   286.188    11.281     0.200
   285.211    11.313     0.200
   305.086    12.117     0.200
   379.289    14.984     0.200
   402.391    16.218     0.200
   412.188    16.714     0.200
   452.289    18.286     0.200
   564.188    23.037     0.200
    12.883     0.053     0.200
    16.570     0.348     0.200
    17.781     0.399     0.200
    17.961     0.426     0.200
    22.938     0.624     0.200
    25.461     0.739     0.200
    24.938     0.738     0.200
    29.047     0.922     0.200
    29.836     0.961     0.200
    30.562     0.961     0.200
    31.195     0.968     0.200
    33.273     1.098     0.200
    36.547     1.112     0.200
    73.461     2.756     0.200
   128.062     4.949     0.200
   145.742     5.735     0.200
    32.113     1.099     0.200
   107.543     4.151     0.200
   148.002     5.819     0.200
   376.473    14.953     0.200
   387.373    15.315     0.200
   485.572    19.594     0.200
    36.680     1.272     0.200
   154.125     5.969     0.200
   160.203     6.310     0.200
   239.930     9.580     0.200
   252.477    10.226     0.200
   423.531    16.922     0.200
   485.625    19.513     0.200
    21.305     0.613     0.200
    20.414     0.593     0.200
    20.594     0.602     0.200
    81.334     3.042     0.200
   150.684     5.972     0.200
   162.234     6.305     0.200
   254.859    10.221     0.200
   456.635    18.479     0.200
    20.082     0.564     0.200
    21.660     0.634     0.200
    22.371     0.670     0.200
    25.191     0.746     0.200
   168.559     6.726     0.200
    18.289     0.358     0.200
    20.023     0.432     0.200
    21.062     0.492     0.200
    20.633     0.491     0.200
    20.883     0.507     0.200
    26.430     0.798     0.200
    28.570     0.860     0.200
    31.422     0.993     0.200
    30.656     0.955     0.200
    41.711     1.364     0.200
    44.898     1.589     0.200
   135.852     5.320     0.200
   155.031     5.995     0.200
   153.906     6.050     0.200
   165.398     6.496     0.200
   178.977     7.251     0.200
   256.250    10.086     0.200
   266.477    10.752     0.200
   288.750    11.426     0.200
   295.148    11.649     0.200
   358.648    14.460     0.200
   476.852    19.172     0.200
    12.633     0.225     0.200
    18.227     0.500     0.200
    17.992     0.476     0.200
    20.273     0.571     0.200
    20.883     0.596     0.200
    22.656     0.678     0.200
    23.531     0.681     0.200
    34.781     1.117     0.200
    35.539     1.141     0.200
    77.586     2.929     0.200
   124.945     4.856     0.200
   131.906     5.225     0.200
   135.234     5.392     0.200
   150.438     5.890     0.200
   162.242     6.323     0.200
    13.312     0.243     0.200
    18.227     0.434     0.200
    19.656     0.513     0.200
    21.898     0.622     0.200
    23.953     0.727     0.200
    31.469     1.124     0.200
    36.586     1.213     0.200
    74.469     2.846     0.200
   139.578     5.521     0.200
   263.227    10.382     0.200
   366.727    14.778     0.200
   419.031    16.711     0.200
   491.430    19.673     0.200
    19.344     0.491     0.200
    21.551     0.561     0.200
    23.961     0.650     0.200
    30.723     0.974     0.200
    38.117     1.301     0.200
    39.484     1.337     0.200
    41.602     1.380     0.200
    66.582     2.527     0.200
   131.281     5.176     0.200
   255.621    10.042     0.200
   267.441    10.493     0.200
    16.362     0.341     0.200
    19.133     0.472     0.200
    20.423     0.552     0.200
    22.643     0.657     0.200
    27.303     0.851     0.200
    31.803     1.054     0.200
   141.293     5.520     0.200
   162.893     6.466     0.200
    18.414     0.452     0.200
    20.215     0.513     0.200
    23.574     0.669     0.200
    22.262     0.648     0.200
    23.445     0.682     0.200
    31.262     1.029     0.200
    51.223     1.823     0.200
   149.934     5.806     0.200
   164.160     6.341     0.200
   167.707     6.516     0.200
   167.660     6.732     0.200
   235.234     9.376     0.200
   265.535    10.460     0.200
   284.734    11.176     0.200
   290.801    11.449     0.200
   302.160    12.052     0.200
   339.832    13.474     0.200
   353.535    14.102     0.200
   354.234    14.039     0.200
   369.434    14.797     0.200
   377.434    14.941     0.200
   378.934    15.234     0.200
   391.633    15.616     0.200
   407.133    16.387     0.200
   416.934    16.773     0.200
   453.934    18.269     0.200
   480.734    19.353     0.200
    17.258     0.436     0.200
    19.176     0.530     0.200
    22.816     0.643     0.200
    21.938     0.638     0.200
    23.746     0.711     0.200
    34.621     1.107     0.200
    50.727     1.801     0.200
    76.746     2.904     0.200
   150.773     5.875     0.200
   167.297     6.690     0.200
    13.055     0.176     0.200
    18.406     0.468     0.200
    20.031     0.542     0.200
    21.930     0.619     0.200
    22.867     0.670     0.200
    23.922     0.681     0.200
    30.781     1.011     0.200
    33.992     1.088     0.200
    33.273     1.093     0.200
    48.750     1.809     0.200
    75.273     2.877     0.200
   124.445     4.862     0.200
   132.711     5.230     0.200
   137.406     5.339     0.200
   149.625     5.837     0.200
   149.031     5.837     0.200
   160.820     6.325     0.200
   168.945     6.736     0.200
    12.180     0.198     0.200
    15.633     0.367     0.200
    17.969     0.473     0.200
    20.812     0.573     0.200
    23.523     0.704     0.200
    25.430     0.780     0.200
    32.477     1.017     0.200
    31.273     1.077     0.200
    33.273     1.115     0.200
   126.422     4.965     0.200
   135.727     5.334     0.200
   137.609     5.362     0.200
   151.609     5.879     0.200
   150.492     5.879     0.200
   163.508     6.430     0.200
   165.078     6.431     0.200
    19.469     0.551     0.200
    22.219     0.622     0.200
    76.375     2.931     0.200
   125.695     4.886     0.200
   137.000     5.397     0.200
   150.469     5.901     0.200
   169.422     6.687     0.200
   268.320    10.549     0.200
   414.516    16.473     0.200
   484.617    19.415     0.200
    17.008     0.415     0.200
    18.789     0.493     0.200
    22.797     0.629     0.200
    22.367     0.670     0.200
    23.672     0.721     0.200
    32.875     1.062     0.200
    36.117     1.122     0.200
   148.719     5.834     0.200
   161.469     6.378     0.200
   166.555     6.689     0.200
    11.867     0.163     0.200
    16.737     0.422     0.200
    18.567     0.502     0.200
    21.897     0.635     0.200
    22.447     0.661     0.200
    23.728     0.716     0.200
    31.428     1.057     0.200
    33.433     1.072     0.200
   149.678     5.841     0.200
    34.365     1.142     0.200
    71.445     2.759     0.200
   136.764     5.399     0.200
   154.535     6.094     0.200
   189.914     7.662     0.200
   268.064    10.613     0.200
    65.480     2.391     0.200
END
# Sb arrivals
gmt psxy -: -R $projection -Sc -Wthin,blue -K -O << END >> $psfile
END
# Sg arrivals
gmt psxy -: -R $projection -Sc -Wthin,red -K -O << END >> $psfile
    12.146     0.206     0.200
    20.146     0.604     0.200
    22.146     0.628     0.200
    30.146     0.967     0.200
    32.146     1.015     0.200
    45.146     1.485     0.200
    46.146     1.560     0.200
    53.146     1.628     0.200
    49.146     1.671     0.200
    52.146     1.724     0.200
    62.146     2.180     0.200
    76.146     2.489     0.200
    80.146     2.697     0.200
    85.146     3.039     0.200
    97.146     3.253     0.200
    14.199     0.308     0.200
    23.799     0.690     0.200
    22.699     0.649     0.200
    29.199     0.929     0.200
    36.999     1.166     0.200
    41.600     1.362     0.200
    55.100     1.905     0.200
    53.199     1.869     0.200
    60.600     1.961     0.200
    60.199     2.074     0.200
    94.199     3.219     0.200
    12.094     0.265     0.200
    16.492     0.459     0.200
    32.289     1.057     0.200
    42.891     1.386     0.200
    42.289     1.322     0.200
    47.094     1.593     0.200
    51.891     1.683     0.200
    58.789     1.899     0.200
    60.391     2.071     0.200
    61.391     2.108     0.200
    61.992     2.171     0.200
    64.391     2.145     0.200
    73.594     2.403     0.200
    11.645     0.237     0.200
    17.645     0.455     0.200
    28.246     0.872     0.200
    41.145     1.377     0.200
    57.145     1.931     0.200
    72.344     2.495     0.200
    89.645     3.149     0.200
   121.445     4.223     0.200
    15.930     0.410     0.200
    17.332     0.485     0.200
    34.230     1.118     0.200
    38.832     1.241     0.200
    38.531     1.264     0.200
    44.133     1.448     0.200
    43.930     1.479     0.200
    45.031     1.533     0.200
    46.930     1.622     0.200
    56.031     1.935     0.200
    59.832     2.053     0.200
    61.832     2.182     0.200
    63.531     2.240     0.200
    13.797     0.332     0.200
    35.997     1.176     0.200
    42.098     1.420     0.200
    46.797     1.577     0.200
    48.997     1.631     0.200
    49.098     1.665     0.200
    56.598     1.968     0.200
    59.098     2.076     0.200
    10.656     0.196     0.200
    18.355     0.492     0.200
    32.758     1.068     0.200
    19.066     0.552     0.200
    20.266     0.578     0.200
    20.664     0.606     0.200
    34.066     1.122     0.200
    36.414     1.183     0.200
    37.164     1.182     0.200
    37.867     1.225     0.200
    41.066     1.328     0.200
    42.367     1.387     0.200
    46.367     1.528     0.200
    46.965     1.605     0.200
    48.367     1.658     0.200
    13.039     0.294     0.200
    18.039     0.513     0.200
    18.742     0.513     0.200
    35.141     1.160     0.200
    42.945     1.425     0.200
    10.604     0.104     0.200
    14.633     0.320     0.200
    16.273     0.438     0.200
    21.842     0.653     0.200
    26.133     0.838     0.200
    14.609     0.354     0.200
    17.375     0.459     0.200
    20.852     0.609     0.200
    20.789     0.598     0.200
    20.445     0.595     0.200
    25.438     0.802     0.200
    28.039     0.883     0.200
    27.922     0.895     0.200
    38.555     1.289     0.200
    39.828     1.272     0.200
    14.734     0.359     0.200
    17.434     0.455     0.200
    26.305     0.805     0.200
    27.523     0.884     0.200
    38.734     1.266     0.200
    38.783     1.292     0.200
    39.564     1.277     0.200
    39.084     1.277     0.200
    40.135     1.277     0.200
    14.461     0.367     0.200
    18.398     0.509     0.200
    29.629     0.960     0.200
    29.680     0.962     0.200
    38.711     1.236     0.200
    39.230     1.282     0.200
    12.016     0.226     0.200
    17.781     0.447     0.200
    23.375     0.650     0.200
    23.852     0.710     0.200
    34.289     1.096     0.200
    35.141     1.134     0.200
    36.750     1.142     0.200
    51.656     1.808     0.200
END
# Lg arrivals
gmt psxy -: -R $projection -Sc -Wthin,cyan -K -O << END >> $psfile
    85.120     2.813     0.200
    91.120     3.085     0.200
   220.120     6.822     0.200
   112.383     3.745     0.200
    90.203     2.970     0.200
    99.203     3.234     0.200
    78.498     2.690     0.200
    98.498     3.247     0.200
    77.215     2.651     0.200
    90.215     2.979     0.200
    84.305     2.708     0.200
    92.305     3.000     0.200
    91.305     3.009     0.200
    94.944     3.053     0.200
    91.944     3.068     0.200
    77.062     2.562     0.200
    82.062     2.781     0.200
    90.062     2.872     0.200
    91.062     3.021     0.200
    93.062     3.095     0.200
    99.062     3.254     0.200
   103.062     3.338     0.200
   115.062     3.832     0.200
    88.516     2.907     0.200
    78.027     2.560     0.200
    85.008     2.758     0.200
    86.008     2.853     0.200
   111.008     3.727     0.200
    77.100     2.543     0.200
    82.688     2.546     0.200
    86.957     2.959     0.200
    80.445     2.617     0.200
   301.645     9.849     0.200
   457.070    14.515     0.200
   174.105     5.585     0.200
    76.297     2.578     0.200
   458.297    14.618     0.200
    76.582     2.588     0.200
    79.980     2.718     0.200
   178.959     5.712     0.200
   181.234     5.972     0.200
   193.809     6.205     0.200
   186.910     6.017     0.200
   173.332     5.631     0.200
   195.023     6.555     0.200
   179.320     5.901     0.200
   605.805    19.240     0.200
END
# Sg arrivals
gmt psxy -: -R $projection -Sc -Wthin,red -K -O << END >> $psfile
    12.146     0.206     0.200
    20.146     0.604     0.200
    22.146     0.628     0.200
    30.146     0.967     0.200
    32.146     1.015     0.200
    45.146     1.485     0.200
    46.146     1.560     0.200
    53.146     1.628     0.200
    49.146     1.671     0.200
    52.146     1.724     0.200
    62.146     2.180     0.200
    76.146     2.489     0.200
    80.146     2.697     0.200
    85.146     3.039     0.200
    97.146     3.253     0.200
    14.199     0.308     0.200
    23.799     0.690     0.200
    22.699     0.649     0.200
    29.199     0.929     0.200
    36.999     1.166     0.200
    41.600     1.362     0.200
    55.100     1.905     0.200
    53.199     1.869     0.200
    60.600     1.961     0.200
    60.199     2.074     0.200
    94.199     3.219     0.200
    12.094     0.265     0.200
    16.492     0.459     0.200
    32.289     1.057     0.200
    42.891     1.386     0.200
    42.289     1.322     0.200
    47.094     1.593     0.200
    51.891     1.683     0.200
    58.789     1.899     0.200
    60.391     2.071     0.200
    61.391     2.108     0.200
    61.992     2.171     0.200
    64.391     2.145     0.200
    73.594     2.403     0.200
    11.645     0.237     0.200
    17.645     0.455     0.200
    28.246     0.872     0.200
    41.145     1.377     0.200
    57.145     1.931     0.200
    72.344     2.495     0.200
    89.645     3.149     0.200
   121.445     4.223     0.200
    15.930     0.410     0.200
    17.332     0.485     0.200
    34.230     1.118     0.200
    38.832     1.241     0.200
    38.531     1.264     0.200
    44.133     1.448     0.200
    43.930     1.479     0.200
    45.031     1.533     0.200
    46.930     1.622     0.200
    56.031     1.935     0.200
    59.832     2.053     0.200
    61.832     2.182     0.200
    63.531     2.240     0.200
    13.797     0.332     0.200
    35.997     1.176     0.200
    42.098     1.420     0.200
    46.797     1.577     0.200
    48.997     1.631     0.200
    49.098     1.665     0.200
    56.598     1.968     0.200
    59.098     2.076     0.200
    10.656     0.196     0.200
    18.355     0.492     0.200
    32.758     1.068     0.200
    19.066     0.552     0.200
    20.266     0.578     0.200
    20.664     0.606     0.200
    34.066     1.122     0.200
    36.414     1.183     0.200
    37.164     1.182     0.200
    37.867     1.225     0.200
    41.066     1.328     0.200
    42.367     1.387     0.200
    46.367     1.528     0.200
    46.965     1.605     0.200
    48.367     1.658     0.200
    13.039     0.294     0.200
    18.039     0.513     0.200
    18.742     0.513     0.200
    35.141     1.160     0.200
    42.945     1.425     0.200
    10.604     0.104     0.200
    14.633     0.320     0.200
    16.273     0.438     0.200
    21.842     0.653     0.200
    26.133     0.838     0.200
    14.609     0.354     0.200
    17.375     0.459     0.200
    20.852     0.609     0.200
    20.789     0.598     0.200
    20.445     0.595     0.200
    25.438     0.802     0.200
    28.039     0.883     0.200
    27.922     0.895     0.200
    38.555     1.289     0.200
    39.828     1.272     0.200
    14.734     0.359     0.200
    17.434     0.455     0.200
    26.305     0.805     0.200
    27.523     0.884     0.200
    38.734     1.266     0.200
    38.783     1.292     0.200
    39.564     1.277     0.200
    39.084     1.277     0.200
    40.135     1.277     0.200
    14.461     0.367     0.200
    18.398     0.509     0.200
    29.629     0.960     0.200
    29.680     0.962     0.200
    38.711     1.236     0.200
    39.230     1.282     0.200
    12.016     0.226     0.200
    17.781     0.447     0.200
    23.375     0.650     0.200
    23.852     0.710     0.200
    34.289     1.096     0.200
    35.141     1.134     0.200
    36.750     1.142     0.200
    51.656     1.808     0.200
END
# S-P arrivals
gmt psxy -: -R $projection -Sc -Wthin,red -O << END >> $psfile
END
